'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var LexicalAutoFocusPlugin = require('@lexical/react/LexicalAutoFocusPlugin');
var LexicalCharacterLimitPlugin = require('@lexical/react/LexicalCharacterLimitPlugin');
var LexicalCheckListPlugin = require('@lexical/react/LexicalCheckListPlugin');
var LexicalClearEditorPlugin = require('@lexical/react/LexicalClearEditorPlugin');
var LexicalClickableLinkPlugin = require('@lexical/react/LexicalClickableLinkPlugin');
var LexicalErrorBoundary = require('@lexical/react/LexicalErrorBoundary');
var LexicalHashtagPlugin = require('@lexical/react/LexicalHashtagPlugin');
var LexicalHistoryPlugin = require('@lexical/react/LexicalHistoryPlugin');
var LexicalHorizontalRulePlugin = require('@lexical/react/LexicalHorizontalRulePlugin');
var LexicalListPlugin = require('@lexical/react/LexicalListPlugin');
var LexicalPlainTextPlugin = require('@lexical/react/LexicalPlainTextPlugin');
var LexicalRichTextPlugin = require('@lexical/react/LexicalRichTextPlugin');
var LexicalTabIndentationPlugin = require('@lexical/react/LexicalTabIndentationPlugin');
var LexicalTablePlugin = require('@lexical/react/LexicalTablePlugin');
var useLexicalEditable = require('@lexical/react/useLexicalEditable');
var React = require('react');
var SettingsContext = require('./context/SettingsContext.js');
var SharedHistoryContext = require('./context/SharedHistoryContext.js');
var TableCellNodes = require('./nodes/TableCellNodes.js');
var index$z = require('./plugins/ActionsPlugin/index.js');
var index$w = require('./plugins/AutocompletePlugin/index.js');
var index$5 = require('./plugins/AutoEmbedPlugin/index.js');
var index$a = require('./plugins/AutoLinkPlugin/index.js');
var index$t = require('./plugins/CodeActionMenuPlugin/index.js');
var index$c = require('./plugins/CodeHighlightPlugin/index.js');
var index$q = require('./plugins/CollapsiblePlugin/index.js');
var index$3 = require('./plugins/ComponentPickerPlugin/index.js');
var index$y = require('./plugins/ContextMenuPlugin/index.js');
var index$2 = require('./plugins/DragDropPastePlugin/index.js');
var index$s = require('./plugins/DraggableBlockPlugin/index.js');
var index$4 = require('./plugins/EmojiPickerPlugin/index.js');
var index$7 = require('./plugins/EmojisPlugin/index.js');
var index$n = require('./plugins/EquationsPlugin/index.js');
var index$o = require('./plugins/ExcalidrawPlugin/index.js');
var index$m = require('./plugins/FigmaPlugin/index.js');
var index$u = require('./plugins/FloatingLinkEditorPlugin/index.js');
var index$h = require('./plugins/FloatingTextFormatToolbarPlugin/index.js');
var index$f = require('./plugins/ImagesPlugin/index.js');
var index$i = require('./plugins/InlineImagePlugin/index.js');
var index$8 = require('./plugins/KeywordsPlugin/index.js');
var index$g = require('./plugins/LinkPlugin/index.js');
var index$d = require('./plugins/ListMaxIndentLevelPlugin/index.js');
var index$b = require('./plugins/MarkdownShortcutPlugin/index.js');
var index$1 = require('./plugins/MaxLengthPlugin/index.js');
var index$6 = require('./plugins/MentionsPlugin/index.js');
var index$r = require('./plugins/PageBreakPlugin/index.js');
var index$j = require('./plugins/PollPlugin/index.js');
var index$9 = require('./plugins/SpeechToTextPlugin/index.js');
var index$p = require('./plugins/TabFocusPlugin/index.js');
var index$v = require('./plugins/TableActionMenuPlugin/index.js');
var index$e = require('./plugins/TableCellResizer/index.js');
var index$x = require('./plugins/TableOfContentsPlugin/index.js');
var TablePlugin = require('./plugins/TablePlugin.js');
var index = require('./plugins/ToolbarPlugin/index.js');
var index$A = require('./plugins/TreeViewPlugin/index.js');
var index$k = require('./plugins/TwitterPlugin/index.js');
var index$l = require('./plugins/YouTubePlugin/index.js');
var PlaygroundEditorTheme = require('./themes/PlaygroundEditorTheme.js');
var ContentEditable = require('./ui/ContentEditable.js');
var Placeholder = require('./ui/Placeholder.js');
var HeaderPlugin = require('./extends/HeaderPlugin.js');
var InitialWithHtmlPlugin = require('./extends/InitialWithHtmlPlugin.js');
var lexical = require('lexical');
var html = require('@lexical/html');
var LexicalOnChangePlugin = require('@lexical/react/LexicalOnChangePlugin');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

function _interopNamespace(e) {
    if (e && e.__esModule) return e;
    var n = Object.create(null);
    if (e) {
        Object.keys(e).forEach(function (k) {
            if (k !== 'default') {
                var d = Object.getOwnPropertyDescriptor(e, k);
                Object.defineProperty(n, k, d.get ? d : {
                    enumerable: true,
                    get: function () { return e[k]; }
                });
            }
        });
    }
    n["default"] = e;
    return Object.freeze(n);
}

var LexicalClickableLinkPlugin__default = /*#__PURE__*/_interopDefaultLegacy(LexicalClickableLinkPlugin);
var LexicalErrorBoundary__default = /*#__PURE__*/_interopDefaultLegacy(LexicalErrorBoundary);
var useLexicalEditable__default = /*#__PURE__*/_interopDefaultLegacy(useLexicalEditable);
var React__namespace = /*#__PURE__*/_interopNamespace(React);

const CAN_USE_DOM = typeof window !== 'undefined' &&
    typeof window.document !== 'undefined' &&
    typeof window.document.createElement !== 'undefined';
function Editor({ onSaveCloud, initialHtml, onChange }) {
    const { historyState } = SharedHistoryContext.useSharedHistoryContext();
    const { settings: { isCollab, isAutocomplete, isMaxLength, isCharLimit, isCharLimitUtf8, isRichText, showTreeView, showTableOfContents, shouldUseLexicalContextMenu, tableCellMerge, tableCellBackgroundColor, }, } = SettingsContext.useSettings();
    const isEditable = useLexicalEditable__default["default"]();
    const text = isCollab
        ? 'Enter some collaborative rich text...'
        : isRichText
            ? 'Enter some rich text...'
            : 'Enter some plain text...';
    const placeholder = jsxRuntime.jsx(Placeholder["default"], { children: text });
    const [floatingAnchorElem, setFloatingAnchorElem] = React.useState(null);
    const [isSmallWidthViewport, setIsSmallWidthViewport] = React.useState(false);
    const onRef = (_floatingAnchorElem) => {
        if (_floatingAnchorElem !== null) {
            setFloatingAnchorElem(_floatingAnchorElem);
        }
    };
    const cellEditorConfig = {
        namespace: 'Playground',
        nodes: [...TableCellNodes["default"]],
        onError: (error) => {
            throw error;
        },
        theme: PlaygroundEditorTheme["default"],
    };
    React.useEffect(() => {
        const updateViewPortWidth = () => {
            const isNextSmallWidthViewport = CAN_USE_DOM && window.matchMedia('(max-width: 1025px)').matches;
            if (isNextSmallWidthViewport !== isSmallWidthViewport) {
                setIsSmallWidthViewport(isNextSmallWidthViewport);
            }
        };
        updateViewPortWidth();
        window.addEventListener('resize', updateViewPortWidth);
        return () => {
            window.removeEventListener('resize', updateViewPortWidth);
        };
    }, [isSmallWidthViewport]);
    const onEditorChange = React__namespace.useCallback((editorState, editor) => {
        editorState.read(() => {
            const htmlString = html.$generateHtmlFromNodes(editor);
            if (htmlString !== initialHtml && htmlString !== '<p class="editor-paragraph"><br></p>') {
                const firstNode = lexical.$getRoot().getChildAtIndex(0);
                let header = '';
                if (firstNode && firstNode.__tag === 'h1') {
                    header = firstNode.getTextContent();
                }
                onChange(htmlString, header);
            }
        });
    }, [initialHtml]);
    return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx(HeaderPlugin.HeaderPlugin, { placeholder: 'Please input a title ...' }), isRichText && jsxRuntime.jsx(index["default"], {}), jsxRuntime.jsxs("div", { className: `editor-container ${showTreeView ? 'tree-view' : ''} ${!isRichText ? 'plain-text' : ''}`, children: [isMaxLength && jsxRuntime.jsx(index$1.MaxLengthPlugin, { maxLength: 30 }), jsxRuntime.jsx(index$2["default"], {}), jsxRuntime.jsx(LexicalAutoFocusPlugin.AutoFocusPlugin, {}), jsxRuntime.jsx(LexicalClearEditorPlugin.ClearEditorPlugin, {}), jsxRuntime.jsx(index$3["default"], {}), jsxRuntime.jsx(index$4["default"], {}), jsxRuntime.jsx(index$5["default"], {}), jsxRuntime.jsx(InitialWithHtmlPlugin.InitialWithHtmlPlugin, { html: initialHtml }), jsxRuntime.jsx(index$6["default"], {}), jsxRuntime.jsx(index$7["default"], {}), jsxRuntime.jsx(LexicalHashtagPlugin.HashtagPlugin, {}), jsxRuntime.jsx(index$8["default"], {}), jsxRuntime.jsx(index$9["default"], {}), jsxRuntime.jsx(index$a["default"], {}), jsxRuntime.jsx(LexicalOnChangePlugin.OnChangePlugin, { onChange: onEditorChange }), isRichText ? (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [
                            // isCollab ? (
                            //   <CollaborationPlugin
                            //     id="main"
                            //     providerFactory={createWebsocketProvider}
                            //     shouldBootstrap={!skipCollaborationInit}
                            //   />
                            // ) : 
                            (jsxRuntime.jsx(LexicalHistoryPlugin.HistoryPlugin, { externalHistoryState: historyState })), jsxRuntime.jsx(LexicalRichTextPlugin.RichTextPlugin, { contentEditable: jsxRuntime.jsx("div", { className: "editor-scroller", children: jsxRuntime.jsx("div", { className: "editor", ref: onRef, children: jsxRuntime.jsx(ContentEditable["default"], {}) }) }), placeholder: placeholder, ErrorBoundary: LexicalErrorBoundary__default["default"] }), jsxRuntime.jsx(index$b["default"], {}), jsxRuntime.jsx(index$c["default"], {}), jsxRuntime.jsx(LexicalListPlugin.ListPlugin, {}), jsxRuntime.jsx(LexicalCheckListPlugin.CheckListPlugin, {}), jsxRuntime.jsx(index$d["default"], { maxDepth: 7 }), jsxRuntime.jsx(LexicalTablePlugin.TablePlugin, { hasCellMerge: tableCellMerge, hasCellBackgroundColor: tableCellBackgroundColor }), jsxRuntime.jsx(index$e["default"], {}), jsxRuntime.jsxs(TablePlugin.TablePlugin, { cellEditorConfig: cellEditorConfig, children: [jsxRuntime.jsx(LexicalAutoFocusPlugin.AutoFocusPlugin, {}), jsxRuntime.jsx(LexicalRichTextPlugin.RichTextPlugin, { contentEditable: jsxRuntime.jsx(ContentEditable["default"], { className: "TableNode__contentEditable" }), placeholder: null, ErrorBoundary: LexicalErrorBoundary__default["default"] }), jsxRuntime.jsx(index$6["default"], {}), jsxRuntime.jsx(LexicalHistoryPlugin.HistoryPlugin, {}), jsxRuntime.jsx(index$f["default"], { captionsEnabled: false }), jsxRuntime.jsx(index$g["default"], {}), jsxRuntime.jsx(LexicalClickableLinkPlugin__default["default"], {}), jsxRuntime.jsx(index$h["default"], {})] }), jsxRuntime.jsx(index$f["default"], {}), jsxRuntime.jsx(index$i["default"], {}), jsxRuntime.jsx(index$g["default"], {}), jsxRuntime.jsx(index$j["default"], {}), jsxRuntime.jsx(index$k["default"], {}), jsxRuntime.jsx(index$l["default"], {}), jsxRuntime.jsx(index$m["default"], {}), !isEditable && jsxRuntime.jsx(LexicalClickableLinkPlugin__default["default"], {}), jsxRuntime.jsx(LexicalHorizontalRulePlugin.HorizontalRulePlugin, {}), jsxRuntime.jsx(index$n["default"], {}), jsxRuntime.jsx(index$o["default"], {}), jsxRuntime.jsx(index$p["default"], {}), jsxRuntime.jsx(LexicalTabIndentationPlugin.TabIndentationPlugin, {}), jsxRuntime.jsx(index$q["default"], {}), jsxRuntime.jsx(index$r["default"], {}), floatingAnchorElem && !isSmallWidthViewport && (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx(index$s["default"], { anchorElem: floatingAnchorElem }), jsxRuntime.jsx(index$t["default"], { anchorElem: floatingAnchorElem }), jsxRuntime.jsx(index$u["default"], { anchorElem: floatingAnchorElem }), jsxRuntime.jsx(index$v["default"], { anchorElem: floatingAnchorElem, cellMerge: true }), jsxRuntime.jsx(index$h["default"], { anchorElem: floatingAnchorElem })] }))] })) : (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx(LexicalPlainTextPlugin.PlainTextPlugin, { contentEditable: jsxRuntime.jsx(ContentEditable["default"], {}), placeholder: placeholder, ErrorBoundary: LexicalErrorBoundary__default["default"] }), jsxRuntime.jsx(LexicalHistoryPlugin.HistoryPlugin, { externalHistoryState: historyState })] })), (isCharLimit || isCharLimitUtf8) && (jsxRuntime.jsx(LexicalCharacterLimitPlugin.CharacterLimitPlugin, { charset: isCharLimit ? 'UTF-16' : 'UTF-8', maxLength: 5 })), isAutocomplete && jsxRuntime.jsx(index$w["default"], {}), jsxRuntime.jsx("div", { children: showTableOfContents && jsxRuntime.jsx(index$x["default"], {}) }), shouldUseLexicalContextMenu && jsxRuntime.jsx(index$y["default"], {}), jsxRuntime.jsx(index$z["default"], { isRichText: isRichText, onSaveCloud: onSaveCloud })] }), showTreeView && jsxRuntime.jsx(index$A["default"], {})] }));
}

exports["default"] = Editor;
