'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var React = require('react');
var appSettings = require('../appSettings.js');

const Context = React.createContext({
    setOption: (name, value) => {
        return;
    },
    settings: appSettings.DEFAULT_SETTINGS,
});
const SettingsContext = ({ children, }) => {
    const [settings, setSettings] = React.useState(appSettings.DEFAULT_SETTINGS);
    const setOption = React.useCallback((setting, value) => {
        setSettings((options) => (Object.assign(Object.assign({}, options), { [setting]: value })));
        if (appSettings.DEFAULT_SETTINGS[setting] === value) {
            setURLParam(setting, null);
        }
        else {
            setURLParam(setting, value);
        }
    }, []);
    const contextValue = React.useMemo(() => {
        return { setOption, settings };
    }, [setOption, settings]);
    return jsxRuntime.jsx(Context.Provider, { value: contextValue, children: children });
};
const useSettings = () => {
    return React.useContext(Context);
};
function setURLParam(param, value) {
    const url = new URL(window.location.href);
    const params = new URLSearchParams(url.search);
    if (value !== null) {
        if (params.has(param)) {
            params.set(param, String(value));
        }
        else {
            params.append(param, String(value));
        }
    }
    else {
        if (params.has(param)) {
            params.delete(param);
        }
    }
    url.search = params.toString();
    window.history.pushState(null, '', url.toString());
}

exports.SettingsContext = SettingsContext;
exports.useSettings = useSettings;
