'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var React = require('react');

const Context = React.createContext([
    (_cb) => () => {
        return;
    },
    (_newSuggestion) => {
        return;
    },
]);
const SharedAutocompleteContext = ({ children, }) => {
    const context = React.useMemo(() => {
        let suggestion = null;
        const listeners = new Set();
        return [
            (cb) => {
                cb(suggestion);
                listeners.add(cb);
                return () => {
                    listeners.delete(cb);
                };
            },
            (newSuggestion) => {
                suggestion = newSuggestion;
                for (const listener of listeners) {
                    listener(newSuggestion);
                }
            },
        ];
    }, []);
    return jsxRuntime.jsx(Context.Provider, { value: context, children: children });
};
const useSharedAutocompleteContext = () => {
    const [subscribe, publish] = React.useContext(Context);
    const [suggestion, setSuggestion] = React.useState(null);
    React.useEffect(() => {
        return subscribe((newSuggestion) => {
            setSuggestion(newSuggestion);
        });
    }, [subscribe]);
    return [suggestion, publish];
};

exports.SharedAutocompleteContext = SharedAutocompleteContext;
exports.useSharedAutocompleteContext = useSharedAutocompleteContext;
