'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var lexical = require('lexical');
var SharedAutocompleteContext = require('../context/SharedAutocompleteContext.js');
var index = require('../plugins/AutocompletePlugin/index.js');

class AutocompleteNode extends lexical.DecoratorNode {
    static clone(node) {
        return new AutocompleteNode(node.__uuid, node.__key);
    }
    static getType() {
        return 'autocomplete';
    }
    static importJSON(serializedNode) {
        const node = $createAutocompleteNode(serializedNode.uuid);
        return node;
    }
    exportJSON() {
        return Object.assign(Object.assign({}, super.exportJSON()), { type: 'autocomplete', uuid: this.__uuid, version: 1 });
    }
    constructor(uuid, key) {
        super(key);
        this.__uuid = uuid;
    }
    updateDOM(prevNode, dom, config) {
        return false;
    }
    createDOM(config) {
        return document.createElement('span');
    }
    decorate() {
        if (this.__uuid !== index.uuid) {
            return null;
        }
        return jsxRuntime.jsx(AutocompleteComponent, {});
    }
}
function $createAutocompleteNode(uuid) {
    return new AutocompleteNode(uuid);
}
function AutocompleteComponent() {
    const [suggestion] = SharedAutocompleteContext.useSharedAutocompleteContext();
    const userAgentData = window.navigator.userAgentData;
    const isMobile = userAgentData !== undefined
        ? userAgentData.mobile
        : window.innerWidth <= 800 && window.innerHeight <= 600;
    // TODO Move to theme
    return (jsxRuntime.jsxs("span", { style: { color: '#ccc' }, spellCheck: "false", children: [suggestion, " ", isMobile ? '(SWIPE \u2B95)' : '(TAB)'] }));
}

exports.$createAutocompleteNode = $createAutocompleteNode;
exports.AutocompleteNode = AutocompleteNode;
