'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var utils = require('@lexical/utils');
var lexical = require('lexical');
var React = require('react');
var reactErrorBoundary = require('react-error-boundary');
var EquationEditor = require('../ui/EquationEditor.js');
var KatexRenderer = require('../ui/KatexRenderer.js');
var EquationNode = require('./EquationNode.js');

function EquationComponent({ equation, inline, nodeKey, }) {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const [equationValue, setEquationValue] = React.useState(equation);
    const [showEquationEditor, setShowEquationEditor] = React.useState(false);
    const inputRef = React.useRef(null);
    const onHide = React.useCallback((restoreSelection) => {
        setShowEquationEditor(false);
        editor.update(() => {
            const node = lexical.$getNodeByKey(nodeKey);
            if (EquationNode.$isEquationNode(node)) {
                node.setEquation(equationValue);
                if (restoreSelection) {
                    node.selectNext(0, 0);
                }
            }
        });
    }, [editor, equationValue, nodeKey]);
    React.useEffect(() => {
        if (!showEquationEditor && equationValue !== equation) {
            setEquationValue(equation);
        }
    }, [showEquationEditor, equation, equationValue]);
    React.useEffect(() => {
        if (showEquationEditor) {
            return utils.mergeRegister(editor.registerCommand(lexical.SELECTION_CHANGE_COMMAND, (payload) => {
                const activeElement = document.activeElement;
                const inputElem = inputRef.current;
                if (inputElem !== activeElement) {
                    onHide();
                }
                return false;
            }, lexical.COMMAND_PRIORITY_HIGH), editor.registerCommand(lexical.KEY_ESCAPE_COMMAND, (payload) => {
                const activeElement = document.activeElement;
                const inputElem = inputRef.current;
                if (inputElem === activeElement) {
                    onHide(true);
                    return true;
                }
                return false;
            }, lexical.COMMAND_PRIORITY_HIGH));
        }
        else {
            return editor.registerUpdateListener(({ editorState }) => {
                const isSelected = editorState.read(() => {
                    const selection = lexical.$getSelection();
                    return (lexical.$isNodeSelection(selection) &&
                        selection.has(nodeKey) &&
                        selection.getNodes().length === 1);
                });
                if (isSelected) {
                    setShowEquationEditor(true);
                }
            });
        }
    }, [editor, nodeKey, onHide, showEquationEditor]);
    return (jsxRuntime.jsx(jsxRuntime.Fragment, { children: showEquationEditor ? (jsxRuntime.jsx(EquationEditor["default"], { equation: equationValue, setEquation: setEquationValue, inline: inline, ref: inputRef })) : (jsxRuntime.jsx(reactErrorBoundary.ErrorBoundary, { onError: (e) => editor._onError(e), fallback: null, children: jsxRuntime.jsx(KatexRenderer["default"], { equation: equationValue, inline: inline, onDoubleClick: () => setShowEquationEditor(true) }) })) }));
}

exports["default"] = EquationComponent;
