'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var katex = require('katex');
var lexical = require('lexical');
var React = require('react');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

function _interopNamespace(e) {
    if (e && e.__esModule) return e;
    var n = Object.create(null);
    if (e) {
        Object.keys(e).forEach(function (k) {
            if (k !== 'default') {
                var d = Object.getOwnPropertyDescriptor(e, k);
                Object.defineProperty(n, k, d.get ? d : {
                    enumerable: true,
                    get: function () { return e[k]; }
                });
            }
        });
    }
    n["default"] = e;
    return Object.freeze(n);
}

var katex__default = /*#__PURE__*/_interopDefaultLegacy(katex);
var React__namespace = /*#__PURE__*/_interopNamespace(React);

const EquationComponent = React__namespace.lazy(
// @ts-ignore
() => Promise.resolve().then(function () { return require('./EquationComponent.js'); }));
function convertEquationElement(domNode) {
    let equation = domNode.getAttribute('data-lexical-equation');
    const inline = domNode.getAttribute('data-lexical-inline') === 'true';
    // Decode the equation from base64
    equation = atob(equation || '');
    if (equation) {
        const node = $createEquationNode(equation, inline);
        return { node };
    }
    return null;
}
class EquationNode extends lexical.DecoratorNode {
    static getType() {
        return 'equation';
    }
    static clone(node) {
        return new EquationNode(node.__equation, node.__inline, node.__key);
    }
    constructor(equation, inline, key) {
        super(key);
        this.__equation = equation;
        this.__inline = inline !== null && inline !== void 0 ? inline : false;
    }
    static importJSON(serializedNode) {
        const node = $createEquationNode(serializedNode.equation, serializedNode.inline);
        return node;
    }
    exportJSON() {
        return {
            equation: this.getEquation(),
            inline: this.__inline,
            type: 'equation',
            version: 1,
        };
    }
    createDOM(_config) {
        const element = document.createElement(this.__inline ? 'span' : 'div');
        // EquationNodes should implement `user-action:none` in their CSS to avoid issues with deletion on Android.
        element.className = 'editor-equation';
        return element;
    }
    exportDOM() {
        const element = document.createElement(this.__inline ? 'span' : 'div');
        // Encode the equation as base64 to avoid issues with special characters
        const equation = btoa(this.__equation);
        element.setAttribute('data-lexical-equation', equation);
        element.setAttribute('data-lexical-inline', `${this.__inline}`);
        katex__default["default"].render(this.__equation, element, {
            displayMode: !this.__inline,
            errorColor: '#cc0000',
            output: 'html',
            strict: 'warn',
            throwOnError: false,
            trust: false,
        });
        return { element };
    }
    static importDOM() {
        return {
            div: (domNode) => {
                if (!domNode.hasAttribute('data-lexical-equation')) {
                    return null;
                }
                return {
                    conversion: convertEquationElement,
                    priority: 2,
                };
            },
            span: (domNode) => {
                if (!domNode.hasAttribute('data-lexical-equation')) {
                    return null;
                }
                return {
                    conversion: convertEquationElement,
                    priority: 1,
                };
            },
        };
    }
    updateDOM(prevNode) {
        // If the inline property changes, replace the element
        return this.__inline !== prevNode.__inline;
    }
    getTextContent() {
        return this.__equation;
    }
    getEquation() {
        return this.__equation;
    }
    setEquation(equation) {
        const writable = this.getWritable();
        writable.__equation = equation;
    }
    decorate() {
        return (jsxRuntime.jsx(React.Suspense, { fallback: null, children: jsxRuntime.jsx(EquationComponent, { equation: this.__equation, inline: this.__inline, nodeKey: this.__key }) }));
    }
}
function $createEquationNode(equation = '', inline = false) {
    const equationNode = new EquationNode(equation, inline);
    return lexical.$applyNodeReplacement(equationNode);
}
function $isEquationNode(node) {
    return node instanceof EquationNode;
}

exports.$createEquationNode = $createEquationNode;
exports.$isEquationNode = $isEquationNode;
exports.EquationNode = EquationNode;
