'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var useLexicalNodeSelection = require('@lexical/react/useLexicalNodeSelection');
var utils = require('@lexical/utils');
var lexical = require('lexical');
var React = require('react');
var ImageResizer = require('../../ui/ImageResizer.js');
var index = require('./index.js');
var ExcalidrawImage = require('./ExcalidrawImage.js');
var ExcalidrawModal = require('./ExcalidrawModal.js');

function ExcalidrawComponent({ nodeKey, data, }) {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const [isModalOpen, setModalOpen] = React.useState(data === '[]' && editor.isEditable());
    const imageContainerRef = React.useRef(null);
    const buttonRef = React.useRef(null);
    const captionButtonRef = React.useRef(null);
    const [isSelected, setSelected, clearSelection] = useLexicalNodeSelection.useLexicalNodeSelection(nodeKey);
    const [isResizing, setIsResizing] = React.useState(false);
    const onDelete = React.useCallback((event) => {
        if (isSelected && lexical.$isNodeSelection(lexical.$getSelection())) {
            event.preventDefault();
            editor.update(() => {
                const node = lexical.$getNodeByKey(nodeKey);
                if (index.$isExcalidrawNode(node)) {
                    node.remove();
                }
            });
        }
        return false;
    }, [editor, isSelected, nodeKey]);
    // Set editor to readOnly if excalidraw is open to prevent unwanted changes
    React.useEffect(() => {
        if (isModalOpen) {
            editor.setEditable(false);
        }
        else {
            editor.setEditable(true);
        }
    }, [isModalOpen, editor]);
    React.useEffect(() => {
        return utils.mergeRegister(editor.registerCommand(lexical.CLICK_COMMAND, (event) => {
            const buttonElem = buttonRef.current;
            const eventTarget = event.target;
            if (isResizing) {
                return true;
            }
            if (buttonElem !== null && buttonElem.contains(eventTarget)) {
                if (!event.shiftKey) {
                    clearSelection();
                }
                setSelected(!isSelected);
                if (event.detail > 1) {
                    setModalOpen(true);
                }
                return true;
            }
            return false;
        }, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.KEY_DELETE_COMMAND, onDelete, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.KEY_BACKSPACE_COMMAND, onDelete, lexical.COMMAND_PRIORITY_LOW));
    }, [clearSelection, editor, isSelected, isResizing, onDelete, setSelected]);
    const deleteNode = React.useCallback(() => {
        setModalOpen(false);
        return editor.update(() => {
            const node = lexical.$getNodeByKey(nodeKey);
            if (index.$isExcalidrawNode(node)) {
                node.remove();
            }
        });
    }, [editor, nodeKey]);
    const setData = (els, aps, fls) => {
        if (!editor.isEditable()) {
            return;
        }
        return editor.update(() => {
            const node = lexical.$getNodeByKey(nodeKey);
            if (index.$isExcalidrawNode(node)) {
                if (els.length > 0 || Object.keys(fls).length > 0) {
                    node.setData(JSON.stringify({
                        appState: aps,
                        elements: els,
                        files: fls,
                    }));
                }
                else {
                    node.remove();
                }
            }
        });
    };
    const onResizeStart = () => {
        setIsResizing(true);
    };
    const onResizeEnd = () => {
        // Delay hiding the resize bars for click case
        setTimeout(() => {
            setIsResizing(false);
        }, 200);
    };
    const openModal = React.useCallback(() => {
        setModalOpen(true);
    }, []);
    const { elements = [], files = {}, appState = {}, } = React.useMemo(() => JSON.parse(data), [data]);
    return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx(ExcalidrawModal["default"], { initialElements: elements, initialFiles: files, initialAppState: appState, isShown: isModalOpen, onDelete: deleteNode, onClose: () => setModalOpen(false), onSave: (els, aps, fls) => {
                    editor.setEditable(true);
                    setData(els, aps, fls);
                    setModalOpen(false);
                }, closeOnClickOutside: false }), elements.length > 0 && (jsxRuntime.jsxs("button", { ref: buttonRef, className: `excalidraw-button ${isSelected ? 'selected' : ''}`, children: [jsxRuntime.jsx(ExcalidrawImage["default"], { imageContainerRef: imageContainerRef, className: "image", elements: elements, files: files, appState: appState }), isSelected && (jsxRuntime.jsx("div", { className: "image-edit-button", role: "button", tabIndex: 0, onMouseDown: (event) => event.preventDefault(), onClick: openModal })), (isSelected || isResizing) && (jsxRuntime.jsx(ImageResizer["default"], { buttonRef: captionButtonRef, showCaption: true, setShowCaption: () => null, imageRef: imageContainerRef, editor: editor, onResizeStart: onResizeStart, onResizeEnd: onResizeEnd, captionsEnabled: true }))] }))] }));
}

exports["default"] = ExcalidrawComponent;
