'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
require('./ExcalidrawModal.css.js');
var excalidraw = require('@excalidraw/excalidraw');
var React = require('react');
var ReactDOM = require('react-dom');
var Button = require('../../ui/Button.js');
var Modal = require('../../ui/Modal.js');

/**
 * @explorer-desc
 * A component which renders a modal with Excalidraw (a painting app)
 * which can be used to export an editable image
 */
function ExcalidrawModal({ closeOnClickOutside = false, onSave, initialElements, initialAppState, initialFiles, isShown = false, onDelete, onClose, }) {
    const excaliDrawModelRef = React.useRef(null);
    const excaliDrawSceneRef = React.useRef(null);
    const [discardModalOpen, setDiscardModalOpen] = React.useState(false);
    const [elements, setElements] = React.useState(initialElements);
    const [files, setFiles] = React.useState(initialFiles);
    React.useEffect(() => {
        if (excaliDrawModelRef.current !== null) {
            excaliDrawModelRef.current.focus();
        }
    }, []);
    React.useEffect(() => {
        var _a;
        let modalOverlayElement = null;
        const clickOutsideHandler = (event) => {
            const target = event.target;
            if (excaliDrawModelRef.current !== null &&
                !excaliDrawModelRef.current.contains(target) &&
                closeOnClickOutside) {
                onDelete();
            }
        };
        if (excaliDrawModelRef.current !== null) {
            modalOverlayElement = (_a = excaliDrawModelRef.current) === null || _a === void 0 ? void 0 : _a.parentElement;
            if (modalOverlayElement !== null) {
                modalOverlayElement === null || modalOverlayElement === void 0 ? void 0 : modalOverlayElement.addEventListener('click', clickOutsideHandler);
            }
        }
        return () => {
            if (modalOverlayElement !== null) {
                modalOverlayElement === null || modalOverlayElement === void 0 ? void 0 : modalOverlayElement.removeEventListener('click', clickOutsideHandler);
            }
        };
    }, [closeOnClickOutside, onDelete]);
    React.useLayoutEffect(() => {
        const currentModalRef = excaliDrawModelRef.current;
        const onKeyDown = (event) => {
            if (event.key === 'Escape') {
                onDelete();
            }
        };
        if (currentModalRef !== null) {
            currentModalRef.addEventListener('keydown', onKeyDown);
        }
        return () => {
            if (currentModalRef !== null) {
                currentModalRef.removeEventListener('keydown', onKeyDown);
            }
        };
    }, [elements, files, onDelete]);
    const save = () => {
        var _a;
        if (elements.filter((el) => !el.isDeleted).length > 0) {
            const appState = (_a = excaliDrawSceneRef === null || excaliDrawSceneRef === void 0 ? void 0 : excaliDrawSceneRef.current) === null || _a === void 0 ? void 0 : _a.getAppState();
            if (appState) {
                // We only need a subset of the state
                const partialState = {
                    exportBackground: appState.exportBackground,
                    exportScale: appState.exportScale,
                    exportWithDarkMode: appState.theme === 'dark',
                    isBindingEnabled: appState.isBindingEnabled,
                    isLoading: appState.isLoading,
                    name: appState.name,
                    theme: appState.theme,
                    viewBackgroundColor: appState.viewBackgroundColor,
                    viewModeEnabled: appState.viewModeEnabled,
                    zenModeEnabled: appState.zenModeEnabled,
                    zoom: appState.zoom,
                };
                onSave(elements, partialState, files);
            }
        }
        else {
            // delete node if the scene is clear
            onDelete();
        }
    };
    const discard = () => {
        if (elements.filter((el) => !el.isDeleted).length === 0) {
            // delete node if the scene is clear
            onDelete();
        }
        else {
            //Otherwise, show confirmation dialog before closing
            setDiscardModalOpen(true);
        }
    };
    function ShowDiscardDialog() {
        return (jsxRuntime.jsxs(Modal["default"], { title: "Discard", onClose: () => {
                setDiscardModalOpen(false);
            }, closeOnClickOutside: false, children: ["Are you sure you want to discard the changes?", jsxRuntime.jsxs("div", { className: "ExcalidrawModal__discardModal", children: [jsxRuntime.jsx(Button["default"], { onClick: () => {
                                setDiscardModalOpen(false);
                                onClose();
                            }, children: "Discard" }), ' ', jsxRuntime.jsx(Button["default"], { onClick: () => {
                                setDiscardModalOpen(false);
                            }, children: "Cancel" })] })] }));
    }
    if (isShown === false) {
        return null;
    }
    const onChange = (els, _, fls) => {
        setElements(els);
        setFiles(fls);
    };
    // This is a hacky work-around for Excalidraw + Vite.
    // In DEV, Vite pulls this in fine, in prod it doesn't. It seems
    // like a module resolution issue with ESM vs CJS?
    const _Excalidraw = excalidraw.Excalidraw.$$typeof != null ? excalidraw.Excalidraw : excalidraw.Excalidraw.default;
    return ReactDOM.createPortal(jsxRuntime.jsx("div", { className: "ExcalidrawModal__overlay", role: "dialog", children: jsxRuntime.jsx("div", { className: "ExcalidrawModal__modal", ref: excaliDrawModelRef, tabIndex: -1, children: jsxRuntime.jsxs("div", { className: "ExcalidrawModal__row", children: [discardModalOpen && jsxRuntime.jsx(ShowDiscardDialog, {}), jsxRuntime.jsx(_Excalidraw, { onChange: onChange, ref: excaliDrawSceneRef, initialData: {
                            appState: initialAppState || { isLoading: false },
                            elements: initialElements,
                            files: initialFiles,
                        } }), jsxRuntime.jsxs("div", { className: "ExcalidrawModal__actions", children: [jsxRuntime.jsx("button", { className: "action-button", onClick: discard, children: "Discard" }), jsxRuntime.jsx("button", { className: "action-button", onClick: save, children: "Save" })] })] }) }) }), document.body);
}

exports["default"] = ExcalidrawModal;
