'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
require('./ImageNode.css.js');
var LexicalAutoFocusPlugin = require('@lexical/react/LexicalAutoFocusPlugin');
var LexicalCollaborationContext = require('@lexical/react/LexicalCollaborationContext');
var LexicalCollaborationPlugin = require('@lexical/react/LexicalCollaborationPlugin');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var LexicalErrorBoundary = require('@lexical/react/LexicalErrorBoundary');
var LexicalHashtagPlugin = require('@lexical/react/LexicalHashtagPlugin');
var LexicalHistoryPlugin = require('@lexical/react/LexicalHistoryPlugin');
var LexicalNestedComposer = require('@lexical/react/LexicalNestedComposer');
var LexicalRichTextPlugin = require('@lexical/react/LexicalRichTextPlugin');
var useLexicalNodeSelection = require('@lexical/react/useLexicalNodeSelection');
var utils = require('@lexical/utils');
var lexical = require('lexical');
var React = require('react');
var collaboration = require('../collaboration.js');
var SettingsContext = require('../context/SettingsContext.js');
var SharedHistoryContext = require('../context/SharedHistoryContext.js');
var index$2 = require('../plugins/EmojisPlugin/index.js');
var index$3 = require('../plugins/KeywordsPlugin/index.js');
var index$1 = require('../plugins/LinkPlugin/index.js');
var index = require('../plugins/MentionsPlugin/index.js');
var index$4 = require('../plugins/TreeViewPlugin/index.js');
var ContentEditable = require('../ui/ContentEditable.js');
var ImageResizer = require('../ui/ImageResizer.js');
var Placeholder = require('../ui/Placeholder.js');
var ImageNode = require('./ImageNode.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var LexicalErrorBoundary__default = /*#__PURE__*/_interopDefaultLegacy(LexicalErrorBoundary);

const imageCache = new Set();
function useSuspenseImage(src) {
    if (!imageCache.has(src)) {
        throw new Promise((resolve) => {
            const img = new Image();
            img.src = src;
            img.onload = () => {
                imageCache.add(src);
                resolve(null);
            };
        });
    }
}
function LazyImage({ altText, className, imageRef, src, width, height, maxWidth, }) {
    useSuspenseImage(src);
    return (jsxRuntime.jsx("img", { className: className || undefined, src: src, alt: altText, ref: imageRef, style: {
            height,
            maxWidth,
            width,
        }, draggable: "false" }));
}
function ImageComponent({ src, altText, nodeKey, width, height, maxWidth, resizable, showCaption, caption, captionsEnabled, }) {
    const imageRef = React.useRef(null);
    const buttonRef = React.useRef(null);
    const [isSelected, setSelected, clearSelection] = useLexicalNodeSelection.useLexicalNodeSelection(nodeKey);
    const [isResizing, setIsResizing] = React.useState(false);
    const { isCollabActive } = LexicalCollaborationContext.useCollaborationContext();
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const [selection, setSelection] = React.useState(null);
    const activeEditorRef = React.useRef(null);
    const onDelete = React.useCallback((payload) => {
        if (isSelected && lexical.$isNodeSelection(lexical.$getSelection())) {
            const event = payload;
            event.preventDefault();
            const node = lexical.$getNodeByKey(nodeKey);
            if (ImageNode.$isImageNode(node)) {
                node.remove();
            }
        }
        return false;
    }, [isSelected, nodeKey]);
    const onEnter = React.useCallback((event) => {
        const latestSelection = lexical.$getSelection();
        const buttonElem = buttonRef.current;
        if (isSelected &&
            lexical.$isNodeSelection(latestSelection) &&
            latestSelection.getNodes().length === 1) {
            if (showCaption) {
                // Move focus into nested editor
                lexical.$setSelection(null);
                event.preventDefault();
                caption.focus();
                return true;
            }
            else if (buttonElem !== null &&
                buttonElem !== document.activeElement) {
                event.preventDefault();
                buttonElem.focus();
                return true;
            }
        }
        return false;
    }, [caption, isSelected, showCaption]);
    const onEscape = React.useCallback((event) => {
        if (activeEditorRef.current === caption ||
            buttonRef.current === event.target) {
            lexical.$setSelection(null);
            editor.update(() => {
                setSelected(true);
                const parentRootElement = editor.getRootElement();
                if (parentRootElement !== null) {
                    parentRootElement.focus();
                }
            });
            return true;
        }
        return false;
    }, [caption, editor, setSelected]);
    React.useEffect(() => {
        let isMounted = true;
        const unregister = utils.mergeRegister(editor.registerUpdateListener(({ editorState }) => {
            if (isMounted) {
                setSelection(editorState.read(() => lexical.$getSelection()));
            }
        }), editor.registerCommand(lexical.SELECTION_CHANGE_COMMAND, (_, activeEditor) => {
            activeEditorRef.current = activeEditor;
            return false;
        }, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.CLICK_COMMAND, (payload) => {
            const event = payload;
            if (isResizing) {
                return true;
            }
            if (event.target === imageRef.current) {
                if (event.shiftKey) {
                    setSelected(!isSelected);
                }
                else {
                    clearSelection();
                    setSelected(true);
                }
                return true;
            }
            return false;
        }, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.DRAGSTART_COMMAND, (event) => {
            if (event.target === imageRef.current) {
                // TODO This is just a temporary workaround for FF to behave like other browsers.
                // Ideally, this handles drag & drop too (and all browsers).
                event.preventDefault();
                return true;
            }
            return false;
        }, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.KEY_DELETE_COMMAND, onDelete, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.KEY_BACKSPACE_COMMAND, onDelete, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.KEY_ENTER_COMMAND, onEnter, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.KEY_ESCAPE_COMMAND, onEscape, lexical.COMMAND_PRIORITY_LOW));
        return () => {
            isMounted = false;
            unregister();
        };
    }, [
        clearSelection,
        editor,
        isResizing,
        isSelected,
        nodeKey,
        onDelete,
        onEnter,
        onEscape,
        setSelected,
    ]);
    const setShowCaption = () => {
        editor.update(() => {
            const node = lexical.$getNodeByKey(nodeKey);
            if (ImageNode.$isImageNode(node)) {
                node.setShowCaption(true);
            }
        });
    };
    const onResizeEnd = (nextWidth, nextHeight) => {
        // Delay hiding the resize bars for click case
        setTimeout(() => {
            setIsResizing(false);
        }, 200);
        editor.update(() => {
            const node = lexical.$getNodeByKey(nodeKey);
            if (ImageNode.$isImageNode(node)) {
                node.setWidthAndHeight(nextWidth, nextHeight);
            }
        });
    };
    const onResizeStart = () => {
        setIsResizing(true);
    };
    const { historyState } = SharedHistoryContext.useSharedHistoryContext();
    const { settings: { showNestedEditorTreeView }, } = SettingsContext.useSettings();
    const draggable = isSelected && lexical.$isNodeSelection(selection) && !isResizing;
    const isFocused = isSelected || isResizing;
    return (jsxRuntime.jsx(React.Suspense, { fallback: null, children: jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx("div", { draggable: draggable, children: jsxRuntime.jsx(LazyImage, { className: isFocused
                            ? `focused ${lexical.$isNodeSelection(selection) ? 'draggable' : ''}`
                            : null, src: src, altText: altText, imageRef: imageRef, width: width, height: height, maxWidth: maxWidth }) }), showCaption && (jsxRuntime.jsx("div", { className: "image-caption-container", children: jsxRuntime.jsxs(LexicalNestedComposer.LexicalNestedComposer, { initialEditor: caption, children: [jsxRuntime.jsx(LexicalAutoFocusPlugin.AutoFocusPlugin, {}), jsxRuntime.jsx(index["default"], {}), jsxRuntime.jsx(index$1["default"], {}), jsxRuntime.jsx(index$2["default"], {}), jsxRuntime.jsx(LexicalHashtagPlugin.HashtagPlugin, {}), jsxRuntime.jsx(index$3["default"], {}), isCollabActive ? (jsxRuntime.jsx(LexicalCollaborationPlugin.CollaborationPlugin, { id: caption.getKey(), providerFactory: collaboration.createWebsocketProvider, shouldBootstrap: true })) : (jsxRuntime.jsx(LexicalHistoryPlugin.HistoryPlugin, { externalHistoryState: historyState })), jsxRuntime.jsx(LexicalRichTextPlugin.RichTextPlugin, { contentEditable: jsxRuntime.jsx(ContentEditable["default"], { className: "ImageNode__contentEditable" }), placeholder: jsxRuntime.jsx(Placeholder["default"], { className: "ImageNode__placeholder", children: "Enter a caption..." }), ErrorBoundary: LexicalErrorBoundary__default["default"] }), showNestedEditorTreeView === true ? jsxRuntime.jsx(index$4["default"], {}) : null] }) })), resizable && lexical.$isNodeSelection(selection) && isFocused && (jsxRuntime.jsx(ImageResizer["default"], { showCaption: showCaption, setShowCaption: setShowCaption, editor: editor, buttonRef: buttonRef, imageRef: imageRef, maxWidth: maxWidth, onResizeStart: onResizeStart, onResizeEnd: onResizeEnd, captionsEnabled: captionsEnabled }))] }) }));
}

exports["default"] = ImageComponent;
