'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
require('./InlineImageNode.css.js');
var LexicalAutoFocusPlugin = require('@lexical/react/LexicalAutoFocusPlugin');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var LexicalErrorBoundary = require('@lexical/react/LexicalErrorBoundary');
var LexicalNestedComposer = require('@lexical/react/LexicalNestedComposer');
var LexicalRichTextPlugin = require('@lexical/react/LexicalRichTextPlugin');
var useLexicalNodeSelection = require('@lexical/react/useLexicalNodeSelection');
var utils = require('@lexical/utils');
var lexical = require('lexical');
var React = require('react');
var useModal = require('../hooks/useModal.js');
var index$1 = require('../plugins/FloatingLinkEditorPlugin/index.js');
var index$2 = require('../plugins/FloatingTextFormatToolbarPlugin/index.js');
var index = require('../plugins/LinkPlugin/index.js');
var Button = require('../ui/Button.js');
var ContentEditable = require('../ui/ContentEditable.js');
var Dialog = require('../ui/Dialog.js');
var Placeholder = require('../ui/Placeholder.js');
var Select = require('../ui/Select.js');
var TextInput = require('../ui/TextInput.js');
var InlineImageNode = require('./InlineImageNode.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var LexicalErrorBoundary__default = /*#__PURE__*/_interopDefaultLegacy(LexicalErrorBoundary);

const imageCache = new Set();
function useSuspenseImage(src) {
    if (!imageCache.has(src)) {
        throw new Promise((resolve) => {
            const img = new Image();
            img.src = src;
            img.onload = () => {
                imageCache.add(src);
                resolve(null);
            };
        });
    }
}
function LazyImage({ altText, className, imageRef, src, width, height, position, }) {
    useSuspenseImage(src);
    return (jsxRuntime.jsx("img", { className: className || undefined, src: src, alt: altText, ref: imageRef, "data-position": position, style: {
            display: 'block',
            height,
            width,
        }, draggable: "false" }));
}
function UpdateInlineImageDialog({ activeEditor, nodeKey, onClose, }) {
    const editorState = activeEditor.getEditorState();
    const node = editorState.read(() => lexical.$getNodeByKey(nodeKey));
    const [altText, setAltText] = React.useState(node.getAltText());
    const [showCaption, setShowCaption] = React.useState(node.getShowCaption());
    const [position, setPosition] = React.useState(node.getPosition());
    const handleShowCaptionChange = (e) => {
        setShowCaption(e.target.checked);
    };
    const handlePositionChange = (e) => {
        setPosition(e.target.value);
    };
    const handleOnConfirm = () => {
        const payload = { altText, position, showCaption };
        if (node) {
            activeEditor.update(() => {
                node.update(payload);
            });
        }
        onClose();
    };
    return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx("div", { style: { marginBottom: '1em' }, children: jsxRuntime.jsx(TextInput["default"], { label: "Alt Text", placeholder: "Descriptive alternative text", onChange: setAltText, value: altText, "data-test-id": "image-modal-alt-text-input" }) }), jsxRuntime.jsxs(Select["default"], { style: { marginBottom: '1em', width: '208px' }, value: position, label: "Position", name: "position", id: "position-select", onChange: handlePositionChange, children: [jsxRuntime.jsx("option", { value: "left", children: "Left" }), jsxRuntime.jsx("option", { value: "right", children: "Right" }), jsxRuntime.jsx("option", { value: "full", children: "Full Width" })] }), jsxRuntime.jsxs("div", { className: "Input__wrapper", children: [jsxRuntime.jsx("input", { id: "caption", type: "checkbox", checked: showCaption, onChange: handleShowCaptionChange }), jsxRuntime.jsx("label", { htmlFor: "caption", children: "Show Caption" })] }), jsxRuntime.jsx(Dialog.DialogActions, { children: jsxRuntime.jsx(Button["default"], { "data-test-id": "image-modal-file-upload-btn", onClick: () => handleOnConfirm(), children: "Confirm" }) })] }));
}
function InlineImageComponent({ src, altText, nodeKey, width, height, showCaption, caption, position, }) {
    const [modal, showModal] = useModal["default"]();
    const imageRef = React.useRef(null);
    const buttonRef = React.useRef(null);
    const [isSelected, setSelected, clearSelection] = useLexicalNodeSelection.useLexicalNodeSelection(nodeKey);
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const [selection, setSelection] = React.useState(null);
    const activeEditorRef = React.useRef(null);
    const onDelete = React.useCallback((payload) => {
        if (isSelected && lexical.$isNodeSelection(lexical.$getSelection())) {
            const event = payload;
            event.preventDefault();
            const node = lexical.$getNodeByKey(nodeKey);
            if (InlineImageNode.$isInlineImageNode(node)) {
                node.remove();
            }
        }
        return false;
    }, [isSelected, nodeKey]);
    const onEnter = React.useCallback((event) => {
        const latestSelection = lexical.$getSelection();
        const buttonElem = buttonRef.current;
        if (isSelected &&
            lexical.$isNodeSelection(latestSelection) &&
            latestSelection.getNodes().length === 1) {
            if (showCaption) {
                // Move focus into nested editor
                lexical.$setSelection(null);
                event.preventDefault();
                caption.focus();
                return true;
            }
            else if (buttonElem !== null &&
                buttonElem !== document.activeElement) {
                event.preventDefault();
                buttonElem.focus();
                return true;
            }
        }
        return false;
    }, [caption, isSelected, showCaption]);
    const onEscape = React.useCallback((event) => {
        if (activeEditorRef.current === caption ||
            buttonRef.current === event.target) {
            lexical.$setSelection(null);
            editor.update(() => {
                setSelected(true);
                const parentRootElement = editor.getRootElement();
                if (parentRootElement !== null) {
                    parentRootElement.focus();
                }
            });
            return true;
        }
        return false;
    }, [caption, editor, setSelected]);
    React.useEffect(() => {
        let isMounted = true;
        const unregister = utils.mergeRegister(editor.registerUpdateListener(({ editorState }) => {
            if (isMounted) {
                setSelection(editorState.read(() => lexical.$getSelection()));
            }
        }), editor.registerCommand(lexical.SELECTION_CHANGE_COMMAND, (_, activeEditor) => {
            activeEditorRef.current = activeEditor;
            return false;
        }, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.CLICK_COMMAND, (payload) => {
            const event = payload;
            if (event.target === imageRef.current) {
                if (event.shiftKey) {
                    setSelected(!isSelected);
                }
                else {
                    clearSelection();
                    setSelected(true);
                }
                return true;
            }
            return false;
        }, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.DRAGSTART_COMMAND, (event) => {
            if (event.target === imageRef.current) {
                // TODO This is just a temporary workaround for FF to behave like other browsers.
                // Ideally, this handles drag & drop too (and all browsers).
                event.preventDefault();
                return true;
            }
            return false;
        }, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.KEY_DELETE_COMMAND, onDelete, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.KEY_BACKSPACE_COMMAND, onDelete, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.KEY_ENTER_COMMAND, onEnter, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.KEY_ESCAPE_COMMAND, onEscape, lexical.COMMAND_PRIORITY_LOW));
        return () => {
            isMounted = false;
            unregister();
        };
    }, [
        clearSelection,
        editor,
        isSelected,
        nodeKey,
        onDelete,
        onEnter,
        onEscape,
        setSelected,
    ]);
    const draggable = isSelected && lexical.$isNodeSelection(selection);
    const isFocused = isSelected;
    return (jsxRuntime.jsxs(React.Suspense, { fallback: null, children: [jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsxs("div", { draggable: draggable, children: [jsxRuntime.jsx("button", { className: "image-edit-button", ref: buttonRef, onClick: () => {
                                    showModal('Update Inline Image', (onClose) => (jsxRuntime.jsx(UpdateInlineImageDialog, { activeEditor: editor, nodeKey: nodeKey, onClose: onClose })));
                                }, children: "Edit" }), jsxRuntime.jsx(LazyImage, { className: isFocused
                                    ? `focused ${lexical.$isNodeSelection(selection) ? 'draggable' : ''}`
                                    : null, src: src, altText: altText, imageRef: imageRef, width: width, height: height, position: position })] }), showCaption && (jsxRuntime.jsx("div", { className: "image-caption-container", children: jsxRuntime.jsxs(LexicalNestedComposer.LexicalNestedComposer, { initialEditor: caption, children: [jsxRuntime.jsx(LexicalAutoFocusPlugin.AutoFocusPlugin, {}), jsxRuntime.jsx(index["default"], {}), jsxRuntime.jsx(index$1["default"], {}), jsxRuntime.jsx(index$2["default"], {}), jsxRuntime.jsx(LexicalRichTextPlugin.RichTextPlugin, { contentEditable: jsxRuntime.jsx(ContentEditable["default"], { className: "InlineImageNode__contentEditable" }), placeholder: jsxRuntime.jsx(Placeholder["default"], { className: "InlineImageNode__placeholder", children: "Enter a caption..." }), ErrorBoundary: LexicalErrorBoundary__default["default"] })] }) }))] }), modal] }));
}

exports.UpdateInlineImageDialog = UpdateInlineImageDialog;
exports["default"] = InlineImageComponent;
