'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
require('./index.css.js');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var useLexicalNodeSelection = require('@lexical/react/useLexicalNodeSelection');
var utils = require('@lexical/utils');
var lexical = require('lexical');
var React = require('react');

function PageBreakComponent({ nodeKey }) {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const [isSelected, setSelected, clearSelection] = useLexicalNodeSelection.useLexicalNodeSelection(nodeKey);
    const onDelete = React.useCallback((event) => {
        event.preventDefault();
        if (isSelected && lexical.$isNodeSelection(lexical.$getSelection())) {
            const node = lexical.$getNodeByKey(nodeKey);
            if ($isPageBreakNode(node)) {
                node.remove();
                return true;
            }
        }
        return false;
    }, [isSelected, nodeKey]);
    React.useEffect(() => {
        return utils.mergeRegister(editor.registerCommand(lexical.CLICK_COMMAND, (event) => {
            const pbElem = editor.getElementByKey(nodeKey);
            if (event.target === pbElem) {
                if (!event.shiftKey) {
                    clearSelection();
                }
                setSelected(!isSelected);
                return true;
            }
            return false;
        }, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.KEY_DELETE_COMMAND, onDelete, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.KEY_BACKSPACE_COMMAND, onDelete, lexical.COMMAND_PRIORITY_LOW));
    }, [clearSelection, editor, isSelected, nodeKey, onDelete, setSelected]);
    React.useEffect(() => {
        const pbElem = editor.getElementByKey(nodeKey);
        if (pbElem !== null) {
            pbElem.className = isSelected ? 'selected' : '';
        }
    }, [editor, isSelected, nodeKey]);
    return null;
}
class PageBreakNode extends lexical.DecoratorNode {
    static getType() {
        return 'page-break';
    }
    static clone(node) {
        return new PageBreakNode(node.__key);
    }
    static importJSON(serializedNode) {
        return $createPageBreakNode();
    }
    static importDOM() {
        return {
            figure: (domNode) => {
                const tp = domNode.getAttribute('type');
                if (tp !== this.getType())
                    return null;
                return {
                    conversion: convertPageBreakElement,
                    priority: lexical.COMMAND_PRIORITY_HIGH,
                };
            },
        };
    }
    exportJSON() {
        return {
            type: this.getType(),
            version: 1,
        };
    }
    createDOM() {
        const el = document.createElement('figure');
        el.style.pageBreakAfter = 'always';
        el.setAttribute('type', this.getType());
        return el;
    }
    getTextContent() {
        return '\n';
    }
    isInline() {
        return false;
    }
    updateDOM() {
        return false;
    }
    decorate() {
        return jsxRuntime.jsx(PageBreakComponent, { nodeKey: this.__key });
    }
}
function convertPageBreakElement() {
    return { node: $createPageBreakNode() };
}
function $createPageBreakNode() {
    return new PageBreakNode();
}
function $isPageBreakNode(node) {
    return node instanceof PageBreakNode;
}

exports.$createPageBreakNode = $createPageBreakNode;
exports.$isPageBreakNode = $isPageBreakNode;
exports.PageBreakNode = PageBreakNode;
