'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
require('./PollNode.css.js');
var LexicalCollaborationContext = require('@lexical/react/LexicalCollaborationContext');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var useLexicalNodeSelection = require('@lexical/react/useLexicalNodeSelection');
var utils = require('@lexical/utils');
var lexical = require('lexical');
var React = require('react');
var Button = require('../ui/Button.js');
var joinClasses = require('../utils/joinClasses.js');
var PollNode = require('./PollNode.js');

function getTotalVotes(options) {
    return options.reduce((totalVotes, next) => {
        return totalVotes + next.votes.length;
    }, 0);
}
function PollOptionComponent({ option, index, options, totalVotes, withPollNode, }) {
    const { clientID } = LexicalCollaborationContext.useCollaborationContext();
    const checkboxRef = React.useRef(null);
    const votesArray = option.votes;
    const checkedIndex = votesArray.indexOf(clientID);
    const checked = checkedIndex !== -1;
    const votes = votesArray.length;
    const text = option.text;
    return (jsxRuntime.jsxs("div", { className: "PollNode__optionContainer", children: [jsxRuntime.jsx("div", { className: joinClasses["default"]('PollNode__optionCheckboxWrapper', checked && 'PollNode__optionCheckboxChecked'), children: jsxRuntime.jsx("input", { ref: checkboxRef, className: "PollNode__optionCheckbox", type: "checkbox", onChange: (e) => {
                        withPollNode((node) => {
                            node.toggleVote(option, clientID);
                        });
                    }, checked: checked }) }), jsxRuntime.jsxs("div", { className: "PollNode__optionInputWrapper", children: [jsxRuntime.jsx("div", { className: "PollNode__optionInputVotes", style: { width: `${votes === 0 ? 0 : (votes / totalVotes) * 100}%` } }), jsxRuntime.jsx("span", { className: "PollNode__optionInputVotesCount", children: votes > 0 && (votes === 1 ? '1 vote' : `${votes} votes`) }), jsxRuntime.jsx("input", { className: "PollNode__optionInput", type: "text", value: text, onChange: (e) => {
                            const target = e.target;
                            const value = target.value;
                            const selectionStart = target.selectionStart;
                            const selectionEnd = target.selectionEnd;
                            withPollNode((node) => {
                                node.setOptionText(option, value);
                            }, () => {
                                target.selectionStart = selectionStart;
                                target.selectionEnd = selectionEnd;
                            });
                        }, placeholder: `Option ${index + 1}` })] }), jsxRuntime.jsx("button", { disabled: options.length < 3, className: joinClasses["default"]('PollNode__optionDelete', options.length < 3 && 'PollNode__optionDeleteDisabled'), "aria-label": "Remove", onClick: () => {
                    withPollNode((node) => {
                        node.deleteOption(option);
                    });
                } })] }));
}
function PollComponent({ question, options, nodeKey, }) {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const totalVotes = React.useMemo(() => getTotalVotes(options), [options]);
    const [isSelected, setSelected, clearSelection] = useLexicalNodeSelection.useLexicalNodeSelection(nodeKey);
    const [selection, setSelection] = React.useState(null);
    const ref = React.useRef(null);
    const onDelete = React.useCallback((payload) => {
        if (isSelected && lexical.$isNodeSelection(lexical.$getSelection())) {
            const event = payload;
            event.preventDefault();
            const node = lexical.$getNodeByKey(nodeKey);
            if (PollNode.$isPollNode(node)) {
                node.remove();
            }
        }
        return false;
    }, [isSelected, nodeKey]);
    React.useEffect(() => {
        return utils.mergeRegister(editor.registerUpdateListener(({ editorState }) => {
            setSelection(editorState.read(() => lexical.$getSelection()));
        }), editor.registerCommand(lexical.CLICK_COMMAND, (payload) => {
            const event = payload;
            if (event.target === ref.current) {
                if (!event.shiftKey) {
                    clearSelection();
                }
                setSelected(!isSelected);
                return true;
            }
            return false;
        }, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.KEY_DELETE_COMMAND, onDelete, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.KEY_BACKSPACE_COMMAND, onDelete, lexical.COMMAND_PRIORITY_LOW));
    }, [clearSelection, editor, isSelected, nodeKey, onDelete, setSelected]);
    const withPollNode = (cb, onUpdate) => {
        editor.update(() => {
            const node = lexical.$getNodeByKey(nodeKey);
            if (PollNode.$isPollNode(node)) {
                cb(node);
            }
        }, { onUpdate });
    };
    const addOption = () => {
        withPollNode((node) => {
            node.addOption(PollNode.createPollOption());
        });
    };
    const isFocused = lexical.$isNodeSelection(selection) && isSelected;
    return (jsxRuntime.jsx("div", { className: `PollNode__container ${isFocused ? 'focused' : ''}`, ref: ref, children: jsxRuntime.jsxs("div", { className: "PollNode__inner", children: [jsxRuntime.jsx("h2", { className: "PollNode__heading", children: question }), options.map((option, index) => {
                    const key = option.uid;
                    return (jsxRuntime.jsx(PollOptionComponent, { withPollNode: withPollNode, option: option, index: index, options: options, totalVotes: totalVotes }, key));
                }), jsxRuntime.jsx("div", { className: "PollNode__footer", children: jsxRuntime.jsx(Button["default"], { onClick: addOption, small: true, children: "Add Option" }) })] }) }));
}

exports["default"] = PollComponent;
