'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
require('./StickyNode.css.js');
var LexicalCollaborationContext = require('@lexical/react/LexicalCollaborationContext');
var LexicalCollaborationPlugin = require('@lexical/react/LexicalCollaborationPlugin');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var LexicalErrorBoundary = require('@lexical/react/LexicalErrorBoundary');
var LexicalHistoryPlugin = require('@lexical/react/LexicalHistoryPlugin');
var LexicalNestedComposer = require('@lexical/react/LexicalNestedComposer');
var LexicalPlainTextPlugin = require('@lexical/react/LexicalPlainTextPlugin');
var lexical = require('lexical');
var React = require('react');
var collaboration = require('../collaboration.js');
var SharedHistoryContext = require('../context/SharedHistoryContext.js');
var StickyEditorTheme = require('../themes/StickyEditorTheme.js');
var ContentEditable = require('../ui/ContentEditable.js');
var Placeholder = require('../ui/Placeholder.js');
var StickyNode = require('./StickyNode.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var LexicalErrorBoundary__default = /*#__PURE__*/_interopDefaultLegacy(LexicalErrorBoundary);

function positionSticky(stickyElem, positioning) {
    const style = stickyElem.style;
    const rootElementRect = positioning.rootElementRect;
    const rectLeft = rootElementRect !== null ? rootElementRect.left : 0;
    const rectTop = rootElementRect !== null ? rootElementRect.top : 0;
    style.top = rectTop + positioning.y + 'px';
    style.left = rectLeft + positioning.x + 'px';
}
function StickyComponent({ x, y, nodeKey, color, caption, }) {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const stickyContainerRef = React.useRef(null);
    const positioningRef = React.useRef({
        isDragging: false,
        offsetX: 0,
        offsetY: 0,
        rootElementRect: null,
        x: 0,
        y: 0,
    });
    const { isCollabActive } = LexicalCollaborationContext.useCollaborationContext();
    React.useEffect(() => {
        const position = positioningRef.current;
        position.x = x;
        position.y = y;
        const stickyContainer = stickyContainerRef.current;
        if (stickyContainer !== null) {
            positionSticky(stickyContainer, position);
        }
    }, [x, y]);
    React.useLayoutEffect(() => {
        const position = positioningRef.current;
        const resizeObserver = new ResizeObserver((entries) => {
            for (let i = 0; i < entries.length; i++) {
                const entry = entries[i];
                const { target } = entry;
                position.rootElementRect = target.getBoundingClientRect();
                const stickyContainer = stickyContainerRef.current;
                if (stickyContainer !== null) {
                    positionSticky(stickyContainer, position);
                }
            }
        });
        const removeRootListener = editor.registerRootListener((nextRootElem, prevRootElem) => {
            if (prevRootElem !== null) {
                resizeObserver.unobserve(prevRootElem);
            }
            if (nextRootElem !== null) {
                resizeObserver.observe(nextRootElem);
            }
        });
        const handleWindowResize = () => {
            const rootElement = editor.getRootElement();
            const stickyContainer = stickyContainerRef.current;
            if (rootElement !== null && stickyContainer !== null) {
                position.rootElementRect = rootElement.getBoundingClientRect();
                positionSticky(stickyContainer, position);
            }
        };
        window.addEventListener('resize', handleWindowResize);
        return () => {
            window.removeEventListener('resize', handleWindowResize);
            removeRootListener();
        };
    }, [editor]);
    React.useEffect(() => {
        const stickyContainer = stickyContainerRef.current;
        if (stickyContainer !== null) {
            // Delay adding transition so we don't trigger the
            // transition on load of the sticky.
            setTimeout(() => {
                stickyContainer.style.setProperty('transition', 'top 0.3s ease 0s, left 0.3s ease 0s');
            }, 500);
        }
    }, []);
    const handlePointerMove = (event) => {
        const stickyContainer = stickyContainerRef.current;
        const positioning = positioningRef.current;
        const rootElementRect = positioning.rootElementRect;
        if (stickyContainer !== null &&
            positioning.isDragging &&
            rootElementRect !== null) {
            positioning.x = event.pageX - positioning.offsetX - rootElementRect.left;
            positioning.y = event.pageY - positioning.offsetY - rootElementRect.top;
            positionSticky(stickyContainer, positioning);
        }
    };
    const handlePointerUp = (event) => {
        const stickyContainer = stickyContainerRef.current;
        const positioning = positioningRef.current;
        if (stickyContainer !== null) {
            positioning.isDragging = false;
            stickyContainer.classList.remove('dragging');
            editor.update(() => {
                const node = lexical.$getNodeByKey(nodeKey);
                if (StickyNode.$isStickyNode(node)) {
                    node.setPosition(positioning.x, positioning.y);
                }
            });
        }
        document.removeEventListener('pointermove', handlePointerMove);
        document.removeEventListener('pointerup', handlePointerUp);
    };
    const handleDelete = () => {
        editor.update(() => {
            const node = lexical.$getNodeByKey(nodeKey);
            if (StickyNode.$isStickyNode(node)) {
                node.remove();
            }
        });
    };
    const handleColorChange = () => {
        editor.update(() => {
            const node = lexical.$getNodeByKey(nodeKey);
            if (StickyNode.$isStickyNode(node)) {
                node.toggleColor();
            }
        });
    };
    const { historyState } = SharedHistoryContext.useSharedHistoryContext();
    return (jsxRuntime.jsx("div", { ref: stickyContainerRef, className: "sticky-note-container", children: jsxRuntime.jsxs("div", { className: `sticky-note ${color}`, onPointerDown: (event) => {
                const stickyContainer = stickyContainerRef.current;
                if (stickyContainer == null ||
                    event.button === 2 ||
                    event.target !== stickyContainer.firstChild) {
                    // Right click or click on editor should not work
                    return;
                }
                const stickContainer = stickyContainer;
                const positioning = positioningRef.current;
                if (stickContainer !== null) {
                    const { top, left } = stickContainer.getBoundingClientRect();
                    positioning.offsetX = event.clientX - left;
                    positioning.offsetY = event.clientY - top;
                    positioning.isDragging = true;
                    stickContainer.classList.add('dragging');
                    document.addEventListener('pointermove', handlePointerMove);
                    document.addEventListener('pointerup', handlePointerUp);
                    event.preventDefault();
                }
            }, children: [jsxRuntime.jsx("button", { onClick: handleDelete, className: "delete", "aria-label": "Delete sticky note", title: "Delete", children: "X" }), jsxRuntime.jsx("button", { onClick: handleColorChange, className: "color", "aria-label": "Change sticky note color", title: "Color", children: jsxRuntime.jsx("i", { className: "bucket" }) }), jsxRuntime.jsxs(LexicalNestedComposer.LexicalNestedComposer, { initialEditor: caption, initialTheme: StickyEditorTheme["default"], children: [isCollabActive ? (jsxRuntime.jsx(LexicalCollaborationPlugin.CollaborationPlugin, { id: caption.getKey(), providerFactory: collaboration.createWebsocketProvider, shouldBootstrap: true })) : (jsxRuntime.jsx(LexicalHistoryPlugin.HistoryPlugin, { externalHistoryState: historyState })), jsxRuntime.jsx(LexicalPlainTextPlugin.PlainTextPlugin, { contentEditable: jsxRuntime.jsx(ContentEditable["default"], { className: "StickyNode__contentEditable" }), placeholder: jsxRuntime.jsx(Placeholder["default"], { className: "StickyNode__placeholder", children: "What's up?" }), ErrorBoundary: LexicalErrorBoundary__default["default"] })] })] }) }));
}

exports["default"] = StickyComponent;
