'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var lexical = require('lexical');
var React = require('react');
var ReactDOM = require('react-dom');

function _interopNamespace(e) {
    if (e && e.__esModule) return e;
    var n = Object.create(null);
    if (e) {
        Object.keys(e).forEach(function (k) {
            if (k !== 'default') {
                var d = Object.getOwnPropertyDescriptor(e, k);
                Object.defineProperty(n, k, d.get ? d : {
                    enumerable: true,
                    get: function () { return e[k]; }
                });
            }
        });
    }
    n["default"] = e;
    return Object.freeze(n);
}

var React__namespace = /*#__PURE__*/_interopNamespace(React);

const StickyComponent = React__namespace.lazy(
// @ts-ignore
() => Promise.resolve().then(function () { return require('./StickyComponent.js'); }));
class StickyNode extends lexical.DecoratorNode {
    static getType() {
        return 'sticky';
    }
    static clone(node) {
        return new StickyNode(node.__x, node.__y, node.__color, node.__caption, node.__key);
    }
    static importJSON(serializedNode) {
        const stickyNode = new StickyNode(serializedNode.xOffset, serializedNode.yOffset, serializedNode.color);
        const caption = serializedNode.caption;
        const nestedEditor = stickyNode.__caption;
        const editorState = nestedEditor.parseEditorState(caption.editorState);
        if (!editorState.isEmpty()) {
            nestedEditor.setEditorState(editorState);
        }
        return stickyNode;
    }
    constructor(x, y, color, caption, key) {
        super(key);
        this.__x = x;
        this.__y = y;
        this.__caption = caption || lexical.createEditor();
        this.__color = color;
    }
    exportJSON() {
        return {
            caption: this.__caption.toJSON(),
            color: this.__color,
            type: 'sticky',
            version: 1,
            xOffset: this.__x,
            yOffset: this.__y,
        };
    }
    createDOM(config) {
        const div = document.createElement('div');
        div.style.display = 'contents';
        return div;
    }
    updateDOM() {
        return false;
    }
    setPosition(x, y) {
        const writable = this.getWritable();
        writable.__x = x;
        writable.__y = y;
        lexical.$setSelection(null);
    }
    toggleColor() {
        const writable = this.getWritable();
        writable.__color = writable.__color === 'pink' ? 'yellow' : 'pink';
    }
    decorate(editor, config) {
        return ReactDOM.createPortal(jsxRuntime.jsx(React.Suspense, { fallback: null, children: jsxRuntime.jsx(StickyComponent, { color: this.__color, x: this.__x, y: this.__y, nodeKey: this.getKey(), caption: this.__caption }) }), document.body);
    }
    isIsolated() {
        return true;
    }
}
function $isStickyNode(node) {
    return node instanceof StickyNode;
}
function $createStickyNode(xOffset, yOffset) {
    return new StickyNode(xOffset, yOffset, 'yellow');
}

exports.$createStickyNode = $createStickyNode;
exports.$isStickyNode = $isStickyNode;
exports.StickyNode = StickyNode;
