'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var tslib_es6 = require('../../node_modules/tslib/tslib.es6.js');
var jsxRuntime = require('react/jsx-runtime');
var LexicalBlockWithAlignableContents = require('@lexical/react/LexicalBlockWithAlignableContents');
var LexicalDecoratorBlockNode = require('@lexical/react/LexicalDecoratorBlockNode');
var React = require('react');

const WIDGET_SCRIPT_URL = 'https://platform.twitter.com/widgets.js';
function convertTweetElement(domNode) {
    const id = domNode.getAttribute('data-lexical-tweet-id');
    if (id) {
        const node = $createTweetNode(id);
        return { node };
    }
    return null;
}
let isTwitterScriptLoading = true;
function TweetComponent({ className, format, loadingComponent, nodeKey, onError, onLoad, tweetID, }) {
    const containerRef = React.useRef(null);
    const previousTweetIDRef = React.useRef('');
    const [isTweetLoading, setIsTweetLoading] = React.useState(false);
    const createTweet = React.useCallback(() => tslib_es6.__awaiter(this, void 0, void 0, function* () {
        try {
            // @ts-expect-error Twitter is attached to the window.
            yield window.twttr.widgets.createTweet(tweetID, containerRef.current);
            setIsTweetLoading(false);
            isTwitterScriptLoading = false;
            if (onLoad) {
                onLoad();
            }
        }
        catch (error) {
            if (onError) {
                onError(String(error));
            }
        }
    }), [onError, onLoad, tweetID]);
    React.useEffect(() => {
        var _a;
        if (tweetID !== previousTweetIDRef.current) {
            setIsTweetLoading(true);
            if (isTwitterScriptLoading) {
                const script = document.createElement('script');
                script.src = WIDGET_SCRIPT_URL;
                script.async = true;
                (_a = document.body) === null || _a === void 0 ? void 0 : _a.appendChild(script);
                script.onload = createTweet;
                if (onError) {
                    script.onerror = onError;
                }
            }
            else {
                createTweet();
            }
            if (previousTweetIDRef) {
                previousTweetIDRef.current = tweetID;
            }
        }
    }, [createTweet, onError, tweetID]);
    return (jsxRuntime.jsxs(LexicalBlockWithAlignableContents.BlockWithAlignableContents, { className: className, format: format, nodeKey: nodeKey, children: [isTweetLoading ? loadingComponent : null, jsxRuntime.jsx("div", { style: { display: 'inline-block', width: '550px' }, ref: containerRef })] }));
}
class TweetNode extends LexicalDecoratorBlockNode.DecoratorBlockNode {
    static getType() {
        return 'tweet';
    }
    static clone(node) {
        return new TweetNode(node.__id, node.__format, node.__key);
    }
    static importJSON(serializedNode) {
        const node = $createTweetNode(serializedNode.id);
        node.setFormat(serializedNode.format);
        return node;
    }
    exportJSON() {
        return Object.assign(Object.assign({}, super.exportJSON()), { id: this.getId(), type: 'tweet', version: 1 });
    }
    static importDOM() {
        return {
            div: (domNode) => {
                if (!domNode.hasAttribute('data-lexical-tweet-id')) {
                    return null;
                }
                return {
                    conversion: convertTweetElement,
                    priority: 2,
                };
            },
        };
    }
    exportDOM() {
        const element = document.createElement('div');
        element.setAttribute('data-lexical-tweet-id', this.__id);
        const text = document.createTextNode(this.getTextContent());
        element.append(text);
        return { element };
    }
    constructor(id, format, key) {
        super(format, key);
        this.__id = id;
    }
    getId() {
        return this.__id;
    }
    getTextContent(_includeInert, _includeDirectionless) {
        return `https://twitter.com/i/web/status/${this.__id}`;
    }
    decorate(editor, config) {
        const embedBlockTheme = config.theme.embedBlock || {};
        const className = {
            base: embedBlockTheme.base || '',
            focus: embedBlockTheme.focus || '',
        };
        return (jsxRuntime.jsx(TweetComponent, { className: className, format: this.__format, loadingComponent: "Loading...", nodeKey: this.getKey(), tweetID: this.__id }));
    }
}
function $createTweetNode(tweetID) {
    return new TweetNode(tweetID);
}
function $isTweetNode(node) {
    return node instanceof TweetNode;
}

exports.$createTweetNode = $createTweetNode;
exports.$isTweetNode = $isTweetNode;
exports.TweetNode = TweetNode;
