'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var tslib_es6 = require('../../../node_modules/tslib/tslib.es6.js');
var jsxRuntime = require('react/jsx-runtime');
var html = require('@lexical/html');
var code = require('@lexical/code');
var markdown = require('@lexical/markdown');
var LexicalCollaborationContext = require('@lexical/react/LexicalCollaborationContext');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var utils = require('@lexical/utils');
var yjs = require('@lexical/yjs');
var lexical = require('lexical');
var React = require('react');
var useModal = require('../../hooks/useModal.js');
require('../../ui/Button.css.js');
var index = require('../MarkdownTransformers/index.js');

function ActionsPlugin({ isRichText, onSaveCloud }) {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const [isEditable, setIsEditable] = React.useState(() => editor.isEditable());
    const [connected, setConnected] = React.useState(false);
    React.useState(true);
    const [modal, showModal] = useModal["default"]();
    const { isCollabActive } = LexicalCollaborationContext.useCollaborationContext();
    const saveCloud = (editor) => tslib_es6.__awaiter(this, void 0, void 0, function* () {
        editor.getEditorState().read(() => {
            const html$1 = html.$generateHtmlFromNodes(editor);
            const firstNode = lexical.$getRoot().getChildAtIndex(0);
            let header = '';
            if (firstNode && firstNode.__tag === 'h1') {
                header = firstNode.getTextContent();
            }
            onSaveCloud && onSaveCloud(html$1, header);
        });
    });
    React.useEffect(() => {
        return utils.mergeRegister(editor.registerEditableListener((editable) => {
            setIsEditable(editable);
        }), editor.registerCommand(yjs.CONNECTED_COMMAND, (payload) => {
            const isConnected = payload;
            setConnected(isConnected);
            return false;
        }, lexical.COMMAND_PRIORITY_EDITOR));
    }, [editor]);
    const handleMarkdownToggle = React.useCallback(() => {
        editor.update(() => {
            const root = lexical.$getRoot();
            const firstChild = root.getFirstChild();
            if (code.$isCodeNode(firstChild) && firstChild.getLanguage() === 'markdown') {
                markdown.$convertFromMarkdownString(firstChild.getTextContent(), index.PLAYGROUND_TRANSFORMERS);
            }
            else {
                const markdown$1 = markdown.$convertToMarkdownString(index.PLAYGROUND_TRANSFORMERS);
                root
                    .clear()
                    .append(code.$createCodeNode('markdown').append(lexical.$createTextNode(markdown$1)));
            }
            root.selectEnd();
        });
    }, [editor]);
    return (jsxRuntime.jsxs("div", { className: "actions", children: [jsxRuntime.jsx("button", { className: "action-button import", onClick: () => saveCloud(editor), title: "Save to cloud", "aria-label": "Import editor state from JSON", children: jsxRuntime.jsx("i", { className: "upload-cloud" }) }), jsxRuntime.jsx("button", { className: `action-button ${!isEditable ? 'unlock' : 'lock'}`, onClick: () => {
                    // Send latest editor state to commenting validation server
                    // if (isEditable) {
                    //   sendEditorState(editor);
                    // }
                    editor.setEditable(!editor.isEditable());
                }, title: "Read-Only Mode", "aria-label": `${!isEditable ? 'Unlock' : 'Lock'} read-only mode`, children: jsxRuntime.jsx("i", { className: !isEditable ? 'unlock' : 'lock' }) }), jsxRuntime.jsx("button", { className: "action-button", onClick: handleMarkdownToggle, title: "Convert From Markdown", "aria-label": "Convert from markdown", children: jsxRuntime.jsx("i", { className: "markdown" }) }), isCollabActive && (jsxRuntime.jsx("button", { className: "action-button connect", onClick: () => {
                    editor.dispatchCommand(yjs.TOGGLE_CONNECT_COMMAND, !connected);
                }, title: `${connected ? 'Disconnect' : 'Connect'} Collaborative Editing`, "aria-label": `${connected ? 'Disconnect from' : 'Connect to'} a collaborative editing server`, children: jsxRuntime.jsx("i", { className: connected ? 'disconnect' : 'connect' }) })), modal] }));
}

exports["default"] = ActionsPlugin;
