'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var tslib_es6 = require('../../../node_modules/tslib/tslib.es6.js');
var jsxRuntime = require('react/jsx-runtime');
var LexicalAutoEmbedPlugin = require('@lexical/react/LexicalAutoEmbedPlugin');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var React = require('react');
var ReactDOM = require('react-dom');
var useModal = require('../../hooks/useModal.js');
var Button = require('../../ui/Button.js');
var Dialog = require('../../ui/Dialog.js');
var index$2 = require('../FigmaPlugin/index.js');
var index$1 = require('../TwitterPlugin/index.js');
var index = require('../YouTubePlugin/index.js');

function _interopNamespace(e) {
    if (e && e.__esModule) return e;
    var n = Object.create(null);
    if (e) {
        Object.keys(e).forEach(function (k) {
            if (k !== 'default') {
                var d = Object.getOwnPropertyDescriptor(e, k);
                Object.defineProperty(n, k, d.get ? d : {
                    enumerable: true,
                    get: function () { return e[k]; }
                });
            }
        });
    }
    n["default"] = e;
    return Object.freeze(n);
}

var ReactDOM__namespace = /*#__PURE__*/_interopNamespace(ReactDOM);

const YoutubeEmbedConfig = {
    contentName: 'Youtube Video',
    exampleUrl: 'https://www.youtube.com/watch?v=jNQXAC9IVRw',
    // Icon for display.
    icon: jsxRuntime.jsx("i", { className: "icon youtube" }),
    insertNode: (editor, result) => {
        editor.dispatchCommand(index.INSERT_YOUTUBE_COMMAND, result.id);
    },
    keywords: ['youtube', 'video'],
    // Determine if a given URL is a match and return url data.
    parseUrl: (url) => tslib_es6.__awaiter(void 0, void 0, void 0, function* () {
        const match = /^.*(youtu\.be\/|v\/|u\/\w\/|embed\/|watch\?v=|&v=)([^#&?]*).*/.exec(url);
        const id = match ? ((match === null || match === void 0 ? void 0 : match[2].length) === 11 ? match[2] : null) : null;
        if (id != null) {
            return {
                id,
                url,
            };
        }
        return null;
    }),
    type: 'youtube-video',
};
const TwitterEmbedConfig = {
    // e.g. Tweet or Google Map.
    contentName: 'Tweet',
    exampleUrl: 'https://twitter.com/jack/status/20',
    // Icon for display.
    icon: jsxRuntime.jsx("i", { className: "icon tweet" }),
    // Create the Lexical embed node from the url data.
    insertNode: (editor, result) => {
        editor.dispatchCommand(index$1.INSERT_TWEET_COMMAND, result.id);
    },
    // For extra searching.
    keywords: ['tweet', 'twitter'],
    // Determine if a given URL is a match and return url data.
    parseUrl: (text) => {
        const match = /^https:\/\/twitter\.com\/(#!\/)?(\w+)\/status(es)*\/(\d+)$/.exec(text);
        if (match != null) {
            return {
                id: match[4],
                url: match[0],
            };
        }
        return null;
    },
    type: 'tweet',
};
const FigmaEmbedConfig = {
    contentName: 'Figma Document',
    exampleUrl: 'https://www.figma.com/file/LKQ4FJ4bTnCSjedbRpk931/Sample-File',
    icon: jsxRuntime.jsx("i", { className: "icon figma" }),
    insertNode: (editor, result) => {
        editor.dispatchCommand(index$2.INSERT_FIGMA_COMMAND, result.id);
    },
    keywords: ['figma', 'figma.com', 'mock-up'],
    // Determine if a given URL is a match and return url data.
    parseUrl: (text) => {
        const match = /https:\/\/([\w.-]+\.)?figma.com\/(file|proto)\/([0-9a-zA-Z]{22,128})(?:\/.*)?$/.exec(text);
        if (match != null) {
            return {
                id: match[3],
                url: match[0],
            };
        }
        return null;
    },
    type: 'figma',
};
const EmbedConfigs = [
    TwitterEmbedConfig,
    YoutubeEmbedConfig,
    FigmaEmbedConfig,
];
function AutoEmbedMenuItem({ index, isSelected, onClick, onMouseEnter, option, }) {
    let className = 'item';
    if (isSelected) {
        className += ' selected';
    }
    return (jsxRuntime.jsx("li", { tabIndex: -1, className: className, ref: option.setRefElement, role: "option", "aria-selected": isSelected, id: 'typeahead-item-' + index, onMouseEnter: onMouseEnter, onClick: onClick, children: jsxRuntime.jsx("span", { className: "text", children: option.title }) }, option.key));
}
function AutoEmbedMenu({ options, selectedItemIndex, onOptionClick, onOptionMouseEnter, }) {
    return (jsxRuntime.jsx("div", { className: "typeahead-popover", children: jsxRuntime.jsx("ul", { children: options.map((option, i) => (jsxRuntime.jsx(AutoEmbedMenuItem, { index: i, isSelected: selectedItemIndex === i, onClick: () => onOptionClick(option, i), onMouseEnter: () => onOptionMouseEnter(i), option: option }, option.key))) }) }));
}
const debounce = (callback, delay) => {
    let timeoutId;
    return (text) => {
        window.clearTimeout(timeoutId);
        timeoutId = window.setTimeout(() => {
            callback(text);
        }, delay);
    };
};
function AutoEmbedDialog({ embedConfig, onClose, }) {
    const [text, setText] = React.useState('');
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const [embedResult, setEmbedResult] = React.useState(null);
    const validateText = React.useMemo(() => debounce((inputText) => {
        const urlMatch = LexicalAutoEmbedPlugin.URL_MATCHER.exec(inputText);
        if (embedConfig != null && inputText != null && urlMatch != null) {
            Promise.resolve(embedConfig.parseUrl(inputText)).then((parseResult) => {
                setEmbedResult(parseResult);
            });
        }
        else if (embedResult != null) {
            setEmbedResult(null);
        }
    }, 200), [embedConfig, embedResult]);
    const onClick = () => {
        if (embedResult != null) {
            embedConfig.insertNode(editor, embedResult);
            onClose();
        }
    };
    return (jsxRuntime.jsxs("div", { style: { width: '600px' }, children: [jsxRuntime.jsx("div", { className: "Input__wrapper", children: jsxRuntime.jsx("input", { type: "text", className: "Input__input", placeholder: embedConfig.exampleUrl, value: text, "data-test-id": `${embedConfig.type}-embed-modal-url`, onChange: (e) => {
                        const { value } = e.target;
                        setText(value);
                        validateText(value);
                    } }) }), jsxRuntime.jsx(Dialog.DialogActions, { children: jsxRuntime.jsx(Button["default"], { disabled: !embedResult, onClick: onClick, "data-test-id": `${embedConfig.type}-embed-modal-submit-btn`, children: "Embed" }) })] }));
}
function AutoEmbedPlugin() {
    const [modal, showModal] = useModal["default"]();
    const openEmbedModal = (embedConfig) => {
        showModal(`Embed ${embedConfig.contentName}`, (onClose) => (jsxRuntime.jsx(AutoEmbedDialog, { embedConfig: embedConfig, onClose: onClose })));
    };
    const getMenuOptions = (activeEmbedConfig, embedFn, dismissFn) => {
        return [
            new LexicalAutoEmbedPlugin.AutoEmbedOption('Dismiss', {
                onSelect: dismissFn,
            }),
            new LexicalAutoEmbedPlugin.AutoEmbedOption(`Embed ${activeEmbedConfig.contentName}`, {
                onSelect: embedFn,
            }),
        ];
    };
    return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [modal, jsxRuntime.jsx(LexicalAutoEmbedPlugin.LexicalAutoEmbedPlugin, { embedConfigs: EmbedConfigs, onOpenEmbedModalForConfig: openEmbedModal, getMenuOptions: getMenuOptions, menuRenderFn: (anchorElementRef, { selectedIndex, options, selectOptionAndCleanUp, setHighlightedIndex }) => anchorElementRef.current
                    ? ReactDOM__namespace.createPortal(jsxRuntime.jsx("div", { className: "typeahead-popover auto-embed-menu", style: {
                            marginLeft: anchorElementRef.current.style.width,
                            width: 200,
                        }, children: jsxRuntime.jsx(AutoEmbedMenu, { options: options, selectedItemIndex: selectedIndex, onOptionClick: (option, index) => {
                                setHighlightedIndex(index);
                                selectOptionAndCleanUp(option);
                            }, onOptionMouseEnter: (index) => {
                                setHighlightedIndex(index);
                            } }) }), anchorElementRef.current)
                    : null })] }));
}

exports.AutoEmbedDialog = AutoEmbedDialog;
exports.EmbedConfigs = EmbedConfigs;
exports.FigmaEmbedConfig = FigmaEmbedConfig;
exports.TwitterEmbedConfig = TwitterEmbedConfig;
exports.YoutubeEmbedConfig = YoutubeEmbedConfig;
exports["default"] = AutoEmbedPlugin;
