'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var tslib_es6 = require('../../../../../node_modules/tslib/tslib.es6.js');
var jsxRuntime = require('react/jsx-runtime');
require('./index.css.js');
var code = require('@lexical/code');
var lexical = require('lexical');
var React = require('react');

function _interopNamespace(e) {
    if (e && e.__esModule) return e;
    var n = Object.create(null);
    if (e) {
        Object.keys(e).forEach(function (k) {
            if (k !== 'default') {
                var d = Object.getOwnPropertyDescriptor(e, k);
                Object.defineProperty(n, k, d.get ? d : {
                    enumerable: true,
                    get: function () { return e[k]; }
                });
            }
        });
    }
    n["default"] = e;
    return Object.freeze(n);
}

const PRETTIER_PARSER_MODULES = {
    css: () => Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require('prettier/parser-postcss')); }),
    html: () => Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require('prettier/parser-html')); }),
    js: () => Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require('prettier/parser-babel')); }),
    markdown: () => Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require('prettier/parser-markdown')); }),
};
function loadPrettierParserByLang(lang) {
    return tslib_es6.__awaiter(this, void 0, void 0, function* () {
        const dynamicImport = PRETTIER_PARSER_MODULES[lang];
        return yield dynamicImport();
    });
}
function loadPrettierFormat() {
    return tslib_es6.__awaiter(this, void 0, void 0, function* () {
        const { format } = yield Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require('prettier/standalone')); });
        return format;
    });
}
const PRETTIER_OPTIONS_BY_LANG = {
    css: {
        parser: 'css',
    },
    html: {
        parser: 'html',
    },
    js: {
        parser: 'babel',
    },
    markdown: {
        parser: 'markdown',
    },
};
const LANG_CAN_BE_PRETTIER = Object.keys(PRETTIER_OPTIONS_BY_LANG);
function canBePrettier(lang) {
    return LANG_CAN_BE_PRETTIER.includes(lang);
}
function getPrettierOptions(lang) {
    const options = PRETTIER_OPTIONS_BY_LANG[lang];
    if (!options) {
        throw new Error(`CodeActionMenuPlugin: Prettier does not support this language: ${lang}`);
    }
    return options;
}
function PrettierButton({ lang, editor, getCodeDOMNode }) {
    const [syntaxError, setSyntaxError] = React.useState('');
    const [tipsVisible, setTipsVisible] = React.useState(false);
    function handleClick() {
        return tslib_es6.__awaiter(this, void 0, void 0, function* () {
            const codeDOMNode = getCodeDOMNode();
            try {
                const format = yield loadPrettierFormat();
                const options = getPrettierOptions(lang);
                options.plugins = [yield loadPrettierParserByLang(lang)];
                if (!codeDOMNode) {
                    return;
                }
                editor.update(() => {
                    const codeNode = lexical.$getNearestNodeFromDOMNode(codeDOMNode);
                    if (code.$isCodeNode(codeNode)) {
                        const content = codeNode.getTextContent();
                        let parsed = '';
                        try {
                            parsed = format(content, options);
                        }
                        catch (error) {
                            setError(error);
                        }
                        if (parsed !== '') {
                            const selection = codeNode.select(0);
                            selection.insertText(parsed);
                            setSyntaxError('');
                            setTipsVisible(false);
                        }
                    }
                });
            }
            catch (error) {
                setError(error);
            }
        });
    }
    function setError(error) {
        if (error instanceof Error) {
            setSyntaxError(error.message);
            setTipsVisible(true);
        }
        else {
            console.error('Unexpected error: ', error);
        }
    }
    function handleMouseEnter() {
        if (syntaxError !== '') {
            setTipsVisible(true);
        }
    }
    function handleMouseLeave() {
        if (syntaxError !== '') {
            setTipsVisible(false);
        }
    }
    return (jsxRuntime.jsxs("div", { className: "prettier-wrapper", children: [jsxRuntime.jsx("button", { className: "menu-item", onClick: handleClick, onMouseEnter: handleMouseEnter, onMouseLeave: handleMouseLeave, "aria-label": "prettier", children: syntaxError ? (jsxRuntime.jsx("i", { className: "format prettier-error" })) : (jsxRuntime.jsx("i", { className: "format prettier" })) }), tipsVisible ? (jsxRuntime.jsx("pre", { className: "code-error-tips", children: syntaxError })) : null] }));
}

exports.PrettierButton = PrettierButton;
exports.canBePrettier = canBePrettier;
