'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
require('./index.css.js');
var code = require('@lexical/code');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var lexical = require('lexical');
var React = require('react');
var ReactDOM = require('react-dom');
var index = require('./components/CopyButton/index.js');
var index$1 = require('./components/PrettierButton/index.js');
var utils = require('./utils.js');

const CODE_PADDING = 8;
function CodeActionMenuContainer({ anchorElem, }) {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const [lang, setLang] = React.useState('');
    const [isShown, setShown] = React.useState(false);
    const [shouldListenMouseMove, setShouldListenMouseMove] = React.useState(false);
    const [position, setPosition] = React.useState({
        right: '0',
        top: '0',
    });
    const codeSetRef = React.useRef(new Set());
    const codeDOMNodeRef = React.useRef(null);
    function getCodeDOMNode() {
        return codeDOMNodeRef.current;
    }
    const debouncedOnMouseMove = utils.useDebounce((event) => {
        const { codeDOMNode, isOutside } = getMouseInfo(event);
        if (isOutside) {
            setShown(false);
            return;
        }
        if (!codeDOMNode) {
            return;
        }
        codeDOMNodeRef.current = codeDOMNode;
        let codeNode = null;
        let _lang = '';
        editor.update(() => {
            const maybeCodeNode = lexical.$getNearestNodeFromDOMNode(codeDOMNode);
            if (code.$isCodeNode(maybeCodeNode)) {
                codeNode = maybeCodeNode;
                _lang = codeNode.getLanguage() || '';
            }
        });
        if (codeNode) {
            const { y: editorElemY, right: editorElemRight } = anchorElem.getBoundingClientRect();
            const { y, right } = codeDOMNode.getBoundingClientRect();
            setLang(_lang);
            setShown(true);
            setPosition({
                right: `${editorElemRight - right + CODE_PADDING}px`,
                top: `${y - editorElemY}px`,
            });
        }
    }, 50, 1000);
    React.useEffect(() => {
        if (!shouldListenMouseMove) {
            return;
        }
        document.addEventListener('mousemove', debouncedOnMouseMove);
        return () => {
            setShown(false);
            debouncedOnMouseMove.cancel();
            document.removeEventListener('mousemove', debouncedOnMouseMove);
        };
    }, [shouldListenMouseMove, debouncedOnMouseMove]);
    editor.registerMutationListener(code.CodeNode, (mutations) => {
        editor.getEditorState().read(() => {
            for (const [key, type] of mutations) {
                switch (type) {
                    case 'created':
                        codeSetRef.current.add(key);
                        setShouldListenMouseMove(codeSetRef.current.size > 0);
                        break;
                    case 'destroyed':
                        codeSetRef.current.delete(key);
                        setShouldListenMouseMove(codeSetRef.current.size > 0);
                        break;
                }
            }
        });
    });
    const normalizedLang = code.normalizeCodeLang(lang);
    const codeFriendlyName = code.getLanguageFriendlyName(lang);
    return (jsxRuntime.jsx(jsxRuntime.Fragment, { children: isShown ? (jsxRuntime.jsxs("div", { className: "code-action-menu-container", style: Object.assign({}, position), children: [jsxRuntime.jsx("div", { className: "code-highlight-language", children: codeFriendlyName }), jsxRuntime.jsx(index.CopyButton, { editor: editor, getCodeDOMNode: getCodeDOMNode }), index$1.canBePrettier(normalizedLang) ? (jsxRuntime.jsx(index$1.PrettierButton, { editor: editor, getCodeDOMNode: getCodeDOMNode, lang: normalizedLang })) : null] })) : null }));
}
function getMouseInfo(event) {
    const target = event.target;
    if (target && target instanceof HTMLElement) {
        const codeDOMNode = target.closest('code.PlaygroundEditorTheme__code');
        const isOutside = !(codeDOMNode ||
            target.closest('div.code-action-menu-container'));
        return { codeDOMNode, isOutside };
    }
    else {
        return { codeDOMNode: null, isOutside: true };
    }
}
function CodeActionMenuPlugin({ anchorElem = document.body, }) {
    return ReactDOM.createPortal(jsxRuntime.jsx(CodeActionMenuContainer, { anchorElem: anchorElem }), anchorElem);
}

exports["default"] = CodeActionMenuPlugin;
