'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var lexical = require('lexical');

/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */
function convertCollapsibleContentElement(domNode) {
    const node = $createCollapsibleContentNode();
    return {
        node,
    };
}
class CollapsibleContentNode extends lexical.ElementNode {
    static getType() {
        return 'collapsible-content';
    }
    static clone(node) {
        return new CollapsibleContentNode(node.__key);
    }
    createDOM(config) {
        const dom = document.createElement('div');
        dom.classList.add('Collapsible__content');
        return dom;
    }
    updateDOM(prevNode, dom) {
        return false;
    }
    static importDOM() {
        return {
            div: (domNode) => {
                if (!domNode.hasAttribute('data-lexical-collapsible-content')) {
                    return null;
                }
                return {
                    conversion: convertCollapsibleContentElement,
                    priority: 2,
                };
            },
        };
    }
    exportDOM() {
        const element = document.createElement('div');
        element.setAttribute('data-lexical-collapsible-content', 'true');
        return { element };
    }
    static importJSON(serializedNode) {
        return $createCollapsibleContentNode();
    }
    isShadowRoot() {
        return true;
    }
    exportJSON() {
        return Object.assign(Object.assign({}, super.exportJSON()), { type: 'collapsible-content', version: 1 });
    }
}
function $createCollapsibleContentNode() {
    return new CollapsibleContentNode();
}
function $isCollapsibleContentNode(node) {
    return node instanceof CollapsibleContentNode;
}

exports.$createCollapsibleContentNode = $createCollapsibleContentNode;
exports.$isCollapsibleContentNode = $isCollapsibleContentNode;
exports.CollapsibleContentNode = CollapsibleContentNode;
exports.convertCollapsibleContentElement = convertCollapsibleContentElement;
