'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var lexical = require('lexical');
var CollapsibleContainerNode = require('./CollapsibleContainerNode.js');
var CollapsibleContentNode = require('./CollapsibleContentNode.js');

/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */
function convertSummaryElement(domNode) {
    const node = $createCollapsibleTitleNode();
    return {
        node,
    };
}
class CollapsibleTitleNode extends lexical.ElementNode {
    static getType() {
        return 'collapsible-title';
    }
    static clone(node) {
        return new CollapsibleTitleNode(node.__key);
    }
    createDOM(config, editor) {
        const dom = document.createElement('summary');
        dom.classList.add('Collapsible__title');
        return dom;
    }
    updateDOM(prevNode, dom) {
        return false;
    }
    static importDOM() {
        return {
            summary: (domNode) => {
                return {
                    conversion: convertSummaryElement,
                    priority: 1,
                };
            },
        };
    }
    static importJSON(serializedNode) {
        return $createCollapsibleTitleNode();
    }
    exportDOM() {
        const element = document.createElement('summary');
        return { element };
    }
    exportJSON() {
        return Object.assign(Object.assign({}, super.exportJSON()), { type: 'collapsible-title', version: 1 });
    }
    collapseAtStart(_selection) {
        this.getParentOrThrow().insertBefore(this);
        return true;
    }
    insertNewAfter(_, restoreSelection = true) {
        const containerNode = this.getParentOrThrow();
        if (!CollapsibleContainerNode.$isCollapsibleContainerNode(containerNode)) {
            throw new Error('CollapsibleTitleNode expects to be child of CollapsibleContainerNode');
        }
        if (containerNode.getOpen()) {
            const contentNode = this.getNextSibling();
            if (!CollapsibleContentNode.$isCollapsibleContentNode(contentNode)) {
                throw new Error('CollapsibleTitleNode expects to have CollapsibleContentNode sibling');
            }
            const firstChild = contentNode.getFirstChild();
            if (lexical.$isElementNode(firstChild)) {
                return firstChild;
            }
            else {
                const paragraph = lexical.$createParagraphNode();
                contentNode.append(paragraph);
                return paragraph;
            }
        }
        else {
            const paragraph = lexical.$createParagraphNode();
            containerNode.insertAfter(paragraph, restoreSelection);
            return paragraph;
        }
    }
}
function $createCollapsibleTitleNode() {
    return new CollapsibleTitleNode();
}
function $isCollapsibleTitleNode(node) {
    return node instanceof CollapsibleTitleNode;
}

exports.$createCollapsibleTitleNode = $createCollapsibleTitleNode;
exports.$isCollapsibleTitleNode = $isCollapsibleTitleNode;
exports.CollapsibleTitleNode = CollapsibleTitleNode;
exports.convertSummaryElement = convertSummaryElement;
