'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var code = require('@lexical/code');
var list = require('@lexical/list');
var LexicalAutoEmbedPlugin = require('@lexical/react/LexicalAutoEmbedPlugin');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var LexicalHorizontalRuleNode = require('@lexical/react/LexicalHorizontalRuleNode');
var LexicalTypeaheadMenuPlugin = require('@lexical/react/LexicalTypeaheadMenuPlugin');
var richText = require('@lexical/rich-text');
var selection = require('@lexical/selection');
var table = require('@lexical/table');
var lexical = require('lexical');
var React = require('react');
var ReactDOM = require('react-dom');
var useModal = require('../../hooks/useModal.js');
var index$3 = require('../AutoEmbedPlugin/index.js');
var index$6 = require('../CollapsiblePlugin/index.js');
var index$4 = require('../EquationsPlugin/index.js');
var index$1 = require('../ExcalidrawPlugin/index.js');
var index$5 = require('../ImagesPlugin/index.js');
var index = require('../PageBreakPlugin/index.js');
var index$2 = require('../PollPlugin/index.js');
var TablePlugin = require('../TablePlugin.js');

function _interopNamespace(e) {
    if (e && e.__esModule) return e;
    var n = Object.create(null);
    if (e) {
        Object.keys(e).forEach(function (k) {
            if (k !== 'default') {
                var d = Object.getOwnPropertyDescriptor(e, k);
                Object.defineProperty(n, k, d.get ? d : {
                    enumerable: true,
                    get: function () { return e[k]; }
                });
            }
        });
    }
    n["default"] = e;
    return Object.freeze(n);
}

var ReactDOM__namespace = /*#__PURE__*/_interopNamespace(ReactDOM);

class ComponentPickerOption extends LexicalTypeaheadMenuPlugin.MenuOption {
    constructor(title, options) {
        super(title);
        this.title = title;
        this.keywords = options.keywords || [];
        this.icon = options.icon;
        this.keyboardShortcut = options.keyboardShortcut;
        this.onSelect = options.onSelect.bind(this);
    }
}
function ComponentPickerMenuItem({ index, isSelected, onClick, onMouseEnter, option, }) {
    let className = 'item';
    if (isSelected) {
        className += ' selected';
    }
    return (jsxRuntime.jsxs("li", { tabIndex: -1, className: className, ref: option.setRefElement, role: "option", "aria-selected": isSelected, id: 'typeahead-item-' + index, onMouseEnter: onMouseEnter, onClick: onClick, children: [option.icon, jsxRuntime.jsx("span", { className: "text", children: option.title })] }, option.key));
}
function ComponentPickerMenuPlugin() {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const [modal, showModal] = useModal["default"]();
    const [queryString, setQueryString] = React.useState(null);
    const checkForTriggerMatch = LexicalTypeaheadMenuPlugin.useBasicTypeaheadTriggerMatch('/', {
        minLength: 0,
    });
    const getDynamicOptions = React.useCallback(() => {
        const options = [];
        if (queryString == null) {
            return options;
        }
        const fullTableRegex = new RegExp(/^([1-9]|10)x([1-9]|10)$/);
        const partialTableRegex = new RegExp(/^([1-9]|10)x?$/);
        const fullTableMatch = fullTableRegex.exec(queryString);
        const partialTableMatch = partialTableRegex.exec(queryString);
        if (fullTableMatch) {
            const [rows, columns] = fullTableMatch[0]
                .split('x')
                .map((n) => parseInt(n, 10));
            options.push(new ComponentPickerOption(`${rows}x${columns} Table`, {
                icon: jsxRuntime.jsx("i", { className: "icon table" }),
                keywords: ['table'],
                onSelect: () => 
                // @ts-ignore Correct types, but since they're dynamic TS doesn't like it.
                editor.dispatchCommand(table.INSERT_TABLE_COMMAND, { columns, rows }),
            }));
        }
        else if (partialTableMatch) {
            const rows = parseInt(partialTableMatch[0], 10);
            options.push(...Array.from({ length: 5 }, (_, i) => i + 1).map((columns) => new ComponentPickerOption(`${rows}x${columns} Table`, {
                icon: jsxRuntime.jsx("i", { className: "icon table" }),
                keywords: ['table'],
                onSelect: () => 
                // @ts-ignore Correct types, but since they're dynamic TS doesn't like it.
                editor.dispatchCommand(table.INSERT_TABLE_COMMAND, { columns, rows }),
            })));
        }
        return options;
    }, [editor, queryString]);
    const options = React.useMemo(() => {
        const baseOptions = [
            new ComponentPickerOption('Paragraph', {
                icon: jsxRuntime.jsx("i", { className: "icon paragraph" }),
                keywords: ['normal', 'paragraph', 'p', 'text'],
                onSelect: () => editor.update(() => {
                    const selection$1 = lexical.$getSelection();
                    if (lexical.$isRangeSelection(selection$1)) {
                        selection.$setBlocksType(selection$1, () => lexical.$createParagraphNode());
                    }
                }),
            }),
            ...Array.from({ length: 3 }, (_, i) => i + 1).map((n) => new ComponentPickerOption(`Heading ${n}`, {
                icon: jsxRuntime.jsx("i", { className: `icon h${n}` }),
                keywords: ['heading', 'header', `h${n}`],
                onSelect: () => editor.update(() => {
                    const selection$1 = lexical.$getSelection();
                    if (lexical.$isRangeSelection(selection$1)) {
                        selection.$setBlocksType(selection$1, () => 
                        // @ts-ignore Correct types, but since they're dynamic TS doesn't like it.
                        richText.$createHeadingNode(`h${n}`));
                    }
                }),
            })),
            new ComponentPickerOption('Table', {
                icon: jsxRuntime.jsx("i", { className: "icon table" }),
                keywords: ['table', 'grid', 'spreadsheet', 'rows', 'columns'],
                onSelect: () => showModal('Insert Table', (onClose) => (jsxRuntime.jsx(TablePlugin.InsertTableDialog, { activeEditor: editor, onClose: onClose }))),
            }),
            new ComponentPickerOption('Table (Experimental)', {
                icon: jsxRuntime.jsx("i", { className: "icon table" }),
                keywords: ['table', 'grid', 'spreadsheet', 'rows', 'columns'],
                onSelect: () => showModal('Insert Table', (onClose) => (jsxRuntime.jsx(TablePlugin.InsertNewTableDialog, { activeEditor: editor, onClose: onClose }))),
            }),
            new ComponentPickerOption('Numbered List', {
                icon: jsxRuntime.jsx("i", { className: "icon number" }),
                keywords: ['numbered list', 'ordered list', 'ol'],
                onSelect: () => editor.dispatchCommand(list.INSERT_ORDERED_LIST_COMMAND, undefined),
            }),
            new ComponentPickerOption('Bulleted List', {
                icon: jsxRuntime.jsx("i", { className: "icon bullet" }),
                keywords: ['bulleted list', 'unordered list', 'ul'],
                onSelect: () => editor.dispatchCommand(list.INSERT_UNORDERED_LIST_COMMAND, undefined),
            }),
            new ComponentPickerOption('Check List', {
                icon: jsxRuntime.jsx("i", { className: "icon check" }),
                keywords: ['check list', 'todo list'],
                onSelect: () => editor.dispatchCommand(list.INSERT_CHECK_LIST_COMMAND, undefined),
            }),
            new ComponentPickerOption('Quote', {
                icon: jsxRuntime.jsx("i", { className: "icon quote" }),
                keywords: ['block quote'],
                onSelect: () => editor.update(() => {
                    const selection$1 = lexical.$getSelection();
                    if (lexical.$isRangeSelection(selection$1)) {
                        selection.$setBlocksType(selection$1, () => richText.$createQuoteNode());
                    }
                }),
            }),
            new ComponentPickerOption('Code', {
                icon: jsxRuntime.jsx("i", { className: "icon code" }),
                keywords: ['javascript', 'python', 'js', 'codeblock'],
                onSelect: () => editor.update(() => {
                    const selection$1 = lexical.$getSelection();
                    if (lexical.$isRangeSelection(selection$1)) {
                        if (selection$1.isCollapsed()) {
                            selection.$setBlocksType(selection$1, () => code.$createCodeNode());
                        }
                        else {
                            // Will this ever happen?
                            const textContent = selection$1.getTextContent();
                            const codeNode = code.$createCodeNode();
                            selection$1.insertNodes([codeNode]);
                            selection$1.insertRawText(textContent);
                        }
                    }
                }),
            }),
            new ComponentPickerOption('Divider', {
                icon: jsxRuntime.jsx("i", { className: "icon horizontal-rule" }),
                keywords: ['horizontal rule', 'divider', 'hr'],
                onSelect: () => editor.dispatchCommand(LexicalHorizontalRuleNode.INSERT_HORIZONTAL_RULE_COMMAND, undefined),
            }),
            new ComponentPickerOption('Page Break', {
                icon: jsxRuntime.jsx("i", { className: "icon page-break" }),
                keywords: ['page break', 'divider'],
                onSelect: () => editor.dispatchCommand(index.INSERT_PAGE_BREAK, undefined),
            }),
            new ComponentPickerOption('Excalidraw', {
                icon: jsxRuntime.jsx("i", { className: "icon diagram-2" }),
                keywords: ['excalidraw', 'diagram', 'drawing'],
                onSelect: () => editor.dispatchCommand(index$1.INSERT_EXCALIDRAW_COMMAND, undefined),
            }),
            new ComponentPickerOption('Poll', {
                icon: jsxRuntime.jsx("i", { className: "icon poll" }),
                keywords: ['poll', 'vote'],
                onSelect: () => showModal('Insert Poll', (onClose) => (jsxRuntime.jsx(index$2.InsertPollDialog, { activeEditor: editor, onClose: onClose }))),
            }),
            ...index$3.EmbedConfigs.map((embedConfig) => new ComponentPickerOption(`Embed ${embedConfig.contentName}`, {
                icon: embedConfig.icon,
                keywords: [...embedConfig.keywords, 'embed'],
                onSelect: () => editor.dispatchCommand(LexicalAutoEmbedPlugin.INSERT_EMBED_COMMAND, embedConfig.type),
            })),
            new ComponentPickerOption('Equation', {
                icon: jsxRuntime.jsx("i", { className: "icon equation" }),
                keywords: ['equation', 'latex', 'math'],
                onSelect: () => showModal('Insert Equation', (onClose) => (jsxRuntime.jsx(index$4.InsertEquationDialog, { activeEditor: editor, onClose: onClose }))),
            }),
            new ComponentPickerOption('GIF', {
                icon: jsxRuntime.jsx("i", { className: "icon gif" }),
                keywords: ['gif', 'animate', 'image', 'file'],
                onSelect: () => console.log('insert image')
                // editor.dispatchCommand(INSERT_IMAGE_COMMAND, {
                //   altText: 'Cat typing on a laptop',
                //   src: catTypingGif,
                // }),
            }),
            new ComponentPickerOption('Image', {
                icon: jsxRuntime.jsx("i", { className: "icon image" }),
                keywords: ['image', 'photo', 'picture', 'file'],
                onSelect: () => showModal('Insert Image', (onClose) => (jsxRuntime.jsx(index$5.InsertImageDialog, { activeEditor: editor, onClose: onClose }))),
            }),
            new ComponentPickerOption('Collapsible', {
                icon: jsxRuntime.jsx("i", { className: "icon caret-right" }),
                keywords: ['collapse', 'collapsible', 'toggle'],
                onSelect: () => editor.dispatchCommand(index$6.INSERT_COLLAPSIBLE_COMMAND, undefined),
            }),
            ...['left', 'center', 'right', 'justify'].map((alignment) => new ComponentPickerOption(`Align ${alignment}`, {
                icon: jsxRuntime.jsx("i", { className: `icon ${alignment}-align` }),
                keywords: ['align', 'justify', alignment],
                onSelect: () => 
                // @ts-ignore Correct types, but since they're dynamic TS doesn't like it.
                editor.dispatchCommand(lexical.FORMAT_ELEMENT_COMMAND, alignment),
            })),
        ];
        const dynamicOptions = getDynamicOptions();
        return queryString
            ? [
                ...dynamicOptions,
                ...baseOptions.filter((option) => {
                    return new RegExp(queryString, 'gi').exec(option.title) ||
                        option.keywords != null
                        ? option.keywords.some((keyword) => new RegExp(queryString, 'gi').exec(keyword))
                        : false;
                }),
            ]
            : baseOptions;
    }, [editor, getDynamicOptions, queryString, showModal]);
    const onSelectOption = React.useCallback((selectedOption, nodeToRemove, closeMenu, matchingString) => {
        editor.update(() => {
            if (nodeToRemove) {
                nodeToRemove.remove();
            }
            selectedOption.onSelect(matchingString);
            closeMenu();
        });
    }, [editor]);
    return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [modal, jsxRuntime.jsx(LexicalTypeaheadMenuPlugin.LexicalTypeaheadMenuPlugin, { onQueryChange: setQueryString, onSelectOption: onSelectOption, triggerFn: checkForTriggerMatch, options: options, menuRenderFn: (anchorElementRef, { selectedIndex, selectOptionAndCleanUp, setHighlightedIndex }) => anchorElementRef.current && options.length
                    ? ReactDOM__namespace.createPortal(jsxRuntime.jsx("div", { className: "typeahead-popover component-picker-menu", children: jsxRuntime.jsx("ul", { children: options.map((option, i) => (jsxRuntime.jsx(ComponentPickerMenuItem, { index: i, isSelected: selectedIndex === i, onClick: () => {
                                    setHighlightedIndex(i);
                                    selectOptionAndCleanUp(option);
                                }, onMouseEnter: () => {
                                    setHighlightedIndex(i);
                                }, option: option }, option.key))) }) }), anchorElementRef.current)
                    : null })] }));
}

exports["default"] = ComponentPickerMenuPlugin;
