'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var tslib_es6 = require('../../../node_modules/tslib/tslib.es6.js');
var jsxRuntime = require('react/jsx-runtime');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var LexicalContextMenuPlugin = require('@lexical/react/LexicalContextMenuPlugin');
var lexical = require('lexical');
var React = require('react');
var ReactDOM = require('react-dom');

function _interopNamespace(e) {
    if (e && e.__esModule) return e;
    var n = Object.create(null);
    if (e) {
        Object.keys(e).forEach(function (k) {
            if (k !== 'default') {
                var d = Object.getOwnPropertyDescriptor(e, k);
                Object.defineProperty(n, k, d.get ? d : {
                    enumerable: true,
                    get: function () { return e[k]; }
                });
            }
        });
    }
    n["default"] = e;
    return Object.freeze(n);
}

var ReactDOM__namespace = /*#__PURE__*/_interopNamespace(ReactDOM);

function ContextMenuItem({ index, isSelected, onClick, onMouseEnter, option, }) {
    let className = 'item';
    if (isSelected) {
        className += ' selected';
    }
    return (jsxRuntime.jsx("li", { tabIndex: -1, className: className, ref: option.setRefElement, role: "option", "aria-selected": isSelected, id: 'typeahead-item-' + index, onMouseEnter: onMouseEnter, onClick: onClick, children: jsxRuntime.jsx("span", { className: "text", children: option.title }) }, option.key));
}
function ContextMenu({ options, selectedItemIndex, onOptionClick, onOptionMouseEnter, }) {
    return (jsxRuntime.jsx("div", { className: "typeahead-popover", children: jsxRuntime.jsx("ul", { children: options.map((option, i) => (jsxRuntime.jsx(ContextMenuItem, { index: i, isSelected: selectedItemIndex === i, onClick: () => onOptionClick(option, i), onMouseEnter: () => onOptionMouseEnter(i), option: option }, option.key))) }) }));
}
class ContextMenuOption extends LexicalContextMenuPlugin.MenuOption {
    constructor(title, options) {
        super(title);
        this.title = title;
        this.onSelect = options.onSelect.bind(this);
    }
}
function ContextMenuPlugin() {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const options = React.useMemo(() => {
        return [
            new ContextMenuOption(`Copy`, {
                onSelect: (_node) => {
                    editor.dispatchCommand(lexical.COPY_COMMAND, null);
                },
            }),
            new ContextMenuOption(`Cut`, {
                onSelect: (_node) => {
                    editor.dispatchCommand(lexical.CUT_COMMAND, null);
                },
            }),
            new ContextMenuOption(`Paste`, {
                onSelect: (_node) => {
                    navigator.clipboard.read().then((...args) => tslib_es6.__awaiter(this, void 0, void 0, function* () {
                        const data = new DataTransfer();
                        const items = yield navigator.clipboard.read();
                        const item = items[0];
                        const permission = yield navigator.permissions.query({
                            // @ts-ignore These types are incorrect.
                            name: 'clipboard-read',
                        });
                        if (permission.state === 'denied') {
                            alert('Not allowed to paste from clipboard.');
                            return;
                        }
                        for (const type of item.types) {
                            const dataString = yield (yield item.getType(type)).text();
                            data.setData(type, dataString);
                        }
                        const event = new ClipboardEvent('paste', {
                            clipboardData: data,
                        });
                        editor.dispatchCommand(lexical.PASTE_COMMAND, event);
                    }));
                },
            }),
            new ContextMenuOption(`Paste as Plain Text`, {
                onSelect: (_node) => {
                    navigator.clipboard.read().then((...args) => tslib_es6.__awaiter(this, void 0, void 0, function* () {
                        const permission = yield navigator.permissions.query({
                            // @ts-ignore These types are incorrect.
                            name: 'clipboard-read',
                        });
                        if (permission.state === 'denied') {
                            alert('Not allowed to paste from clipboard.');
                            return;
                        }
                        const data = new DataTransfer();
                        const items = yield navigator.clipboard.readText();
                        data.setData('text/plain', items);
                        const event = new ClipboardEvent('paste', {
                            clipboardData: data,
                        });
                        editor.dispatchCommand(lexical.PASTE_COMMAND, event);
                    }));
                },
            }),
            new ContextMenuOption(`Delete Node`, {
                onSelect: (_node) => {
                    const selection = lexical.$getSelection();
                    if (lexical.$isRangeSelection(selection)) {
                        const currentNode = selection.anchor.getNode();
                        const ancestorNodeWithRootAsParent = currentNode
                            .getParents()
                            .at(-2);
                        ancestorNodeWithRootAsParent === null || ancestorNodeWithRootAsParent === void 0 ? void 0 : ancestorNodeWithRootAsParent.remove();
                    }
                },
            }),
        ];
    }, [editor]);
    const onSelectOption = React.useCallback((selectedOption, targetNode, closeMenu) => {
        editor.update(() => {
            selectedOption.onSelect(targetNode);
            closeMenu();
        });
    }, [editor]);
    return (jsxRuntime.jsx(LexicalContextMenuPlugin.LexicalContextMenuPlugin, { options: options, onSelectOption: onSelectOption, menuRenderFn: (anchorElementRef, { selectedIndex, options: _options, selectOptionAndCleanUp, setHighlightedIndex, }, { setMenuRef }) => anchorElementRef.current
            ? ReactDOM__namespace.createPortal(jsxRuntime.jsx("div", { className: "typeahead-popover auto-embed-menu", style: {
                    marginLeft: anchorElementRef.current.style.width,
                    userSelect: 'none',
                    width: 200,
                }, ref: setMenuRef, children: jsxRuntime.jsx(ContextMenu, { options: options, selectedItemIndex: selectedIndex, onOptionClick: (option, index) => {
                        setHighlightedIndex(index);
                        selectOptionAndCleanUp(option);
                    }, onOptionMouseEnter: (index) => {
                        setHighlightedIndex(index);
                    } }) }), anchorElementRef.current)
            : null }));
}

exports.ContextMenuOption = ContextMenuOption;
exports["default"] = ContextMenuPlugin;
