'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var LexicalTypeaheadMenuPlugin = require('@lexical/react/LexicalTypeaheadMenuPlugin');
var lexical = require('lexical');
var React = require('react');
var ReactDOM = require('react-dom');

function _interopNamespace(e) {
    if (e && e.__esModule) return e;
    var n = Object.create(null);
    if (e) {
        Object.keys(e).forEach(function (k) {
            if (k !== 'default') {
                var d = Object.getOwnPropertyDescriptor(e, k);
                Object.defineProperty(n, k, d.get ? d : {
                    enumerable: true,
                    get: function () { return e[k]; }
                });
            }
        });
    }
    n["default"] = e;
    return Object.freeze(n);
}

var ReactDOM__namespace = /*#__PURE__*/_interopNamespace(ReactDOM);

class EmojiOption extends LexicalTypeaheadMenuPlugin.MenuOption {
    constructor(title, emoji, options) {
        super(title);
        this.title = title;
        this.emoji = emoji;
        this.keywords = options.keywords || [];
    }
}
function EmojiMenuItem({ index, isSelected, onClick, onMouseEnter, option, }) {
    let className = 'item';
    if (isSelected) {
        className += ' selected';
    }
    return (jsxRuntime.jsx("li", { tabIndex: -1, className: className, ref: option.setRefElement, role: "option", "aria-selected": isSelected, id: 'typeahead-item-' + index, onMouseEnter: onMouseEnter, onClick: onClick, children: jsxRuntime.jsxs("span", { className: "text", children: [option.emoji, " ", option.title] }) }, option.key));
}
const MAX_EMOJI_SUGGESTION_COUNT = 10;
function EmojiPickerPlugin() {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const [queryString, setQueryString] = React.useState(null);
    const [emojis, setEmojis] = React.useState([]);
    React.useEffect(() => {
        // @ts-ignore
        Promise.resolve().then(function () { return require('../../utils/emoji-list.js'); }).then((file) => setEmojis(file.default));
    }, []);
    const emojiOptions = React.useMemo(() => emojis != null
        ? emojis.map(({ emoji, aliases, tags }) => new EmojiOption(aliases[0], emoji, {
            keywords: [...aliases, ...tags],
        }))
        : [], [emojis]);
    const checkForTriggerMatch = LexicalTypeaheadMenuPlugin.useBasicTypeaheadTriggerMatch(':', {
        minLength: 0,
    });
    const options = React.useMemo(() => {
        return emojiOptions
            .filter((option) => {
            return queryString != null
                ? new RegExp(queryString, 'gi').exec(option.title) ||
                    option.keywords != null
                    ? option.keywords.some((keyword) => new RegExp(queryString, 'gi').exec(keyword))
                    : false
                : emojiOptions;
        })
            .slice(0, MAX_EMOJI_SUGGESTION_COUNT);
    }, [emojiOptions, queryString]);
    const onSelectOption = React.useCallback((selectedOption, nodeToRemove, closeMenu) => {
        editor.update(() => {
            const selection = lexical.$getSelection();
            if (!lexical.$isRangeSelection(selection) || selectedOption == null) {
                return;
            }
            if (nodeToRemove) {
                nodeToRemove.remove();
            }
            selection.insertNodes([lexical.$createTextNode(selectedOption.emoji)]);
            closeMenu();
        });
    }, [editor]);
    return (jsxRuntime.jsx(LexicalTypeaheadMenuPlugin.LexicalTypeaheadMenuPlugin, { onQueryChange: setQueryString, onSelectOption: onSelectOption, triggerFn: checkForTriggerMatch, options: options, menuRenderFn: (anchorElementRef, { selectedIndex, selectOptionAndCleanUp, setHighlightedIndex }) => {
            if (anchorElementRef.current == null || options.length === 0) {
                return null;
            }
            return anchorElementRef.current && options.length
                ? ReactDOM__namespace.createPortal(jsxRuntime.jsx("div", { className: "typeahead-popover emoji-menu", children: jsxRuntime.jsx("ul", { children: options.map((option, index) => (jsxRuntime.jsx("div", { children: jsxRuntime.jsx(EmojiMenuItem, { index: index, isSelected: selectedIndex === index, onClick: () => {
                                    setHighlightedIndex(index);
                                    selectOptionAndCleanUp(option);
                                }, onMouseEnter: () => {
                                    setHighlightedIndex(index);
                                }, option: option }) }, option.key))) }) }), anchorElementRef.current)
                : null;
        } }));
}

exports["default"] = EmojiPickerPlugin;
