'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
require('katex/dist/katex.css');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var utils = require('@lexical/utils');
var lexical = require('lexical');
var React = require('react');
var EquationNode = require('../../nodes/EquationNode.js');
var KatexEquationAlterer = require('../../ui/KatexEquationAlterer.js');

const INSERT_EQUATION_COMMAND = lexical.createCommand('INSERT_EQUATION_COMMAND');
function InsertEquationDialog({ activeEditor, onClose, }) {
    const onEquationConfirm = React.useCallback((equation, inline) => {
        activeEditor.dispatchCommand(INSERT_EQUATION_COMMAND, { equation, inline });
        onClose();
    }, [activeEditor, onClose]);
    return jsxRuntime.jsx(KatexEquationAlterer["default"], { onConfirm: onEquationConfirm });
}
function EquationsPlugin() {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    React.useEffect(() => {
        if (!editor.hasNodes([EquationNode.EquationNode])) {
            throw new Error('EquationsPlugins: EquationsNode not registered on editor');
        }
        return editor.registerCommand(INSERT_EQUATION_COMMAND, (payload) => {
            const { equation, inline } = payload;
            const equationNode = EquationNode.$createEquationNode(equation, inline);
            lexical.$insertNodes([equationNode]);
            if (lexical.$isRootOrShadowRoot(equationNode.getParentOrThrow())) {
                utils.$wrapNodeInElement(equationNode, lexical.$createParagraphNode).selectEnd();
            }
            return true;
        }, lexical.COMMAND_PRIORITY_EDITOR);
    }, [editor]);
    return null;
}

exports.INSERT_EQUATION_COMMAND = INSERT_EQUATION_COMMAND;
exports.InsertEquationDialog = InsertEquationDialog;
exports["default"] = EquationsPlugin;
