'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
require('./index.css.js');
var link = require('@lexical/link');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var utils = require('@lexical/utils');
var lexical = require('lexical');
var React = require('react');
var ReactDOM = require('react-dom');
var getSelectedNode = require('../../utils/getSelectedNode.js');
var setFloatingElemPositionForLinkEditor = require('../../utils/setFloatingElemPositionForLinkEditor.js');
var url = require('../../utils/url.js');

function FloatingLinkEditor({ editor, isLink, setIsLink, anchorElem, }) {
    const editorRef = React.useRef(null);
    const inputRef = React.useRef(null);
    const [linkUrl, setLinkUrl] = React.useState('');
    const [editedLinkUrl, setEditedLinkUrl] = React.useState('');
    const [isEditMode, setEditMode] = React.useState(false);
    const [lastSelection, setLastSelection] = React.useState(null);
    const updateLinkEditor = React.useCallback(() => {
        var _a, _b;
        const selection = lexical.$getSelection();
        if (lexical.$isRangeSelection(selection)) {
            const node = getSelectedNode.getSelectedNode(selection);
            const parent = node.getParent();
            if (link.$isLinkNode(parent)) {
                setLinkUrl(parent.getURL());
            }
            else if (link.$isLinkNode(node)) {
                setLinkUrl(node.getURL());
            }
            else {
                setLinkUrl('');
            }
        }
        const editorElem = editorRef.current;
        const nativeSelection = window.getSelection();
        const activeElement = document.activeElement;
        if (editorElem === null) {
            return;
        }
        const rootElement = editor.getRootElement();
        if (selection !== null &&
            nativeSelection !== null &&
            rootElement !== null &&
            rootElement.contains(nativeSelection.anchorNode) &&
            editor.isEditable()) {
            const domRect = (_b = (_a = nativeSelection.focusNode) === null || _a === void 0 ? void 0 : _a.parentElement) === null || _b === void 0 ? void 0 : _b.getBoundingClientRect();
            if (domRect) {
                domRect.y += 40;
                setFloatingElemPositionForLinkEditor.setFloatingElemPositionForLinkEditor(domRect, editorElem, anchorElem);
            }
            setLastSelection(selection);
        }
        else if (!activeElement || activeElement.className !== 'link-input') {
            if (rootElement !== null) {
                setFloatingElemPositionForLinkEditor.setFloatingElemPositionForLinkEditor(null, editorElem, anchorElem);
            }
            setLastSelection(null);
            setEditMode(false);
            setLinkUrl('');
        }
        return true;
    }, [anchorElem, editor]);
    React.useEffect(() => {
        const scrollerElem = anchorElem.parentElement;
        const update = () => {
            editor.getEditorState().read(() => {
                updateLinkEditor();
            });
        };
        window.addEventListener('resize', update);
        if (scrollerElem) {
            scrollerElem.addEventListener('scroll', update);
        }
        return () => {
            window.removeEventListener('resize', update);
            if (scrollerElem) {
                scrollerElem.removeEventListener('scroll', update);
            }
        };
    }, [anchorElem.parentElement, editor, updateLinkEditor]);
    React.useEffect(() => {
        return utils.mergeRegister(editor.registerUpdateListener(({ editorState }) => {
            editorState.read(() => {
                updateLinkEditor();
            });
        }), editor.registerCommand(lexical.SELECTION_CHANGE_COMMAND, () => {
            updateLinkEditor();
            return true;
        }, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.KEY_ESCAPE_COMMAND, () => {
            if (isLink) {
                setIsLink(false);
                return true;
            }
            return false;
        }, lexical.COMMAND_PRIORITY_HIGH));
    }, [editor, updateLinkEditor, setIsLink, isLink]);
    React.useEffect(() => {
        editor.getEditorState().read(() => {
            updateLinkEditor();
        });
    }, [editor, updateLinkEditor]);
    React.useEffect(() => {
        if (isEditMode && inputRef.current) {
            inputRef.current.focus();
        }
    }, [isEditMode]);
    const monitorInputInteraction = (event) => {
        if (event.key === 'Enter') {
            event.preventDefault();
            handleLinkSubmission();
        }
        else if (event.key === 'Escape') {
            event.preventDefault();
            setEditMode(false);
        }
    };
    const handleLinkSubmission = () => {
        if (lastSelection !== null) {
            if (linkUrl !== '') {
                editor.dispatchCommand(link.TOGGLE_LINK_COMMAND, url.sanitizeUrl(editedLinkUrl));
            }
            setEditMode(false);
        }
    };
    return (jsxRuntime.jsx("div", { ref: editorRef, className: "link-editor", children: !isLink ? null : isEditMode ? (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx("input", { ref: inputRef, className: "link-input", value: editedLinkUrl, onChange: (event) => {
                        setEditedLinkUrl(event.target.value);
                    }, onKeyDown: (event) => {
                        monitorInputInteraction(event);
                    } }), jsxRuntime.jsxs("div", { children: [jsxRuntime.jsx("div", { className: "link-cancel", role: "button", tabIndex: 0, onMouseDown: (event) => event.preventDefault(), onClick: () => {
                                setEditMode(false);
                            } }), jsxRuntime.jsx("div", { className: "link-confirm", role: "button", tabIndex: 0, onMouseDown: (event) => event.preventDefault(), onClick: handleLinkSubmission })] })] })) : (jsxRuntime.jsxs("div", { className: "link-view", children: [jsxRuntime.jsx("a", { href: url.sanitizeUrl(linkUrl), target: "_blank", rel: "noopener noreferrer", children: linkUrl }), jsxRuntime.jsx("div", { className: "link-edit", role: "button", tabIndex: 0, onMouseDown: (event) => event.preventDefault(), onClick: () => {
                        setEditedLinkUrl(linkUrl);
                        setEditMode(true);
                    } }), jsxRuntime.jsx("div", { className: "link-trash", role: "button", tabIndex: 0, onMouseDown: (event) => event.preventDefault(), onClick: () => {
                        editor.dispatchCommand(link.TOGGLE_LINK_COMMAND, null);
                    } })] })) }));
}
function useFloatingLinkEditorToolbar(editor, anchorElem) {
    const [activeEditor, setActiveEditor] = React.useState(editor);
    const [isLink, setIsLink] = React.useState(false);
    const updateToolbar = React.useCallback(() => {
        const selection = lexical.$getSelection();
        if (lexical.$isRangeSelection(selection)) {
            const node = getSelectedNode.getSelectedNode(selection);
            const linkParent = utils.$findMatchingParent(node, link.$isLinkNode);
            const autoLinkParent = utils.$findMatchingParent(node, link.$isAutoLinkNode);
            // We don't want this menu to open for auto links.
            if (linkParent != null && autoLinkParent == null) {
                setIsLink(true);
            }
            else {
                setIsLink(false);
            }
        }
    }, []);
    React.useEffect(() => {
        return utils.mergeRegister(editor.registerUpdateListener(({ editorState }) => {
            editorState.read(() => {
                updateToolbar();
            });
        }), editor.registerCommand(lexical.SELECTION_CHANGE_COMMAND, (_payload, newEditor) => {
            updateToolbar();
            setActiveEditor(newEditor);
            return false;
        }, lexical.COMMAND_PRIORITY_CRITICAL));
    }, [editor, updateToolbar]);
    return ReactDOM.createPortal(jsxRuntime.jsx(FloatingLinkEditor, { editor: activeEditor, isLink: isLink, anchorElem: anchorElem, setIsLink: setIsLink }), anchorElem);
}
function FloatingLinkEditorPlugin({ anchorElem = document.body, }) {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    return useFloatingLinkEditorToolbar(editor, anchorElem);
}

exports["default"] = FloatingLinkEditorPlugin;
