'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
require('./index.css.js');
var code = require('@lexical/code');
var link = require('@lexical/link');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var utils = require('@lexical/utils');
var lexical = require('lexical');
var React = require('react');
var ReactDOM = require('react-dom');
var getDOMRangeRect = require('../../utils/getDOMRangeRect.js');
var getSelectedNode = require('../../utils/getSelectedNode.js');
var setFloatingElemPosition = require('../../utils/setFloatingElemPosition.js');
var index = require('../CommentPlugin/index.js');

function TextFormatFloatingToolbar({ editor, anchorElem, isLink, isBold, isItalic, isUnderline, isCode, isStrikethrough, isSubscript, isSuperscript, }) {
    const popupCharStylesEditorRef = React.useRef(null);
    const insertLink = React.useCallback(() => {
        if (!isLink) {
            editor.dispatchCommand(link.TOGGLE_LINK_COMMAND, 'https://');
        }
        else {
            editor.dispatchCommand(link.TOGGLE_LINK_COMMAND, null);
        }
    }, [editor, isLink]);
    const insertComment = () => {
        editor.dispatchCommand(index.INSERT_INLINE_COMMAND, undefined);
    };
    function mouseMoveListener(e) {
        if ((popupCharStylesEditorRef === null || popupCharStylesEditorRef === void 0 ? void 0 : popupCharStylesEditorRef.current) &&
            (e.buttons === 1 || e.buttons === 3)) {
            if (popupCharStylesEditorRef.current.style.pointerEvents !== 'none') {
                const x = e.clientX;
                const y = e.clientY;
                const elementUnderMouse = document.elementFromPoint(x, y);
                if (!popupCharStylesEditorRef.current.contains(elementUnderMouse)) {
                    // Mouse is not over the target element => not a normal click, but probably a drag
                    popupCharStylesEditorRef.current.style.pointerEvents = 'none';
                }
            }
        }
    }
    function mouseUpListener(e) {
        if (popupCharStylesEditorRef === null || popupCharStylesEditorRef === void 0 ? void 0 : popupCharStylesEditorRef.current) {
            if (popupCharStylesEditorRef.current.style.pointerEvents !== 'auto') {
                popupCharStylesEditorRef.current.style.pointerEvents = 'auto';
            }
        }
    }
    React.useEffect(() => {
        if (popupCharStylesEditorRef === null || popupCharStylesEditorRef === void 0 ? void 0 : popupCharStylesEditorRef.current) {
            document.addEventListener('mousemove', mouseMoveListener);
            document.addEventListener('mouseup', mouseUpListener);
            return () => {
                document.removeEventListener('mousemove', mouseMoveListener);
                document.removeEventListener('mouseup', mouseUpListener);
            };
        }
    }, [popupCharStylesEditorRef]);
    const updateTextFormatFloatingToolbar = React.useCallback(() => {
        const selection = lexical.$getSelection();
        const popupCharStylesEditorElem = popupCharStylesEditorRef.current;
        const nativeSelection = window.getSelection();
        if (popupCharStylesEditorElem === null) {
            return;
        }
        const rootElement = editor.getRootElement();
        if (selection !== null &&
            nativeSelection !== null &&
            !nativeSelection.isCollapsed &&
            rootElement !== null &&
            rootElement.contains(nativeSelection.anchorNode)) {
            const rangeRect = getDOMRangeRect.getDOMRangeRect(nativeSelection, rootElement);
            setFloatingElemPosition.setFloatingElemPosition(rangeRect, popupCharStylesEditorElem, anchorElem);
        }
    }, [editor, anchorElem]);
    React.useEffect(() => {
        const scrollerElem = anchorElem.parentElement;
        const update = () => {
            editor.getEditorState().read(() => {
                updateTextFormatFloatingToolbar();
            });
        };
        window.addEventListener('resize', update);
        if (scrollerElem) {
            scrollerElem.addEventListener('scroll', update);
        }
        return () => {
            window.removeEventListener('resize', update);
            if (scrollerElem) {
                scrollerElem.removeEventListener('scroll', update);
            }
        };
    }, [editor, updateTextFormatFloatingToolbar, anchorElem]);
    React.useEffect(() => {
        editor.getEditorState().read(() => {
            updateTextFormatFloatingToolbar();
        });
        return utils.mergeRegister(editor.registerUpdateListener(({ editorState }) => {
            editorState.read(() => {
                updateTextFormatFloatingToolbar();
            });
        }), editor.registerCommand(lexical.SELECTION_CHANGE_COMMAND, () => {
            updateTextFormatFloatingToolbar();
            return false;
        }, lexical.COMMAND_PRIORITY_LOW));
    }, [editor, updateTextFormatFloatingToolbar]);
    return (jsxRuntime.jsxs("div", { ref: popupCharStylesEditorRef, className: "floating-text-format-popup", children: [editor.isEditable() && (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx("button", { type: "button", onClick: () => {
                            editor.dispatchCommand(lexical.FORMAT_TEXT_COMMAND, 'bold');
                        }, className: 'popup-item spaced ' + (isBold ? 'active' : ''), "aria-label": "Format text as bold", children: jsxRuntime.jsx("i", { className: "format bold" }) }), jsxRuntime.jsx("button", { type: "button", onClick: () => {
                            editor.dispatchCommand(lexical.FORMAT_TEXT_COMMAND, 'italic');
                        }, className: 'popup-item spaced ' + (isItalic ? 'active' : ''), "aria-label": "Format text as italics", children: jsxRuntime.jsx("i", { className: "format italic" }) }), jsxRuntime.jsx("button", { type: "button", onClick: () => {
                            editor.dispatchCommand(lexical.FORMAT_TEXT_COMMAND, 'underline');
                        }, className: 'popup-item spaced ' + (isUnderline ? 'active' : ''), "aria-label": "Format text to underlined", children: jsxRuntime.jsx("i", { className: "format underline" }) }), jsxRuntime.jsx("button", { type: "button", onClick: () => {
                            editor.dispatchCommand(lexical.FORMAT_TEXT_COMMAND, 'strikethrough');
                        }, className: 'popup-item spaced ' + (isStrikethrough ? 'active' : ''), "aria-label": "Format text with a strikethrough", children: jsxRuntime.jsx("i", { className: "format strikethrough" }) }), jsxRuntime.jsx("button", { type: "button", onClick: () => {
                            editor.dispatchCommand(lexical.FORMAT_TEXT_COMMAND, 'subscript');
                        }, className: 'popup-item spaced ' + (isSubscript ? 'active' : ''), title: "Subscript", "aria-label": "Format Subscript", children: jsxRuntime.jsx("i", { className: "format subscript" }) }), jsxRuntime.jsx("button", { type: "button", onClick: () => {
                            editor.dispatchCommand(lexical.FORMAT_TEXT_COMMAND, 'superscript');
                        }, className: 'popup-item spaced ' + (isSuperscript ? 'active' : ''), title: "Superscript", "aria-label": "Format Superscript", children: jsxRuntime.jsx("i", { className: "format superscript" }) }), jsxRuntime.jsx("button", { type: "button", onClick: () => {
                            editor.dispatchCommand(lexical.FORMAT_TEXT_COMMAND, 'code');
                        }, className: 'popup-item spaced ' + (isCode ? 'active' : ''), "aria-label": "Insert code block", children: jsxRuntime.jsx("i", { className: "format code" }) }), jsxRuntime.jsx("button", { type: "button", onClick: insertLink, className: 'popup-item spaced ' + (isLink ? 'active' : ''), "aria-label": "Insert link", children: jsxRuntime.jsx("i", { className: "format link" }) })] })), jsxRuntime.jsx("button", { type: "button", onClick: insertComment, className: 'popup-item spaced insert-comment', "aria-label": "Insert comment", children: jsxRuntime.jsx("i", { className: "format add-comment" }) })] }));
}
function useFloatingTextFormatToolbar(editor, anchorElem) {
    const [isText, setIsText] = React.useState(false);
    const [isLink, setIsLink] = React.useState(false);
    const [isBold, setIsBold] = React.useState(false);
    const [isItalic, setIsItalic] = React.useState(false);
    const [isUnderline, setIsUnderline] = React.useState(false);
    const [isStrikethrough, setIsStrikethrough] = React.useState(false);
    const [isSubscript, setIsSubscript] = React.useState(false);
    const [isSuperscript, setIsSuperscript] = React.useState(false);
    const [isCode, setIsCode] = React.useState(false);
    const updatePopup = React.useCallback(() => {
        editor.getEditorState().read(() => {
            // Should not to pop up the floating toolbar when using IME input
            if (editor.isComposing()) {
                return;
            }
            const selection = lexical.$getSelection();
            const nativeSelection = window.getSelection();
            const rootElement = editor.getRootElement();
            if (nativeSelection !== null &&
                (!lexical.$isRangeSelection(selection) ||
                    rootElement === null ||
                    !rootElement.contains(nativeSelection.anchorNode))) {
                setIsText(false);
                return;
            }
            if (!lexical.$isRangeSelection(selection)) {
                return;
            }
            const node = getSelectedNode.getSelectedNode(selection);
            // Update text format
            setIsBold(selection.hasFormat('bold'));
            setIsItalic(selection.hasFormat('italic'));
            setIsUnderline(selection.hasFormat('underline'));
            setIsStrikethrough(selection.hasFormat('strikethrough'));
            setIsSubscript(selection.hasFormat('subscript'));
            setIsSuperscript(selection.hasFormat('superscript'));
            setIsCode(selection.hasFormat('code'));
            // Update links
            const parent = node.getParent();
            if (link.$isLinkNode(parent) || link.$isLinkNode(node)) {
                setIsLink(true);
            }
            else {
                setIsLink(false);
            }
            if (!code.$isCodeHighlightNode(selection.anchor.getNode()) &&
                selection.getTextContent() !== '') {
                setIsText(lexical.$isTextNode(node));
            }
            else {
                setIsText(false);
            }
            const rawTextContent = selection.getTextContent().replace(/\n/g, '');
            if (!selection.isCollapsed() && rawTextContent === '') {
                setIsText(false);
                return;
            }
        });
    }, [editor]);
    React.useEffect(() => {
        document.addEventListener('selectionchange', updatePopup);
        return () => {
            document.removeEventListener('selectionchange', updatePopup);
        };
    }, [updatePopup]);
    React.useEffect(() => {
        return utils.mergeRegister(editor.registerUpdateListener(() => {
            updatePopup();
        }), editor.registerRootListener(() => {
            if (editor.getRootElement() === null) {
                setIsText(false);
            }
        }));
    }, [editor, updatePopup]);
    if (!isText || isLink) {
        return null;
    }
    return ReactDOM.createPortal(jsxRuntime.jsx(TextFormatFloatingToolbar, { editor: editor, anchorElem: anchorElem, isLink: isLink, isBold: isBold, isItalic: isItalic, isStrikethrough: isStrikethrough, isSubscript: isSubscript, isSuperscript: isSuperscript, isUnderline: isUnderline, isCode: isCode }), anchorElem);
}
function FloatingTextFormatToolbarPlugin({ anchorElem = document.body, }) {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    return useFloatingTextFormatToolbar(editor, anchorElem);
}

exports["default"] = FloatingTextFormatToolbarPlugin;
