'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var utils = require('@lexical/utils');
var lexical = require('lexical');
var React = require('react');
var ImageNode = require('../../nodes/ImageNode.js');
var Button = require('../../ui/Button.js');
var Dialog = require('../../ui/Dialog.js');
var FileInput = require('../../ui/FileInput.js');
var TextInput = require('../../ui/TextInput.js');
var index$1 = require('../../shared/index.js');
var selection = require('./selection.js');
var index = require('../../../network/index.js');

const getDOMSelection = (targetWindow) => index$1.CAN_USE_DOM ? (targetWindow || window).getSelection() : null;
const INSERT_IMAGE_COMMAND = lexical.createCommand('INSERT_IMAGE_COMMAND');
function InsertImageUriDialogBody({ onClick, }) {
    const [src, setSrc] = React.useState('');
    const [altText, setAltText] = React.useState('');
    const isDisabled = src === '';
    return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx(TextInput["default"], { label: "Image URL", placeholder: "i.e. https://source.unsplash.com/random", onChange: setSrc, value: src, "data-test-id": "image-modal-url-input" }), jsxRuntime.jsx(TextInput["default"], { label: "Alt Text", placeholder: "Random unsplash image", onChange: setAltText, value: altText, "data-test-id": "image-modal-alt-text-input" }), jsxRuntime.jsx(Dialog.DialogActions, { children: jsxRuntime.jsx(Button["default"], { "data-test-id": "image-modal-confirm-btn", disabled: isDisabled, onClick: () => onClick({ altText, src }), children: "Confirm" }) })] }));
}
function InsertImageUploadedDialogBody({ onClick, }) {
    const [src, setSrc] = React.useState('');
    const [altText, setAltText] = React.useState('');
    const isDisabled = src === '';
    const loadImage = (files) => {
        const reader = new FileReader();
        reader.onload = function () {
            if (typeof reader.result === 'string') {
                setSrc(reader.result);
            }
            return '';
        };
        if (files !== null) {
            reader.readAsDataURL(files[0]);
        }
    };
    return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx(FileInput["default"], { label: "Image Upload", onChange: loadImage, accept: "image/*", "data-test-id": "image-modal-file-upload" }), jsxRuntime.jsx(TextInput["default"], { label: "Alt Text", placeholder: "Descriptive alternative text", onChange: setAltText, value: altText, "data-test-id": "image-modal-alt-text-input" }), jsxRuntime.jsx(Dialog.DialogActions, { children: jsxRuntime.jsx(Button["default"], { "data-test-id": "image-modal-file-upload-btn", disabled: isDisabled, onClick: () => onClick({ altText, src }), children: "Confirm" }) })] }));
}
function InsertImageDialog({ activeEditor, onClose, }) {
    const [mode, setMode] = React.useState(null);
    const hasModifier = React.useRef(false);
    React.useEffect(() => {
        hasModifier.current = false;
        const handler = (e) => {
            hasModifier.current = e.altKey;
        };
        document.addEventListener('keydown', handler);
        return () => {
            document.removeEventListener('keydown', handler);
        };
    }, [activeEditor]);
    const onClick = (payload) => {
        activeEditor.dispatchCommand(INSERT_IMAGE_COMMAND, payload);
        onClose();
    };
    const batchInsert = (src) => {
        src.forEach(p => {
            activeEditor.dispatchCommand(INSERT_IMAGE_COMMAND, { src: p, altText: '' });
        });
        onClose();
    };
    return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [!mode && (jsxRuntime.jsxs(Dialog.DialogButtonsList, { children: [jsxRuntime.jsx(Button["default"], { "data-test-id": "image-modal-option-cloud", onClick: () => setMode('cloud'), children: "Cloud" }), jsxRuntime.jsx(Button["default"], { "data-test-id": "image-modal-option-url", onClick: () => setMode('url'), children: "URL" })] })), mode === 'url' && jsxRuntime.jsx(InsertImageUriDialogBody, { onClick: onClick }), mode === 'file' && jsxRuntime.jsx(InsertImageUploadedDialogBody, { onClick: onClick }), mode === 'cloud' && jsxRuntime.jsx(selection.ImageSelection, { onCancel: () => { }, getFiles: index.getEditorImages, uploadUrl: index.editorUploadImageUrl, onSelect: batchInsert })] }));
}
function ImagesPlugin({ captionsEnabled, }) {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    React.useEffect(() => {
        if (!editor.hasNodes([ImageNode.ImageNode])) {
            throw new Error('ImagesPlugin: ImageNode not registered on editor');
        }
        return utils.mergeRegister(editor.registerCommand(INSERT_IMAGE_COMMAND, (payload) => {
            const imageNode = ImageNode.$createImageNode(payload);
            lexical.$insertNodes([imageNode]);
            if (lexical.$isRootOrShadowRoot(imageNode.getParentOrThrow())) {
                utils.$wrapNodeInElement(imageNode, lexical.$createParagraphNode).selectEnd();
            }
            return true;
        }, lexical.COMMAND_PRIORITY_EDITOR), editor.registerCommand(lexical.DRAGSTART_COMMAND, (event) => {
            return onDragStart(event);
        }, lexical.COMMAND_PRIORITY_HIGH), editor.registerCommand(lexical.DRAGOVER_COMMAND, (event) => {
            return onDragover(event);
        }, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.DROP_COMMAND, (event) => {
            return onDrop(event, editor);
        }, lexical.COMMAND_PRIORITY_HIGH));
    }, [captionsEnabled, editor]);
    return null;
}
const TRANSPARENT_IMAGE = 'data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7';
const img = document.createElement('img');
img.src = TRANSPARENT_IMAGE;
function onDragStart(event) {
    const node = getImageNodeInSelection();
    if (!node) {
        return false;
    }
    const dataTransfer = event.dataTransfer;
    if (!dataTransfer) {
        return false;
    }
    dataTransfer.setData('text/plain', '_');
    dataTransfer.setDragImage(img, 0, 0);
    dataTransfer.setData('application/x-lexical-drag', JSON.stringify({
        data: {
            altText: node.__altText,
            caption: node.__caption,
            height: node.__height,
            key: node.getKey(),
            maxWidth: node.__maxWidth,
            showCaption: node.__showCaption,
            src: node.__src,
            width: node.__width,
        },
        type: 'image',
    }));
    return true;
}
function onDragover(event) {
    const node = getImageNodeInSelection();
    if (!node) {
        return false;
    }
    if (!canDropImage(event)) {
        event.preventDefault();
    }
    return true;
}
function onDrop(event, editor) {
    const node = getImageNodeInSelection();
    if (!node) {
        return false;
    }
    const data = getDragImageData(event);
    if (!data) {
        return false;
    }
    event.preventDefault();
    if (canDropImage(event)) {
        const range = getDragSelection(event);
        node.remove();
        const rangeSelection = lexical.$createRangeSelection();
        if (range !== null && range !== undefined) {
            rangeSelection.applyDOMRange(range);
        }
        lexical.$setSelection(rangeSelection);
        editor.dispatchCommand(INSERT_IMAGE_COMMAND, data);
    }
    return true;
}
function getImageNodeInSelection() {
    const selection = lexical.$getSelection();
    if (!lexical.$isNodeSelection(selection)) {
        return null;
    }
    const nodes = selection.getNodes();
    const node = nodes[0];
    return ImageNode.$isImageNode(node) ? node : null;
}
function getDragImageData(event) {
    var _a;
    const dragData = (_a = event.dataTransfer) === null || _a === void 0 ? void 0 : _a.getData('application/x-lexical-drag');
    if (!dragData) {
        return null;
    }
    const { type, data } = JSON.parse(dragData);
    if (type !== 'image') {
        return null;
    }
    return data;
}
function canDropImage(event) {
    const target = event.target;
    return !!(target &&
        target instanceof HTMLElement &&
        !target.closest('code, span.editor-image') &&
        target.parentElement &&
        target.parentElement.closest('div.ContentEditable__root'));
}
function getDragSelection(event) {
    let range;
    const target = event.target;
    const targetWindow = target == null
        ? null
        : target.nodeType === 9
            ? target.defaultView
            : target.ownerDocument.defaultView;
    const domSelection = getDOMSelection(targetWindow);
    if (document.caretRangeFromPoint) {
        range = document.caretRangeFromPoint(event.clientX, event.clientY);
    }
    else if (event.rangeParent && domSelection !== null) {
        domSelection.collapse(event.rangeParent, event.rangeOffset || 0);
        range = domSelection.getRangeAt(0);
    }
    else {
        throw Error(`Cannot get the selection when dragging`);
    }
    return range;
}

exports.INSERT_IMAGE_COMMAND = INSERT_IMAGE_COMMAND;
exports.InsertImageDialog = InsertImageDialog;
exports.InsertImageUploadedDialogBody = InsertImageUploadedDialogBody;
exports.InsertImageUriDialogBody = InsertImageUriDialogBody;
exports["default"] = ImagesPlugin;
