'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var tslib_es6 = require('../../../node_modules/tslib/tslib.es6.js');
var jsxRuntime = require('react/jsx-runtime');
var Skeleton = require('react-loading-skeleton');
var React = require('react');
var ui = require('@cpchain-foundation/ui');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var Skeleton__default = /*#__PURE__*/_interopDefaultLegacy(Skeleton);

function Image({ selected, src, onClick }) {
    return jsxRuntime.jsxs("div", { className: "my-4 relative shadow-md", children: [selected && jsxRuntime.jsx("i", { className: "icon-check-circle text-3xl text-green-500 absolute" }), jsxRuntime.jsx("img", { className: "w-40 object-contain ", onClick: () => { onClick(); }, src: src, alt: "" })] });
}
function ImageHolder() {
    return jsxRuntime.jsx("div", { className: "w-40 h-405", children: jsxRuntime.jsx(Skeleton__default["default"], { count: 5, className: "h-40 my-3" }) });
}
function ImageViewer({ images, onSelect, loading }) {
    const [img, setImg] = React.useState([]);
    const columns = [1, 2, 3, 4];
    React.useEffect(() => {
        setImg(images.map(p => { return { src: p, selected: false }; }));
    }, [images]);
    if (loading) {
        return jsxRuntime.jsx("div", { className: "w-224 h-96 overflow-y-auto flex-row flex overflow-hidden gap-4", children: columns.map((p) => jsxRuntime.jsx(ImageHolder, {}, p)) });
    }
    return jsxRuntime.jsx("div", { className: "w-224 h-96 overflow-y-auto overflow-hidden", children: jsxRuntime.jsx("ul", { className: "columns-4 gap-4", children: img.map((p, i) => {
                return jsxRuntime.jsx("li", { className: " break-inside-avoid", children: jsxRuntime.jsx(Image, { onClick: () => {
                            p.selected = !p.selected;
                            setImg([...img]);
                            onSelect(img.filter(p => p.selected).map(p => p.src));
                        }, src: p.src, selected: p.selected }) }, i);
            }) }) });
}
function ImageSelection({ onSelect, onCancel, getFiles, uploadUrl }) {
    const [images, setImages] = React.useState([]);
    const [selected, setSelected] = React.useState([]);
    const [uploadProgress, setUploadProgress] = React.useState(0);
    const [loading, setLoading] = React.useState(false);
    const [count, setCount] = React.useState(0);
    const [offset, setOffset] = React.useState(0);
    const limit = 10;
    const loadImg = React.useCallback(() => tslib_es6.__awaiter(this, void 0, void 0, function* () {
        if (getFiles) {
            setLoading(true);
            const { results: urls, count } = yield getFiles({ limit, offset });
            setImages(urls);
            setCount(count);
            setLoading(false);
        }
    }), [offset, limit]);
    React.useEffect(() => {
        loadImg();
    }, [limit, offset, getFiles]);
    const upload = (files) => {
        if (uploadUrl) {
            let xhr = new XMLHttpRequest();
            xhr.open('POST', uploadUrl, true);
            xhr.upload.onprogress = function (e) {
                if (e.lengthComputable) {
                    setUploadProgress((e.loaded / e.total) * 100);
                }
            };
            xhr.onload = function () {
                if (this.status == 200) {
                    console.log('Upload complete');
                    loadImg();
                }
            };
            let formData = new FormData();
            formData.append('file', files[0]);
            xhr.send(formData);
        }
    };
    const uploading = React.useMemo(() => {
        return uploadProgress > 0 && uploadProgress < 100;
    }, [uploadProgress]);
    return jsxRuntime.jsxs("div", { className: "bg-gray-100 py-4 px-3 flex flex-col w-224", children: [jsxRuntime.jsx("h3", { className: "border-b pb-2 border-gray-200 text-lg", children: "Add Image" }), jsxRuntime.jsx(ImageViewer, { onSelect: (images) => { setSelected(images); }, images: images, loading: loading }), jsxRuntime.jsx(ui.Pagination, { containerClassName: 'mt-5', limit: limit, count: count, offset: offset, onPageChanged: (i) => { setOffset((i - 1) * limit); } }), uploadUrl && jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx("button", { className: "cursor-pointer underline text-blue-400 my-5", disabled: uploading, onClick: () => { var _a; return (_a = document.getElementById("fileInput")) === null || _a === void 0 ? void 0 : _a.click(); }, children: uploading ? `${uploadProgress.toFixed(0)} %` : 'Upload' }), jsxRuntime.jsx("div", { className: "h-0 w-0 overflow-hidden", children: jsxRuntime.jsx("input", { type: "file", id: "fileInput", name: "fileInput", onChange: (e) => {
                                var _a, _b, _c;
                                if (((_a = e === null || e === void 0 ? void 0 : e.target) === null || _a === void 0 ? void 0 : _a.files) && ((_b = e === null || e === void 0 ? void 0 : e.target) === null || _b === void 0 ? void 0 : _b.files[0])) {
                                    upload((_c = e === null || e === void 0 ? void 0 : e.target) === null || _c === void 0 ? void 0 : _c.files);
                                }
                            } }) })] }), jsxRuntime.jsxs("div", { className: "flex flex-row justify-end gap-2 items-center my-2", children: [jsxRuntime.jsx("div", { className: "text-gray-400 cursor-pointer", onClick: () => {
                            onCancel();
                        }, children: "Cancel" }), jsxRuntime.jsx(ui.Button, { onClick: () => {
                            onSelect(selected);
                        }, children: "Confirm" })] })] });
}

exports.ImageSelection = ImageSelection;
