'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

require('react/jsx-runtime');
require('../../ui/Checkbox.css.js');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var utils = require('@lexical/utils');
var lexical = require('lexical');
var React = require('react');
var InlineImageNode = require('../../nodes/InlineImageNode.js');
require('../../ui/Button.css.js');
require('../../ui/Dialog.css.js');
require('../../ui/Input.css.js');
require('../../../node_modules/tslib/tslib.es6.js');
require('../../ui/Select.css.js');
var index = require('../../shared/index.js');

const getDOMSelection = (targetWindow) => index.CAN_USE_DOM ? (targetWindow || window).getSelection() : null;
const INSERT_INLINE_IMAGE_COMMAND = lexical.createCommand('INSERT_INLINE_IMAGE_COMMAND');
function InlineImagePlugin() {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    React.useEffect(() => {
        if (!editor.hasNodes([InlineImageNode.InlineImageNode])) {
            throw new Error('ImagesPlugin: ImageNode not registered on editor');
        }
        return utils.mergeRegister(editor.registerCommand(INSERT_INLINE_IMAGE_COMMAND, (payload) => {
            const imageNode = InlineImageNode.$createInlineImageNode(payload);
            lexical.$insertNodes([imageNode]);
            if (lexical.$isRootOrShadowRoot(imageNode.getParentOrThrow())) {
                utils.$wrapNodeInElement(imageNode, lexical.$createParagraphNode).selectEnd();
            }
            return true;
        }, lexical.COMMAND_PRIORITY_EDITOR), editor.registerCommand(lexical.DRAGSTART_COMMAND, (event) => {
            return onDragStart(event);
        }, lexical.COMMAND_PRIORITY_HIGH), editor.registerCommand(lexical.DRAGOVER_COMMAND, (event) => {
            return onDragover(event);
        }, lexical.COMMAND_PRIORITY_LOW), editor.registerCommand(lexical.DROP_COMMAND, (event) => {
            return onDrop(event, editor);
        }, lexical.COMMAND_PRIORITY_HIGH));
    }, [editor]);
    return null;
}
const TRANSPARENT_IMAGE = 'data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7';
const img = document.createElement('img');
img.src = TRANSPARENT_IMAGE;
function onDragStart(event) {
    const node = getImageNodeInSelection();
    if (!node) {
        return false;
    }
    const dataTransfer = event.dataTransfer;
    if (!dataTransfer) {
        return false;
    }
    dataTransfer.setData('text/plain', '_');
    dataTransfer.setDragImage(img, 0, 0);
    dataTransfer.setData('application/x-lexical-drag', JSON.stringify({
        data: {
            altText: node.__altText,
            caption: node.__caption,
            height: node.__height,
            key: node.getKey(),
            showCaption: node.__showCaption,
            src: node.__src,
            width: node.__width,
        },
        type: 'image',
    }));
    return true;
}
function onDragover(event) {
    const node = getImageNodeInSelection();
    if (!node) {
        return false;
    }
    if (!canDropImage(event)) {
        event.preventDefault();
    }
    return true;
}
function onDrop(event, editor) {
    const node = getImageNodeInSelection();
    if (!node) {
        return false;
    }
    const data = getDragImageData(event);
    if (!data) {
        return false;
    }
    event.preventDefault();
    if (canDropImage(event)) {
        const range = getDragSelection(event);
        node.remove();
        const rangeSelection = lexical.$createRangeSelection();
        if (range !== null && range !== undefined) {
            rangeSelection.applyDOMRange(range);
        }
        lexical.$setSelection(rangeSelection);
        editor.dispatchCommand(INSERT_INLINE_IMAGE_COMMAND, data);
    }
    return true;
}
function getImageNodeInSelection() {
    const selection = lexical.$getSelection();
    if (!lexical.$isNodeSelection(selection)) {
        return null;
    }
    const nodes = selection.getNodes();
    const node = nodes[0];
    return InlineImageNode.$isInlineImageNode(node) ? node : null;
}
function getDragImageData(event) {
    var _a;
    const dragData = (_a = event.dataTransfer) === null || _a === void 0 ? void 0 : _a.getData('application/x-lexical-drag');
    if (!dragData) {
        return null;
    }
    const { type, data } = JSON.parse(dragData);
    if (type !== 'image') {
        return null;
    }
    return data;
}
function canDropImage(event) {
    const target = event.target;
    return !!(target &&
        target instanceof HTMLElement &&
        !target.closest('code, span.editor-image') &&
        target.parentElement &&
        target.parentElement.closest('div.ContentEditable__root'));
}
function getDragSelection(event) {
    let range;
    const target = event.target;
    const targetWindow = target == null
        ? null
        : target.nodeType === 9
            ? target.defaultView
            : target.ownerDocument.defaultView;
    const domSelection = getDOMSelection(targetWindow);
    if (document.caretRangeFromPoint) {
        range = document.caretRangeFromPoint(event.clientX, event.clientY);
    }
    else if (event.rangeParent && domSelection !== null) {
        domSelection.collapse(event.rangeParent, event.rangeOffset || 0);
        range = domSelection.getRangeAt(0);
    }
    else {
        throw Error('Cannot get the selection when dragging');
    }
    return range;
}

exports.INSERT_INLINE_IMAGE_COMMAND = INSERT_INLINE_IMAGE_COMMAND;
exports["default"] = InlineImagePlugin;
