'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var list = require('@lexical/list');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var lexical = require('lexical');
var React = require('react');

/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */
function getElementNodesInSelection(selection) {
    const nodesInSelection = selection.getNodes();
    if (nodesInSelection.length === 0) {
        return new Set([
            selection.anchor.getNode().getParentOrThrow(),
            selection.focus.getNode().getParentOrThrow(),
        ]);
    }
    return new Set(nodesInSelection.map((n) => (lexical.$isElementNode(n) ? n : n.getParentOrThrow())));
}
function isIndentPermitted(maxDepth) {
    const selection = lexical.$getSelection();
    if (!lexical.$isRangeSelection(selection)) {
        return false;
    }
    const elementNodesInSelection = getElementNodesInSelection(selection);
    let totalDepth = 0;
    for (const elementNode of elementNodesInSelection) {
        if (list.$isListNode(elementNode)) {
            totalDepth = Math.max(list.$getListDepth(elementNode) + 1, totalDepth);
        }
        else if (list.$isListItemNode(elementNode)) {
            const parent = elementNode.getParent();
            if (!list.$isListNode(parent)) {
                throw new Error('ListMaxIndentLevelPlugin: A ListItemNode must have a ListNode for a parent.');
            }
            totalDepth = Math.max(list.$getListDepth(parent) + 1, totalDepth);
        }
    }
    return totalDepth <= maxDepth;
}
function ListMaxIndentLevelPlugin({ maxDepth }) {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    React.useEffect(() => {
        return editor.registerCommand(lexical.INDENT_CONTENT_COMMAND, () => !isIndentPermitted(maxDepth !== null && maxDepth !== void 0 ? maxDepth : 7), lexical.COMMAND_PRIORITY_CRITICAL);
    }, [editor, maxDepth]);
    return null;
}

exports["default"] = ListMaxIndentLevelPlugin;
