'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var selection = require('@lexical/selection');
var utils = require('@lexical/utils');
var lexical = require('lexical');
var React = require('react');

/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */
function MaxLengthPlugin({ maxLength }) {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    React.useEffect(() => {
        let lastRestoredEditorState = null;
        return editor.registerNodeTransform(lexical.RootNode, (rootNode) => {
            const selection$1 = lexical.$getSelection();
            if (!lexical.$isRangeSelection(selection$1) || !selection$1.isCollapsed()) {
                return;
            }
            const prevEditorState = editor.getEditorState();
            const prevTextContentSize = prevEditorState.read(() => rootNode.getTextContentSize());
            const textContentSize = rootNode.getTextContentSize();
            if (prevTextContentSize !== textContentSize) {
                const delCount = textContentSize - maxLength;
                const anchor = selection$1.anchor;
                if (delCount > 0) {
                    // Restore the old editor state instead if the last
                    // text content was already at the limit.
                    if (prevTextContentSize === maxLength &&
                        lastRestoredEditorState !== prevEditorState) {
                        lastRestoredEditorState = prevEditorState;
                        utils.$restoreEditorState(editor, prevEditorState);
                    }
                    else {
                        selection.trimTextContentFromAnchor(editor, anchor, delCount);
                    }
                }
            }
        });
    }, [editor, maxLength]);
    return null;
}

exports.MaxLengthPlugin = MaxLengthPlugin;
