'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var utils = require('@lexical/utils');
var lexical = require('lexical');
var React = require('react');
var index = require('../../nodes/PageBreakNode/index.js');

/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */
const INSERT_PAGE_BREAK = lexical.createCommand();
function PageBreakPlugin() {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    React.useEffect(() => {
        if (!editor.hasNodes([index.PageBreakNode]))
            throw new Error('PageBreakPlugin: PageBreakNode is not registered on editor');
        return utils.mergeRegister(editor.registerCommand(INSERT_PAGE_BREAK, () => {
            const selection = lexical.$getSelection();
            if (!lexical.$isRangeSelection(selection))
                return false;
            const focusNode = selection.focus.getNode();
            if (focusNode !== null) {
                const pgBreak = index.$createPageBreakNode();
                utils.$insertNodeToNearestRoot(pgBreak);
            }
            return true;
        }, lexical.COMMAND_PRIORITY_EDITOR));
    }, [editor]);
    return null;
}

exports.INSERT_PAGE_BREAK = INSERT_PAGE_BREAK;
exports["default"] = PageBreakPlugin;
