'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var utils = require('@lexical/utils');
var lexical = require('lexical');
var React = require('react');
var PollNode = require('../../nodes/PollNode.js');
var Button = require('../../ui/Button.js');
var Dialog = require('../../ui/Dialog.js');
var TextInput = require('../../ui/TextInput.js');

const INSERT_POLL_COMMAND = lexical.createCommand('INSERT_POLL_COMMAND');
function InsertPollDialog({ activeEditor, onClose, }) {
    const [question, setQuestion] = React.useState('');
    const onClick = () => {
        activeEditor.dispatchCommand(INSERT_POLL_COMMAND, question);
        onClose();
    };
    return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx(TextInput["default"], { label: "Question", onChange: setQuestion, value: question }), jsxRuntime.jsx(Dialog.DialogActions, { children: jsxRuntime.jsx(Button["default"], { disabled: question.trim() === '', onClick: onClick, children: "Confirm" }) })] }));
}
function PollPlugin() {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    React.useEffect(() => {
        if (!editor.hasNodes([PollNode.PollNode])) {
            throw new Error('PollPlugin: PollNode not registered on editor');
        }
        return editor.registerCommand(INSERT_POLL_COMMAND, (payload) => {
            const pollNode = PollNode.$createPollNode(payload, [
                PollNode.createPollOption(),
                PollNode.createPollOption(),
            ]);
            lexical.$insertNodes([pollNode]);
            if (lexical.$isRootOrShadowRoot(pollNode.getParentOrThrow())) {
                utils.$wrapNodeInElement(pollNode, lexical.$createParagraphNode).selectEnd();
            }
            return true;
        }, lexical.COMMAND_PRIORITY_EDITOR);
    }, [editor]);
    return null;
}

exports.INSERT_POLL_COMMAND = INSERT_POLL_COMMAND;
exports.InsertPollDialog = InsertPollDialog;
exports["default"] = PollPlugin;
