'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var lexical = require('lexical');
var React = require('react');
var useReport = require('../../hooks/useReport.js');

/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */
const SPEECH_TO_TEXT_COMMAND = lexical.createCommand('SPEECH_TO_TEXT_COMMAND');
const VOICE_COMMANDS = {
    '\n': ({ selection }) => {
        selection.insertParagraph();
    },
    redo: ({ editor }) => {
        editor.dispatchCommand(lexical.REDO_COMMAND, undefined);
    },
    undo: ({ editor }) => {
        editor.dispatchCommand(lexical.UNDO_COMMAND, undefined);
    },
};
const SUPPORT_SPEECH_RECOGNITION = 'SpeechRecognition' in window || 'webkitSpeechRecognition' in window;
function SpeechToTextPlugin() {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const [isEnabled, setIsEnabled] = React.useState(false);
    const SpeechRecognition = 
    // @ts-ignore
    window.SpeechRecognition || window.webkitSpeechRecognition;
    const recognition = React.useRef(null);
    const report = useReport["default"]();
    React.useEffect(() => {
        if (isEnabled && recognition.current === null) {
            recognition.current = new SpeechRecognition();
            recognition.current.continuous = true;
            recognition.current.interimResults = true;
            recognition.current.addEventListener('result', (event) => {
                const resultItem = event.results.item(event.resultIndex);
                const { transcript } = resultItem.item(0);
                report(transcript);
                if (!resultItem.isFinal) {
                    return;
                }
                editor.update(() => {
                    const selection = lexical.$getSelection();
                    if (lexical.$isRangeSelection(selection)) {
                        const command = VOICE_COMMANDS[transcript.toLowerCase().trim()];
                        if (command) {
                            command({
                                editor,
                                selection,
                            });
                        }
                        else if (transcript.match(/\s*\n\s*/)) {
                            selection.insertParagraph();
                        }
                        else {
                            selection.insertText(transcript);
                        }
                    }
                });
            });
        }
        if (recognition.current) {
            if (isEnabled) {
                recognition.current.start();
            }
            else {
                recognition.current.stop();
            }
        }
        return () => {
            if (recognition.current !== null) {
                recognition.current.stop();
            }
        };
    }, [SpeechRecognition, editor, isEnabled, report]);
    React.useEffect(() => {
        return editor.registerCommand(SPEECH_TO_TEXT_COMMAND, (_isEnabled) => {
            setIsEnabled(_isEnabled);
            return true;
        }, lexical.COMMAND_PRIORITY_EDITOR);
    }, [editor]);
    return null;
}
var SpeechToTextPlugin$1 = (SUPPORT_SPEECH_RECOGNITION
    ? SpeechToTextPlugin
    : () => null);

exports.SPEECH_TO_TEXT_COMMAND = SPEECH_TO_TEXT_COMMAND;
exports.SUPPORT_SPEECH_RECOGNITION = SUPPORT_SPEECH_RECOGNITION;
exports["default"] = SpeechToTextPlugin$1;
