'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var lexical = require('lexical');
var React = require('react');

/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */
const COMMAND_PRIORITY_LOW = 1;
const TAB_TO_FOCUS_INTERVAL = 100;
let lastTabKeyDownTimestamp = 0;
let hasRegisteredKeyDownListener = false;
function registerKeyTimeStampTracker() {
    window.addEventListener('keydown', (event) => {
        // Tab
        if (event.keyCode === 9) {
            lastTabKeyDownTimestamp = event.timeStamp;
        }
    }, true);
}
function TabFocusPlugin() {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    React.useEffect(() => {
        if (!hasRegisteredKeyDownListener) {
            registerKeyTimeStampTracker();
            hasRegisteredKeyDownListener = true;
        }
        return editor.registerCommand(lexical.FOCUS_COMMAND, (event) => {
            const selection = lexical.$getSelection();
            if (lexical.$isRangeSelection(selection)) {
                if (lastTabKeyDownTimestamp + TAB_TO_FOCUS_INTERVAL >
                    event.timeStamp) {
                    lexical.$setSelection(selection.clone());
                }
            }
            return false;
        }, COMMAND_PRIORITY_LOW);
    }, [editor]);
    return null;
}

exports["default"] = TabFocusPlugin;
