'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var useLexicalEditable = require('@lexical/react/useLexicalEditable');
var table = require('@lexical/table');
var lexical = require('lexical');
var React = require('react');
var ReactDOM = require('react-dom');
var useModal = require('../../hooks/useModal.js');
var ColorPicker = require('../../ui/ColorPicker.js');
var index = require('../../shared/index.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var useLexicalEditable__default = /*#__PURE__*/_interopDefaultLegacy(useLexicalEditable);

function computeSelectionCount(selection) {
    const selectionShape = selection.getShape();
    return {
        columns: selectionShape.toX - selectionShape.fromX + 1,
        rows: selectionShape.toY - selectionShape.fromY + 1,
    };
}
// This is important when merging cells as there is no good way to re-merge weird shapes (a result
// of selecting merged cells and non-merged)
function isGridSelectionRectangular(selection) {
    const nodes = selection.getNodes();
    const currentRows = [];
    let currentRow = null;
    let expectedColumns = null;
    let currentColumns = 0;
    for (let i = 0; i < nodes.length; i++) {
        const node = nodes[i];
        if (table.$isTableCellNode(node)) {
            const row = node.getParentOrThrow();
            index.invariant(table.$isTableRowNode(row), 'Expected CellNode to have a RowNode parent');
            if (currentRow !== row) {
                if (expectedColumns !== null && currentColumns !== expectedColumns) {
                    return false;
                }
                if (currentRow !== null) {
                    expectedColumns = currentColumns;
                }
                currentRow = row;
                currentColumns = 0;
            }
            const colSpan = node.__colSpan;
            for (let j = 0; j < colSpan; j++) {
                if (currentRows[currentColumns + j] === undefined) {
                    currentRows[currentColumns + j] = 0;
                }
                currentRows[currentColumns + j] += node.__rowSpan;
            }
            currentColumns += colSpan;
        }
    }
    return ((expectedColumns === null || currentColumns === expectedColumns) &&
        currentRows.every((v) => v === currentRows[0]));
}
function $canUnmerge() {
    const selection = lexical.$getSelection();
    if ((lexical.$isRangeSelection(selection) && !selection.isCollapsed()) ||
        (lexical.DEPRECATED_$isGridSelection(selection) &&
            !selection.anchor.is(selection.focus)) ||
        (!lexical.$isRangeSelection(selection) && !lexical.DEPRECATED_$isGridSelection(selection))) {
        return false;
    }
    const [cell] = lexical.DEPRECATED_$getNodeTriplet(selection.anchor);
    return cell.__colSpan > 1 || cell.__rowSpan > 1;
}
function $cellContainsEmptyParagraph(cell) {
    if (cell.getChildrenSize() !== 1) {
        return false;
    }
    const firstChild = cell.getFirstChildOrThrow();
    if (!lexical.$isParagraphNode(firstChild) || !firstChild.isEmpty()) {
        return false;
    }
    return true;
}
function $selectLastDescendant(node) {
    const lastDescendant = node.getLastDescendant();
    if (lexical.$isTextNode(lastDescendant)) {
        lastDescendant.select();
    }
    else if (lexical.$isElementNode(lastDescendant)) {
        lastDescendant.selectEnd();
    }
    else if (lastDescendant !== null) {
        lastDescendant.selectNext();
    }
}
function currentCellBackgroundColor(editor) {
    return editor.getEditorState().read(() => {
        const selection = lexical.$getSelection();
        if (lexical.$isRangeSelection(selection) ||
            lexical.DEPRECATED_$isGridSelection(selection)) {
            const [cell] = lexical.DEPRECATED_$getNodeTriplet(selection.anchor);
            if (table.$isTableCellNode(cell)) {
                return cell.getBackgroundColor();
            }
        }
        return null;
    });
}
function TableActionMenu({ onClose, tableCellNode: _tableCellNode, setIsMenuOpen, contextRef, cellMerge, showColorPickerModal, }) {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const dropDownRef = React.useRef(null);
    const [tableCellNode, updateTableCellNode] = React.useState(_tableCellNode);
    const [selectionCounts, updateSelectionCounts] = React.useState({
        columns: 1,
        rows: 1,
    });
    const [canMergeCells, setCanMergeCells] = React.useState(false);
    const [canUnmergeCell, setCanUnmergeCell] = React.useState(false);
    const [backgroundColor, setBackgroundColor] = React.useState(() => currentCellBackgroundColor(editor) || '');
    React.useEffect(() => {
        return editor.registerMutationListener(table.TableCellNode, (nodeMutations) => {
            const nodeUpdated = nodeMutations.get(tableCellNode.getKey()) === 'updated';
            if (nodeUpdated) {
                editor.getEditorState().read(() => {
                    updateTableCellNode(tableCellNode.getLatest());
                });
                setBackgroundColor(currentCellBackgroundColor(editor) || '');
            }
        });
    }, [editor, tableCellNode]);
    React.useEffect(() => {
        editor.getEditorState().read(() => {
            const selection = lexical.$getSelection();
            // Merge cells
            if (lexical.DEPRECATED_$isGridSelection(selection)) {
                const currentSelectionCounts = computeSelectionCount(selection);
                updateSelectionCounts(computeSelectionCount(selection));
                setCanMergeCells(isGridSelectionRectangular(selection) &&
                    (currentSelectionCounts.columns > 1 ||
                        currentSelectionCounts.rows > 1));
            }
            // Unmerge cell
            setCanUnmergeCell($canUnmerge());
        });
    }, [editor]);
    React.useEffect(() => {
        const menuButtonElement = contextRef.current;
        const dropDownElement = dropDownRef.current;
        const rootElement = editor.getRootElement();
        if (menuButtonElement != null &&
            dropDownElement != null &&
            rootElement != null) {
            const rootEleRect = rootElement.getBoundingClientRect();
            const menuButtonRect = menuButtonElement.getBoundingClientRect();
            dropDownElement.style.opacity = '1';
            const dropDownElementRect = dropDownElement.getBoundingClientRect();
            const margin = 5;
            let leftPosition = menuButtonRect.right + margin;
            if (leftPosition + dropDownElementRect.width > window.innerWidth ||
                leftPosition + dropDownElementRect.width > rootEleRect.right) {
                const position = menuButtonRect.left - dropDownElementRect.width - margin;
                leftPosition = (position < 0 ? margin : position) + window.pageXOffset;
            }
            dropDownElement.style.left = `${leftPosition + window.pageXOffset}px`;
            let topPosition = menuButtonRect.top;
            if (topPosition + dropDownElementRect.height > window.innerHeight) {
                const position = menuButtonRect.bottom - dropDownElementRect.height;
                topPosition = (position < 0 ? margin : position) + window.pageYOffset;
            }
            dropDownElement.style.top = `${topPosition + +window.pageYOffset}px`;
        }
    }, [contextRef, dropDownRef, editor]);
    React.useEffect(() => {
        function handleClickOutside(event) {
            if (dropDownRef.current != null &&
                contextRef.current != null &&
                !dropDownRef.current.contains(event.target) &&
                !contextRef.current.contains(event.target)) {
                setIsMenuOpen(false);
            }
        }
        window.addEventListener('click', handleClickOutside);
        return () => window.removeEventListener('click', handleClickOutside);
    }, [setIsMenuOpen, contextRef]);
    const clearTableSelection = React.useCallback(() => {
        editor.update(() => {
            if (tableCellNode.isAttached()) {
                const tableNode = table.$getTableNodeFromLexicalNodeOrThrow(tableCellNode);
                const tableElement = editor.getElementByKey(tableNode.getKey());
                if (!tableElement) {
                    throw new Error('Expected to find tableElement in DOM');
                }
                const tableSelection = table.getTableSelectionFromTableElement(tableElement);
                if (tableSelection !== null) {
                    tableSelection.clearHighlight();
                }
                tableNode.markDirty();
                updateTableCellNode(tableCellNode.getLatest());
            }
            const rootNode = lexical.$getRoot();
            rootNode.selectStart();
        });
    }, [editor, tableCellNode]);
    const mergeTableCellsAtSelection = () => {
        editor.update(() => {
            const selection = lexical.$getSelection();
            if (lexical.DEPRECATED_$isGridSelection(selection)) {
                const { columns, rows } = computeSelectionCount(selection);
                const nodes = selection.getNodes();
                let firstCell = null;
                for (let i = 0; i < nodes.length; i++) {
                    const node = nodes[i];
                    if (lexical.DEPRECATED_$isGridCellNode(node)) {
                        if (firstCell === null) {
                            node.setColSpan(columns).setRowSpan(rows);
                            firstCell = node;
                            const isEmpty = $cellContainsEmptyParagraph(node);
                            let firstChild;
                            if (isEmpty &&
                                lexical.$isParagraphNode((firstChild = node.getFirstChild()))) {
                                firstChild.remove();
                            }
                        }
                        else if (lexical.DEPRECATED_$isGridCellNode(firstCell)) {
                            const isEmpty = $cellContainsEmptyParagraph(node);
                            if (!isEmpty) {
                                firstCell.append(...node.getChildren());
                            }
                            node.remove();
                        }
                    }
                }
                if (firstCell !== null) {
                    if (firstCell.getChildrenSize() === 0) {
                        firstCell.append(lexical.$createParagraphNode());
                    }
                    $selectLastDescendant(firstCell);
                }
                onClose();
            }
        });
    };
    const unmergeTableCellsAtSelection = () => {
        editor.update(() => {
            table.$unmergeCell();
        });
    };
    const insertTableRowAtSelection = React.useCallback((shouldInsertAfter) => {
        editor.update(() => {
            table.$insertTableRow__EXPERIMENTAL(shouldInsertAfter);
            onClose();
        });
    }, [editor, onClose]);
    const insertTableColumnAtSelection = React.useCallback((shouldInsertAfter) => {
        editor.update(() => {
            for (let i = 0; i < selectionCounts.columns; i++) {
                table.$insertTableColumn__EXPERIMENTAL(shouldInsertAfter);
            }
            onClose();
        });
    }, [editor, onClose, selectionCounts.columns]);
    const deleteTableRowAtSelection = React.useCallback(() => {
        editor.update(() => {
            table.$deleteTableRow__EXPERIMENTAL();
            onClose();
        });
    }, [editor, onClose]);
    const deleteTableAtSelection = React.useCallback(() => {
        editor.update(() => {
            const tableNode = table.$getTableNodeFromLexicalNodeOrThrow(tableCellNode);
            tableNode.remove();
            clearTableSelection();
            onClose();
        });
    }, [editor, tableCellNode, clearTableSelection, onClose]);
    const deleteTableColumnAtSelection = React.useCallback(() => {
        editor.update(() => {
            table.$deleteTableColumn__EXPERIMENTAL();
            onClose();
        });
    }, [editor, onClose]);
    const toggleTableRowIsHeader = React.useCallback(() => {
        editor.update(() => {
            const tableNode = table.$getTableNodeFromLexicalNodeOrThrow(tableCellNode);
            const tableRowIndex = table.$getTableRowIndexFromTableCellNode(tableCellNode);
            const tableRows = tableNode.getChildren();
            if (tableRowIndex >= tableRows.length || tableRowIndex < 0) {
                throw new Error('Expected table cell to be inside of table row.');
            }
            const tableRow = tableRows[tableRowIndex];
            if (!table.$isTableRowNode(tableRow)) {
                throw new Error('Expected table row');
            }
            tableRow.getChildren().forEach((tableCell) => {
                if (!table.$isTableCellNode(tableCell)) {
                    throw new Error('Expected table cell');
                }
                tableCell.toggleHeaderStyle(table.TableCellHeaderStates.ROW);
            });
            clearTableSelection();
            onClose();
        });
    }, [editor, tableCellNode, clearTableSelection, onClose]);
    const toggleTableColumnIsHeader = React.useCallback(() => {
        editor.update(() => {
            const tableNode = table.$getTableNodeFromLexicalNodeOrThrow(tableCellNode);
            const tableColumnIndex = table.$getTableColumnIndexFromTableCellNode(tableCellNode);
            const tableRows = tableNode.getChildren();
            for (let r = 0; r < tableRows.length; r++) {
                const tableRow = tableRows[r];
                if (!table.$isTableRowNode(tableRow)) {
                    throw new Error('Expected table row');
                }
                const tableCells = tableRow.getChildren();
                if (tableColumnIndex >= tableCells.length || tableColumnIndex < 0) {
                    throw new Error('Expected table cell to be inside of table row.');
                }
                const tableCell = tableCells[tableColumnIndex];
                if (!table.$isTableCellNode(tableCell)) {
                    throw new Error('Expected table cell');
                }
                tableCell.toggleHeaderStyle(table.TableCellHeaderStates.COLUMN);
            }
            clearTableSelection();
            onClose();
        });
    }, [editor, tableCellNode, clearTableSelection, onClose]);
    const handleCellBackgroundColor = React.useCallback((value) => {
        editor.update(() => {
            const selection = lexical.$getSelection();
            if (lexical.$isRangeSelection(selection) ||
                lexical.DEPRECATED_$isGridSelection(selection)) {
                const [cell] = lexical.DEPRECATED_$getNodeTriplet(selection.anchor);
                if (table.$isTableCellNode(cell)) {
                    cell.setBackgroundColor(value);
                }
            }
        });
    }, [editor]);
    let mergeCellButton = null;
    if (cellMerge) {
        if (canMergeCells) {
            mergeCellButton = (jsxRuntime.jsx("button", { className: "item", onClick: () => mergeTableCellsAtSelection(), "data-test-id": "table-merge-cells", children: "Merge cells" }));
        }
        else if (canUnmergeCell) {
            mergeCellButton = (jsxRuntime.jsx("button", { className: "item", onClick: () => unmergeTableCellsAtSelection(), "data-test-id": "table-unmerge-cells", children: "Unmerge cells" }));
        }
    }
    return ReactDOM.createPortal(
    // eslint-disable-next-line jsx-a11y/no-static-element-interactions
    jsxRuntime.jsxs("div", { className: "dropdown", ref: dropDownRef, onClick: (e) => {
            e.stopPropagation();
        }, children: [mergeCellButton, jsxRuntime.jsx("button", { className: "item", onClick: () => showColorPickerModal('Cell background color', () => (jsxRuntime.jsx(ColorPicker["default"], { color: backgroundColor, onChange: handleCellBackgroundColor }))), "data-test-id": "table-background-color", children: jsxRuntime.jsx("span", { className: "text", children: "Background color" }) }), jsxRuntime.jsx("hr", {}), jsxRuntime.jsx("button", { className: "item", onClick: () => insertTableRowAtSelection(false), "data-test-id": "table-insert-row-above", children: jsxRuntime.jsxs("span", { className: "text", children: ["Insert", ' ', selectionCounts.rows === 1 ? 'row' : `${selectionCounts.rows} rows`, ' ', "above"] }) }), jsxRuntime.jsx("button", { className: "item", onClick: () => insertTableRowAtSelection(true), "data-test-id": "table-insert-row-below", children: jsxRuntime.jsxs("span", { className: "text", children: ["Insert", ' ', selectionCounts.rows === 1 ? 'row' : `${selectionCounts.rows} rows`, ' ', "below"] }) }), jsxRuntime.jsx("hr", {}), jsxRuntime.jsx("button", { className: "item", onClick: () => insertTableColumnAtSelection(false), "data-test-id": "table-insert-column-before", children: jsxRuntime.jsxs("span", { className: "text", children: ["Insert", ' ', selectionCounts.columns === 1
                            ? 'column'
                            : `${selectionCounts.columns} columns`, ' ', "left"] }) }), jsxRuntime.jsx("button", { className: "item", onClick: () => insertTableColumnAtSelection(true), "data-test-id": "table-insert-column-after", children: jsxRuntime.jsxs("span", { className: "text", children: ["Insert", ' ', selectionCounts.columns === 1
                            ? 'column'
                            : `${selectionCounts.columns} columns`, ' ', "right"] }) }), jsxRuntime.jsx("hr", {}), jsxRuntime.jsx("button", { className: "item", onClick: () => deleteTableColumnAtSelection(), "data-test-id": "table-delete-columns", children: jsxRuntime.jsx("span", { className: "text", children: "Delete column" }) }), jsxRuntime.jsx("button", { className: "item", onClick: () => deleteTableRowAtSelection(), "data-test-id": "table-delete-rows", children: jsxRuntime.jsx("span", { className: "text", children: "Delete row" }) }), jsxRuntime.jsx("button", { className: "item", onClick: () => deleteTableAtSelection(), "data-test-id": "table-delete", children: jsxRuntime.jsx("span", { className: "text", children: "Delete table" }) }), jsxRuntime.jsx("hr", {}), jsxRuntime.jsx("button", { className: "item", onClick: () => toggleTableRowIsHeader(), children: jsxRuntime.jsxs("span", { className: "text", children: [(tableCellNode.__headerState & table.TableCellHeaderStates.ROW) ===
                            table.TableCellHeaderStates.ROW
                            ? 'Remove'
                            : 'Add', ' ', "row header"] }) }), jsxRuntime.jsx("button", { className: "item", onClick: () => toggleTableColumnIsHeader(), children: jsxRuntime.jsxs("span", { className: "text", children: [(tableCellNode.__headerState & table.TableCellHeaderStates.COLUMN) ===
                            table.TableCellHeaderStates.COLUMN
                            ? 'Remove'
                            : 'Add', ' ', "column header"] }) })] }), document.body);
}
function TableCellActionMenuContainer({ anchorElem, cellMerge, }) {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const menuButtonRef = React.useRef(null);
    const menuRootRef = React.useRef(null);
    const [isMenuOpen, setIsMenuOpen] = React.useState(false);
    const [tableCellNode, setTableMenuCellNode] = React.useState(null);
    const [colorPickerModal, showColorPickerModal] = useModal["default"]();
    const moveMenu = React.useCallback(() => {
        const menu = menuButtonRef.current;
        const selection = lexical.$getSelection();
        const nativeSelection = window.getSelection();
        const activeElement = document.activeElement;
        if (selection == null || menu == null) {
            setTableMenuCellNode(null);
            return;
        }
        const rootElement = editor.getRootElement();
        if (lexical.$isRangeSelection(selection) &&
            rootElement !== null &&
            nativeSelection !== null &&
            rootElement.contains(nativeSelection.anchorNode)) {
            const tableCellNodeFromSelection = table.$getTableCellNodeFromLexicalNode(selection.anchor.getNode());
            if (tableCellNodeFromSelection == null) {
                setTableMenuCellNode(null);
                return;
            }
            const tableCellParentNodeDOM = editor.getElementByKey(tableCellNodeFromSelection.getKey());
            if (tableCellParentNodeDOM == null) {
                setTableMenuCellNode(null);
                return;
            }
            setTableMenuCellNode(tableCellNodeFromSelection);
        }
        else if (!activeElement) {
            setTableMenuCellNode(null);
        }
    }, [editor]);
    React.useEffect(() => {
        return editor.registerUpdateListener(() => {
            editor.getEditorState().read(() => {
                moveMenu();
            });
        });
    });
    React.useEffect(() => {
        const menuButtonDOM = menuButtonRef.current;
        if (menuButtonDOM != null && tableCellNode != null) {
            const tableCellNodeDOM = editor.getElementByKey(tableCellNode.getKey());
            if (tableCellNodeDOM != null) {
                const tableCellRect = tableCellNodeDOM.getBoundingClientRect();
                const menuRect = menuButtonDOM.getBoundingClientRect();
                const anchorRect = anchorElem.getBoundingClientRect();
                const top = tableCellRect.top - anchorRect.top + 4;
                const left = tableCellRect.right - menuRect.width - 10 - anchorRect.left;
                menuButtonDOM.style.opacity = '1';
                menuButtonDOM.style.transform = `translate(${left}px, ${top}px)`;
            }
            else {
                menuButtonDOM.style.opacity = '0';
                menuButtonDOM.style.transform = 'translate(-10000px, -10000px)';
            }
        }
    }, [menuButtonRef, tableCellNode, editor, anchorElem]);
    const prevTableCellDOM = React.useRef(tableCellNode);
    React.useEffect(() => {
        if (prevTableCellDOM.current !== tableCellNode) {
            setIsMenuOpen(false);
        }
        prevTableCellDOM.current = tableCellNode;
    }, [prevTableCellDOM, tableCellNode]);
    return (jsxRuntime.jsx("div", { className: "table-cell-action-button-container", ref: menuButtonRef, children: tableCellNode != null && (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx("button", { className: "table-cell-action-button chevron-down", onClick: (e) => {
                        e.stopPropagation();
                        setIsMenuOpen(!isMenuOpen);
                    }, ref: menuRootRef, children: jsxRuntime.jsx("i", { className: "chevron-down" }) }), colorPickerModal, isMenuOpen && (jsxRuntime.jsx(TableActionMenu, { contextRef: menuRootRef, setIsMenuOpen: setIsMenuOpen, onClose: () => setIsMenuOpen(false), tableCellNode: tableCellNode, cellMerge: cellMerge, showColorPickerModal: showColorPickerModal }))] })) }));
}
function TableActionMenuPlugin({ anchorElem = document.body, cellMerge = false, }) {
    const isEditable = useLexicalEditable__default["default"]();
    return ReactDOM.createPortal(isEditable ? (jsxRuntime.jsx(TableCellActionMenuContainer, { anchorElem: anchorElem, cellMerge: cellMerge })) : null, anchorElem);
}

exports["default"] = TableActionMenuPlugin;
