'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
require('./index.css.js');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var useLexicalEditable = require('@lexical/react/useLexicalEditable');
var table = require('@lexical/table');
var lexical = require('lexical');
var React = require('react');
var ReactDOM = require('react-dom');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var useLexicalEditable__default = /*#__PURE__*/_interopDefaultLegacy(useLexicalEditable);

const MIN_ROW_HEIGHT = 33;
const MIN_COLUMN_WIDTH = 50;
function TableCellResizer({ editor }) {
    const targetRef = React.useRef(null);
    const resizerRef = React.useRef(null);
    const tableRectRef = React.useRef(null);
    const mouseStartPosRef = React.useRef(null);
    const [mouseCurrentPos, updateMouseCurrentPos] = React.useState(null);
    const [activeCell, updateActiveCell] = React.useState(null);
    const [isSelectingGrid, updateIsSelectingGrid] = React.useState(false);
    const [draggingDirection, updateDraggingDirection] = React.useState(null);
    React.useEffect(() => {
        return editor.registerCommand(lexical.SELECTION_CHANGE_COMMAND, (payload) => {
            const selection = lexical.$getSelection();
            const isGridSelection = lexical.DEPRECATED_$isGridSelection(selection);
            if (isSelectingGrid !== isGridSelection) {
                updateIsSelectingGrid(isGridSelection);
            }
            return false;
        }, lexical.COMMAND_PRIORITY_HIGH);
    });
    const resetState = React.useCallback(() => {
        updateActiveCell(null);
        targetRef.current = null;
        updateDraggingDirection(null);
        mouseStartPosRef.current = null;
        tableRectRef.current = null;
    }, []);
    React.useEffect(() => {
        const onMouseMove = (event) => {
            setTimeout(() => {
                const target = event.target;
                if (draggingDirection) {
                    updateMouseCurrentPos({
                        x: event.clientX,
                        y: event.clientY,
                    });
                    return;
                }
                if (resizerRef.current && resizerRef.current.contains(target)) {
                    return;
                }
                if (targetRef.current !== target) {
                    targetRef.current = target;
                    const cell = table.getCellFromTarget(target);
                    if (cell && activeCell !== cell) {
                        editor.update(() => {
                            const tableCellNode = lexical.$getNearestNodeFromDOMNode(cell.elem);
                            if (!tableCellNode) {
                                throw new Error('TableCellResizer: Table cell node not found.');
                            }
                            const tableNode = table.$getTableNodeFromLexicalNodeOrThrow(tableCellNode);
                            const tableElement = editor.getElementByKey(tableNode.getKey());
                            if (!tableElement) {
                                throw new Error('TableCellResizer: Table element not found.');
                            }
                            targetRef.current = target;
                            tableRectRef.current = tableElement.getBoundingClientRect();
                            updateActiveCell(cell);
                        });
                    }
                    else if (cell == null) {
                        resetState();
                    }
                }
            }, 0);
        };
        document.addEventListener('mousemove', onMouseMove);
        return () => {
            document.removeEventListener('mousemove', onMouseMove);
        };
    }, [activeCell, draggingDirection, editor, resetState]);
    const isHeightChanging = (direction) => {
        if (direction === 'bottom')
            return true;
        return false;
    };
    const updateRowHeight = React.useCallback((newHeight) => {
        if (!activeCell) {
            throw new Error('TableCellResizer: Expected active cell.');
        }
        editor.update(() => {
            const tableCellNode = lexical.$getNearestNodeFromDOMNode(activeCell.elem);
            if (!table.$isTableCellNode(tableCellNode)) {
                throw new Error('TableCellResizer: Table cell node not found.');
            }
            const tableNode = table.$getTableNodeFromLexicalNodeOrThrow(tableCellNode);
            const tableRowIndex = table.$getTableRowIndexFromTableCellNode(tableCellNode);
            const tableRows = tableNode.getChildren();
            if (tableRowIndex >= tableRows.length || tableRowIndex < 0) {
                throw new Error('Expected table cell to be inside of table row.');
            }
            const tableRow = tableRows[tableRowIndex];
            if (!table.$isTableRowNode(tableRow)) {
                throw new Error('Expected table row');
            }
            tableRow.setHeight(newHeight);
        });
    }, [activeCell, editor]);
    const updateColumnWidth = React.useCallback((newWidth) => {
        if (!activeCell) {
            throw new Error('TableCellResizer: Expected active cell.');
        }
        editor.update(() => {
            const tableCellNode = lexical.$getNearestNodeFromDOMNode(activeCell.elem);
            if (!table.$isTableCellNode(tableCellNode)) {
                throw new Error('TableCellResizer: Table cell node not found.');
            }
            const tableNode = table.$getTableNodeFromLexicalNodeOrThrow(tableCellNode);
            const tableColumnIndex = table.$getTableColumnIndexFromTableCellNode(tableCellNode);
            const tableRows = tableNode.getChildren();
            for (let r = 0; r < tableRows.length; r++) {
                const tableRow = tableRows[r];
                if (!table.$isTableRowNode(tableRow)) {
                    throw new Error('Expected table row');
                }
                const tableCells = tableRow.getChildren();
                if (tableColumnIndex >= tableCells.length || tableColumnIndex < 0) {
                    throw new Error('Expected table cell to be inside of table row.');
                }
                const tableCell = tableCells[tableColumnIndex];
                if (!table.$isTableCellNode(tableCell)) {
                    throw new Error('Expected table cell');
                }
                tableCell.setWidth(newWidth);
            }
        });
    }, [activeCell, editor]);
    const toggleResize = React.useCallback((direction) => (event) => {
        event.preventDefault();
        event.stopPropagation();
        if (!activeCell) {
            throw new Error('TableCellResizer: Expected active cell.');
        }
        if (draggingDirection === direction && mouseStartPosRef.current) {
            const { x, y } = mouseStartPosRef.current;
            if (activeCell === null) {
                return;
            }
            const { height, width } = activeCell.elem.getBoundingClientRect();
            if (isHeightChanging(direction)) {
                const heightChange = Math.abs(event.clientY - y);
                const isShrinking = direction === 'bottom' && y > event.clientY;
                updateRowHeight(Math.max(isShrinking ? height - heightChange : heightChange + height, MIN_ROW_HEIGHT));
            }
            else {
                const widthChange = Math.abs(event.clientX - x);
                const isShrinking = direction === 'right' && x > event.clientX;
                updateColumnWidth(Math.max(isShrinking ? width - widthChange : widthChange + width, MIN_COLUMN_WIDTH));
            }
            resetState();
        }
        else {
            mouseStartPosRef.current = {
                x: event.clientX,
                y: event.clientY,
            };
            updateMouseCurrentPos(mouseStartPosRef.current);
            updateDraggingDirection(direction);
        }
    }, [
        activeCell,
        draggingDirection,
        resetState,
        updateColumnWidth,
        updateRowHeight,
    ]);
    const getResizers = React.useCallback(() => {
        if (activeCell) {
            const { height, width, top, left } = activeCell.elem.getBoundingClientRect();
            const styles = {
                bottom: {
                    backgroundColor: 'none',
                    cursor: 'row-resize',
                    height: '10px',
                    left: `${window.pageXOffset + left}px`,
                    top: `${window.pageYOffset + top + height}px`,
                    width: `${width}px`,
                },
                right: {
                    backgroundColor: 'none',
                    cursor: 'col-resize',
                    height: `${height}px`,
                    left: `${window.pageXOffset + left + width}px`,
                    top: `${window.pageYOffset + top}px`,
                    width: '10px',
                },
            };
            const tableRect = tableRectRef.current;
            if (draggingDirection && mouseCurrentPos && tableRect) {
                if (isHeightChanging(draggingDirection)) {
                    styles[draggingDirection].left = `${window.pageXOffset + tableRect.left}px`;
                    styles[draggingDirection].top = `${window.pageYOffset + mouseCurrentPos.y}px`;
                    styles[draggingDirection].height = '3px';
                    styles[draggingDirection].width = `${tableRect.width}px`;
                }
                else {
                    styles[draggingDirection].top = `${window.pageYOffset + tableRect.top}px`;
                    styles[draggingDirection].left = `${window.pageXOffset + mouseCurrentPos.x}px`;
                    styles[draggingDirection].width = '3px';
                    styles[draggingDirection].height = `${tableRect.height}px`;
                }
                styles[draggingDirection].backgroundColor = '#adf';
            }
            return styles;
        }
        return {
            bottom: null,
            left: null,
            right: null,
            top: null,
        };
    }, [activeCell, draggingDirection, mouseCurrentPos]);
    const resizerStyles = getResizers();
    return (jsxRuntime.jsx("div", { ref: resizerRef, children: activeCell != null && !isSelectingGrid && (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx("div", { className: "TableCellResizer__resizer TableCellResizer__ui", style: resizerStyles.right || undefined, onMouseDown: toggleResize('right'), onMouseUp: toggleResize('right') }), jsxRuntime.jsx("div", { className: "TableCellResizer__resizer TableCellResizer__ui", style: resizerStyles.bottom || undefined, onMouseDown: toggleResize('bottom'), onMouseUp: toggleResize('bottom') })] })) }));
}
function TableCellResizerPlugin() {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const isEditable = useLexicalEditable__default["default"]();
    return React.useMemo(() => isEditable
        ? ReactDOM.createPortal(jsxRuntime.jsx(TableCellResizer, { editor: editor }), document.body)
        : null, [editor, isEditable]);
}

exports["default"] = TableCellResizerPlugin;
