'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var table = require('@lexical/table');
var lexical = require('lexical');
var React = require('react');
var TableNode = require('../nodes/TableNode.js');
var Button = require('../ui/Button.js');
var Dialog = require('../ui/Dialog.js');
var TextInput = require('../ui/TextInput.js');
var index = require('../shared/index.js');

const INSERT_NEW_TABLE_COMMAND = lexical.createCommand('INSERT_NEW_TABLE_COMMAND');
const CellContext = React.createContext({
    cellEditorConfig: null,
    cellEditorPlugins: null,
    set: () => {
        // Empty
    },
});
function TableContext({ children }) {
    const [contextValue, setContextValue] = React.useState({
        cellEditorConfig: null,
        cellEditorPlugins: null,
    });
    return (jsxRuntime.jsx(CellContext.Provider, { value: React.useMemo(() => ({
            cellEditorConfig: contextValue.cellEditorConfig,
            cellEditorPlugins: contextValue.cellEditorPlugins,
            set: (cellEditorConfig, cellEditorPlugins) => {
                setContextValue({ cellEditorConfig, cellEditorPlugins });
            },
        }), [contextValue.cellEditorConfig, contextValue.cellEditorPlugins]), children: children }));
}
function InsertTableDialog({ activeEditor, onClose, }) {
    const [rows, setRows] = React.useState('5');
    const [columns, setColumns] = React.useState('5');
    const [isDisabled, setIsDisabled] = React.useState(true);
    React.useEffect(() => {
        const row = Number(rows);
        const column = Number(columns);
        if (row && row > 0 && row <= 500 && column && column > 0 && column <= 50) {
            setIsDisabled(false);
        }
        else {
            setIsDisabled(true);
        }
    }, [rows, columns]);
    const onClick = () => {
        activeEditor.dispatchCommand(table.INSERT_TABLE_COMMAND, {
            columns,
            rows,
        });
        onClose();
    };
    return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx(TextInput["default"], { placeholder: '# of rows (1-500)', label: "Rows", onChange: setRows, value: rows, "data-test-id": "table-modal-rows", type: "number" }), jsxRuntime.jsx(TextInput["default"], { placeholder: '# of columns (1-50)', label: "Columns", onChange: setColumns, value: columns, "data-test-id": "table-modal-columns", type: "number" }), jsxRuntime.jsx(Dialog.DialogActions, { "data-test-id": "table-model-confirm-insert", children: jsxRuntime.jsx(Button["default"], { disabled: isDisabled, onClick: onClick, children: "Confirm" }) })] }));
}
function InsertNewTableDialog({ activeEditor, onClose, }) {
    const [rows, setRows] = React.useState('');
    const [columns, setColumns] = React.useState('');
    const [isDisabled, setIsDisabled] = React.useState(true);
    React.useEffect(() => {
        const row = Number(rows);
        const column = Number(columns);
        if (row && row > 0 && row <= 500 && column && column > 0 && column <= 50) {
            setIsDisabled(false);
        }
        else {
            setIsDisabled(true);
        }
    }, [rows, columns]);
    const onClick = () => {
        activeEditor.dispatchCommand(INSERT_NEW_TABLE_COMMAND, { columns, rows });
        onClose();
    };
    return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx(TextInput["default"], { placeholder: '# of rows (1-500)', label: "Rows", onChange: setRows, value: rows, "data-test-id": "table-modal-rows", type: "number" }), jsxRuntime.jsx(TextInput["default"], { placeholder: '# of columns (1-50)', label: "Columns", onChange: setColumns, value: columns, "data-test-id": "table-modal-columns", type: "number" }), jsxRuntime.jsx(Dialog.DialogActions, { "data-test-id": "table-model-confirm-insert", children: jsxRuntime.jsx(Button["default"], { disabled: isDisabled, onClick: onClick, children: "Confirm" }) })] }));
}
function TablePlugin({ cellEditorConfig, children, }) {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const cellContext = React.useContext(CellContext);
    React.useEffect(() => {
        if (!editor.hasNodes([TableNode.TableNode])) {
            index.invariant(false, 'TablePlugin: TableNode is not registered on editor');
        }
        cellContext.set(cellEditorConfig, children);
        return editor.registerCommand(INSERT_NEW_TABLE_COMMAND, ({ columns, rows, includeHeaders }) => {
            const tableNode = TableNode.$createTableNodeWithDimensions(Number(rows), Number(columns), includeHeaders);
            lexical.$insertNodes([tableNode]);
            return true;
        }, lexical.COMMAND_PRIORITY_EDITOR);
    }, [cellContext, cellEditorConfig, children, editor]);
    return null;
}

exports.CellContext = CellContext;
exports.INSERT_NEW_TABLE_COMMAND = INSERT_NEW_TABLE_COMMAND;
exports.InsertNewTableDialog = InsertNewTableDialog;
exports.InsertTableDialog = InsertTableDialog;
exports.TableContext = TableContext;
exports.TablePlugin = TablePlugin;
