'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var code = require('@lexical/code');
var link = require('@lexical/link');
var list = require('@lexical/list');
var LexicalAutoEmbedPlugin = require('@lexical/react/LexicalAutoEmbedPlugin');
var LexicalComposerContext = require('@lexical/react/LexicalComposerContext');
var LexicalDecoratorBlockNode = require('@lexical/react/LexicalDecoratorBlockNode');
var LexicalHorizontalRuleNode = require('@lexical/react/LexicalHorizontalRuleNode');
var richText = require('@lexical/rich-text');
var selection = require('@lexical/selection');
var table = require('@lexical/table');
var utils = require('@lexical/utils');
var lexical = require('lexical');
var React = require('react');
var useModal = require('../../hooks/useModal.js');
var StickyNode = require('../../nodes/StickyNode.js');
var DropDown = require('../../ui/DropDown.js');
var DropdownColorPicker = require('../../ui/DropdownColorPicker.js');
var getSelectedNode = require('../../utils/getSelectedNode.js');
var url = require('../../utils/url.js');
var index$4 = require('../AutoEmbedPlugin/index.js');
var index$3 = require('../CollapsiblePlugin/index.js');
var index$2 = require('../ImagesPlugin/index.js');
var index$1 = require('../PageBreakPlugin/index.js');
var TablePlugin = require('../TablePlugin.js');
var index = require('../../shared/index.js');

const blockTypeToBlockName = {
    bullet: 'Bulleted List',
    check: 'Check List',
    code: 'Code Block',
    // h1: 'Heading 1',
    h2: 'Heading 2',
    h3: 'Heading 3',
    h4: 'Heading 4',
    h5: 'Heading 5',
    h6: 'Heading 6',
    number: 'Numbered List',
    paragraph: 'Normal',
    quote: 'Quote',
};
function getCodeLanguageOptions() {
    const options = [];
    for (const [lang, friendlyName] of Object.entries(code.CODE_LANGUAGE_FRIENDLY_NAME_MAP)) {
        options.push([lang, friendlyName]);
    }
    return options;
}
const CODE_LANGUAGE_OPTIONS = getCodeLanguageOptions();
const FONT_FAMILY_OPTIONS = [
    ['Arial', 'Arial'],
    ['Courier New', 'Courier New'],
    ['Georgia', 'Georgia'],
    ['Times New Roman', 'Times New Roman'],
    ['Trebuchet MS', 'Trebuchet MS'],
    ['Verdana', 'Verdana'],
];
const FONT_SIZE_OPTIONS = [
    ['10px', '10px'],
    ['11px', '11px'],
    ['12px', '12px'],
    ['13px', '13px'],
    ['14px', '14px'],
    ['15px', '15px'],
    ['16px', '16px'],
    ['17px', '17px'],
    ['18px', '18px'],
    ['19px', '19px'],
    ['20px', '20px'],
];
function dropDownActiveClass(active) {
    if (active)
        return 'active dropdown-item-active';
    else
        return '';
}
function BlockFormatDropDown({ editor, blockType, rootType, disabled = false, }) {
    const formatParagraph = () => {
        editor.update(() => {
            const selection$1 = lexical.$getSelection();
            if (lexical.$isRangeSelection(selection$1) ||
                lexical.DEPRECATED_$isGridSelection(selection$1)) {
                selection.$setBlocksType(selection$1, () => lexical.$createParagraphNode());
            }
        });
    };
    const formatHeading = (headingSize) => {
        if (blockType !== headingSize) {
            editor.update(() => {
                const selection$1 = lexical.$getSelection();
                if (lexical.$isRangeSelection(selection$1) ||
                    lexical.DEPRECATED_$isGridSelection(selection$1)) {
                    selection.$setBlocksType(selection$1, () => richText.$createHeadingNode(headingSize));
                }
            });
        }
    };
    const formatBulletList = () => {
        if (blockType !== 'bullet') {
            editor.dispatchCommand(list.INSERT_UNORDERED_LIST_COMMAND, undefined);
        }
        else {
            editor.dispatchCommand(list.REMOVE_LIST_COMMAND, undefined);
        }
    };
    const formatCheckList = () => {
        if (blockType !== 'check') {
            editor.dispatchCommand(list.INSERT_CHECK_LIST_COMMAND, undefined);
        }
        else {
            editor.dispatchCommand(list.REMOVE_LIST_COMMAND, undefined);
        }
    };
    const formatNumberedList = () => {
        if (blockType !== 'number') {
            editor.dispatchCommand(list.INSERT_ORDERED_LIST_COMMAND, undefined);
        }
        else {
            editor.dispatchCommand(list.REMOVE_LIST_COMMAND, undefined);
        }
    };
    const formatQuote = () => {
        if (blockType !== 'quote') {
            editor.update(() => {
                const selection$1 = lexical.$getSelection();
                if (lexical.$isRangeSelection(selection$1) ||
                    lexical.DEPRECATED_$isGridSelection(selection$1)) {
                    selection.$setBlocksType(selection$1, () => richText.$createQuoteNode());
                }
            });
        }
    };
    const formatCode = () => {
        if (blockType !== 'code') {
            editor.update(() => {
                let selection$1 = lexical.$getSelection();
                if (lexical.$isRangeSelection(selection$1) ||
                    lexical.DEPRECATED_$isGridSelection(selection$1)) {
                    if (selection$1.isCollapsed()) {
                        selection.$setBlocksType(selection$1, () => code.$createCodeNode());
                    }
                    else {
                        const textContent = selection$1.getTextContent();
                        const codeNode = code.$createCodeNode();
                        selection$1.insertNodes([codeNode]);
                        selection$1 = lexical.$getSelection();
                        if (lexical.$isRangeSelection(selection$1))
                            selection$1.insertRawText(textContent);
                    }
                }
            });
        }
    };
    return (jsxRuntime.jsxs(DropDown["default"], { disabled: disabled, buttonClassName: "toolbar-item block-controls", buttonIconClassName: 'icon block-type ' + blockType, buttonLabel: blockTypeToBlockName[blockType], buttonAriaLabel: "Formatting options for text style", children: [jsxRuntime.jsxs(DropDown.DropDownItem, { className: 'item ' + dropDownActiveClass(blockType === 'paragraph'), onClick: formatParagraph, children: [jsxRuntime.jsx("i", { className: "icon paragraph" }), jsxRuntime.jsx("span", { className: "text", children: "Normal" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { className: 'item ' + dropDownActiveClass(blockType === 'h2'), onClick: () => formatHeading('h2'), children: [jsxRuntime.jsx("i", { className: "icon h2" }), jsxRuntime.jsx("span", { className: "text", children: "Heading 2" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { className: 'item ' + dropDownActiveClass(blockType === 'h3'), onClick: () => formatHeading('h3'), children: [jsxRuntime.jsx("i", { className: "icon h3" }), jsxRuntime.jsx("span", { className: "text", children: "Heading 3" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { className: 'item ' + dropDownActiveClass(blockType === 'bullet'), onClick: formatBulletList, children: [jsxRuntime.jsx("i", { className: "icon bullet-list" }), jsxRuntime.jsx("span", { className: "text", children: "Bullet List" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { className: 'item ' + dropDownActiveClass(blockType === 'number'), onClick: formatNumberedList, children: [jsxRuntime.jsx("i", { className: "icon numbered-list" }), jsxRuntime.jsx("span", { className: "text", children: "Numbered List" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { className: 'item ' + dropDownActiveClass(blockType === 'check'), onClick: formatCheckList, children: [jsxRuntime.jsx("i", { className: "icon check-list" }), jsxRuntime.jsx("span", { className: "text", children: "Check List" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { className: 'item ' + dropDownActiveClass(blockType === 'quote'), onClick: formatQuote, children: [jsxRuntime.jsx("i", { className: "icon quote" }), jsxRuntime.jsx("span", { className: "text", children: "Quote" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { className: 'item ' + dropDownActiveClass(blockType === 'code'), onClick: formatCode, children: [jsxRuntime.jsx("i", { className: "icon code" }), jsxRuntime.jsx("span", { className: "text", children: "Code Block" })] })] }));
}
function Divider() {
    return jsxRuntime.jsx("div", { className: "divider" });
}
function FontDropDown({ editor, value, style, disabled = false, }) {
    const handleClick = React.useCallback((option) => {
        editor.update(() => {
            const selection$1 = lexical.$getSelection();
            if (lexical.$isRangeSelection(selection$1)) {
                selection.$patchStyleText(selection$1, {
                    [style]: option,
                });
            }
        });
    }, [editor, style]);
    const buttonAriaLabel = style === 'font-family'
        ? 'Formatting options for font family'
        : 'Formatting options for font size';
    return (jsxRuntime.jsx(DropDown["default"], { disabled: disabled, buttonClassName: 'toolbar-item ' + style, buttonLabel: value, buttonIconClassName: style === 'font-family' ? 'icon block-type font-family' : '', buttonAriaLabel: buttonAriaLabel, children: (style === 'font-family' ? FONT_FAMILY_OPTIONS : FONT_SIZE_OPTIONS).map(([option, text]) => (jsxRuntime.jsx(DropDown.DropDownItem, { className: `item ${dropDownActiveClass(value === option)} ${style === 'font-size' ? 'fontsize-item' : ''}`, onClick: () => handleClick(option), children: jsxRuntime.jsx("span", { className: "text", children: text }) }, option))) }));
}
function ToolbarPlugin() {
    const [editor] = LexicalComposerContext.useLexicalComposerContext();
    const [activeEditor, setActiveEditor] = React.useState(editor);
    const [blockType, setBlockType] = React.useState('paragraph');
    const [rootType, setRootType] = React.useState('root');
    const [selectedElementKey, setSelectedElementKey] = React.useState(null);
    const [fontSize, setFontSize] = React.useState('15px');
    const [fontColor, setFontColor] = React.useState('#000');
    const [bgColor, setBgColor] = React.useState('#fff');
    const [fontFamily, setFontFamily] = React.useState('Arial');
    const [isLink, setIsLink] = React.useState(false);
    const [isBold, setIsBold] = React.useState(false);
    const [isItalic, setIsItalic] = React.useState(false);
    const [isUnderline, setIsUnderline] = React.useState(false);
    const [isStrikethrough, setIsStrikethrough] = React.useState(false);
    const [isSubscript, setIsSubscript] = React.useState(false);
    const [isSuperscript, setIsSuperscript] = React.useState(false);
    const [isCode, setIsCode] = React.useState(false);
    const [canUndo, setCanUndo] = React.useState(false);
    const [canRedo, setCanRedo] = React.useState(false);
    const [modal, showModal] = useModal["default"]();
    const [isRTL, setIsRTL] = React.useState(false);
    const [codeLanguage, setCodeLanguage] = React.useState('');
    const [isEditable, setIsEditable] = React.useState(() => editor.isEditable());
    const $updateToolbar = React.useCallback(() => {
        const selection$1 = lexical.$getSelection();
        if (lexical.$isRangeSelection(selection$1)) {
            const anchorNode = selection$1.anchor.getNode();
            let element = anchorNode.getKey() === 'root'
                ? anchorNode
                : utils.$findMatchingParent(anchorNode, (e) => {
                    const parent = e.getParent();
                    return parent !== null && lexical.$isRootOrShadowRoot(parent);
                });
            if (element === null) {
                element = anchorNode.getTopLevelElementOrThrow();
            }
            const elementKey = element.getKey();
            const elementDOM = activeEditor.getElementByKey(elementKey);
            // Update text format
            setIsBold(selection$1.hasFormat('bold'));
            setIsItalic(selection$1.hasFormat('italic'));
            setIsUnderline(selection$1.hasFormat('underline'));
            setIsStrikethrough(selection$1.hasFormat('strikethrough'));
            setIsSubscript(selection$1.hasFormat('subscript'));
            setIsSuperscript(selection$1.hasFormat('superscript'));
            setIsCode(selection$1.hasFormat('code'));
            setIsRTL(selection.$isParentElementRTL(selection$1));
            // Update links
            const node = getSelectedNode.getSelectedNode(selection$1);
            const parent = node.getParent();
            if (link.$isLinkNode(parent) || link.$isLinkNode(node)) {
                setIsLink(true);
            }
            else {
                setIsLink(false);
            }
            const tableNode = utils.$findMatchingParent(node, table.$isTableNode);
            if (table.$isTableNode(tableNode)) {
                setRootType('table');
            }
            else {
                setRootType('root');
            }
            if (elementDOM !== null) {
                setSelectedElementKey(elementKey);
                if (list.$isListNode(element)) {
                    const parentList = utils.$getNearestNodeOfType(anchorNode, list.ListNode);
                    const type = parentList
                        ? parentList.getListType()
                        : element.getListType();
                    setBlockType(type);
                }
                else {
                    const type = richText.$isHeadingNode(element)
                        ? element.getTag()
                        : element.getType();
                    if (type in blockTypeToBlockName) {
                        setBlockType(type);
                    }
                    if (code.$isCodeNode(element)) {
                        const language = element.getLanguage();
                        setCodeLanguage(language ? code.CODE_LANGUAGE_MAP[language] || language : '');
                        return;
                    }
                }
            }
            // Handle buttons
            setFontSize(selection.$getSelectionStyleValueForProperty(selection$1, 'font-size', '15px'));
            setFontColor(selection.$getSelectionStyleValueForProperty(selection$1, 'color', '#000'));
            setBgColor(selection.$getSelectionStyleValueForProperty(selection$1, 'background-color', '#fff'));
            setFontFamily(selection.$getSelectionStyleValueForProperty(selection$1, 'font-family', 'Arial'));
        }
    }, [activeEditor]);
    React.useEffect(() => {
        return editor.registerCommand(lexical.SELECTION_CHANGE_COMMAND, (_payload, newEditor) => {
            $updateToolbar();
            setActiveEditor(newEditor);
            return false;
        }, lexical.COMMAND_PRIORITY_CRITICAL);
    }, [editor, $updateToolbar]);
    React.useEffect(() => {
        return utils.mergeRegister(editor.registerEditableListener((editable) => {
            setIsEditable(editable);
        }), activeEditor.registerUpdateListener(({ editorState }) => {
            editorState.read(() => {
                $updateToolbar();
            });
        }), activeEditor.registerCommand(lexical.CAN_UNDO_COMMAND, (payload) => {
            setCanUndo(payload);
            return false;
        }, lexical.COMMAND_PRIORITY_CRITICAL), activeEditor.registerCommand(lexical.CAN_REDO_COMMAND, (payload) => {
            setCanRedo(payload);
            return false;
        }, lexical.COMMAND_PRIORITY_CRITICAL));
    }, [$updateToolbar, activeEditor, editor]);
    React.useEffect(() => {
        return activeEditor.registerCommand(lexical.KEY_MODIFIER_COMMAND, (payload) => {
            const event = payload;
            const { code, ctrlKey, metaKey } = event;
            if (code === 'KeyK' && (ctrlKey || metaKey)) {
                event.preventDefault();
                return activeEditor.dispatchCommand(link.TOGGLE_LINK_COMMAND, url.sanitizeUrl('https://'));
            }
            return false;
        }, lexical.COMMAND_PRIORITY_NORMAL);
    }, [activeEditor, isLink]);
    const applyStyleText = React.useCallback((styles) => {
        activeEditor.update(() => {
            const selection$1 = lexical.$getSelection();
            if (lexical.$isRangeSelection(selection$1)) {
                selection.$patchStyleText(selection$1, styles);
            }
        });
    }, [activeEditor]);
    const clearFormatting = React.useCallback(() => {
        activeEditor.update(() => {
            const selection = lexical.$getSelection();
            if (lexical.$isRangeSelection(selection)) {
                const anchor = selection.anchor;
                const focus = selection.focus;
                const nodes = selection.getNodes();
                if (anchor.key === focus.key && anchor.offset === focus.offset) {
                    return;
                }
                nodes.forEach((node, idx) => {
                    // We split the first and last node by the selection
                    // So that we don't format unselected text inside those nodes
                    if (lexical.$isTextNode(node)) {
                        if (idx === 0 && anchor.offset !== 0) {
                            node = node.splitText(anchor.offset)[1] || node;
                        }
                        if (idx === nodes.length - 1) {
                            node = node.splitText(focus.offset)[0] || node;
                        }
                        if (node.__style !== '') {
                            node.setStyle('');
                        }
                        if (node.__format !== 0) {
                            node.setFormat(0);
                            utils.$getNearestBlockElementAncestorOrThrow(node).setFormat('');
                        }
                    }
                    else if (richText.$isHeadingNode(node) || richText.$isQuoteNode(node)) {
                        node.replace(lexical.$createParagraphNode(), true);
                    }
                    else if (LexicalDecoratorBlockNode.$isDecoratorBlockNode(node)) {
                        node.setFormat('');
                    }
                });
            }
        });
    }, [activeEditor]);
    const onFontColorSelect = React.useCallback((value) => {
        applyStyleText({ color: value });
    }, [applyStyleText]);
    const onBgColorSelect = React.useCallback((value) => {
        applyStyleText({ 'background-color': value });
    }, [applyStyleText]);
    const insertLink = React.useCallback(() => {
        if (!isLink) {
            editor.dispatchCommand(link.TOGGLE_LINK_COMMAND, url.sanitizeUrl('https://'));
        }
        else {
            editor.dispatchCommand(link.TOGGLE_LINK_COMMAND, null);
        }
    }, [editor, isLink]);
    const onCodeLanguageSelect = React.useCallback((value) => {
        activeEditor.update(() => {
            if (selectedElementKey !== null) {
                const node = lexical.$getNodeByKey(selectedElementKey);
                if (code.$isCodeNode(node)) {
                    node.setLanguage(value);
                }
            }
        });
    }, [activeEditor, selectedElementKey]);
    return (jsxRuntime.jsxs("div", { className: "toolbar", children: [jsxRuntime.jsx("button", { disabled: !canUndo || !isEditable, onClick: () => {
                    activeEditor.dispatchCommand(lexical.UNDO_COMMAND, undefined);
                }, title: index.IS_APPLE ? 'Undo (⌘Z)' : 'Undo (Ctrl+Z)', type: "button", className: "toolbar-item spaced", "aria-label": "Undo", children: jsxRuntime.jsx("i", { className: "format undo" }) }), jsxRuntime.jsx("button", { disabled: !canRedo || !isEditable, onClick: () => {
                    activeEditor.dispatchCommand(lexical.REDO_COMMAND, undefined);
                }, title: index.IS_APPLE ? 'Redo (⌘Y)' : 'Redo (Ctrl+Y)', type: "button", className: "toolbar-item", "aria-label": "Redo", children: jsxRuntime.jsx("i", { className: "format redo" }) }), jsxRuntime.jsx(Divider, {}), blockType in blockTypeToBlockName && activeEditor === editor && (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx(BlockFormatDropDown, { disabled: !isEditable, blockType: blockType, rootType: rootType, editor: editor }), jsxRuntime.jsx(Divider, {})] })), blockType === 'code' ? (jsxRuntime.jsx(DropDown["default"], { disabled: !isEditable, buttonClassName: "toolbar-item code-language", buttonLabel: code.getLanguageFriendlyName(codeLanguage), buttonAriaLabel: "Select language", children: CODE_LANGUAGE_OPTIONS.map(([value, name]) => {
                    return (jsxRuntime.jsx(DropDown.DropDownItem, { className: `item ${dropDownActiveClass(value === codeLanguage)}`, onClick: () => onCodeLanguageSelect(value), children: jsxRuntime.jsx("span", { className: "text", children: name }) }, value));
                }) })) : (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx(FontDropDown, { disabled: !isEditable, style: 'font-family', value: fontFamily, editor: editor }), jsxRuntime.jsx(FontDropDown, { disabled: !isEditable, style: 'font-size', value: fontSize, editor: editor }), jsxRuntime.jsx(Divider, {}), jsxRuntime.jsx("button", { disabled: !isEditable, onClick: () => {
                            activeEditor.dispatchCommand(lexical.FORMAT_TEXT_COMMAND, 'bold');
                        }, className: 'toolbar-item spaced ' + (isBold ? 'active' : ''), title: index.IS_APPLE ? 'Bold (⌘B)' : 'Bold (Ctrl+B)', type: "button", "aria-label": `Format text as bold. Shortcut: ${index.IS_APPLE ? '⌘B' : 'Ctrl+B'}`, children: jsxRuntime.jsx("i", { className: "format bold" }) }), jsxRuntime.jsx("button", { disabled: !isEditable, onClick: () => {
                            activeEditor.dispatchCommand(lexical.FORMAT_TEXT_COMMAND, 'italic');
                        }, className: 'toolbar-item spaced ' + (isItalic ? 'active' : ''), title: index.IS_APPLE ? 'Italic (⌘I)' : 'Italic (Ctrl+I)', type: "button", "aria-label": `Format text as italics. Shortcut: ${index.IS_APPLE ? '⌘I' : 'Ctrl+I'}`, children: jsxRuntime.jsx("i", { className: "format italic" }) }), jsxRuntime.jsx("button", { disabled: !isEditable, onClick: () => {
                            activeEditor.dispatchCommand(lexical.FORMAT_TEXT_COMMAND, 'underline');
                        }, className: 'toolbar-item spaced ' + (isUnderline ? 'active' : ''), title: index.IS_APPLE ? 'Underline (⌘U)' : 'Underline (Ctrl+U)', type: "button", "aria-label": `Format text to underlined. Shortcut: ${index.IS_APPLE ? '⌘U' : 'Ctrl+U'}`, children: jsxRuntime.jsx("i", { className: "format underline" }) }), jsxRuntime.jsx("button", { disabled: !isEditable, onClick: () => {
                            activeEditor.dispatchCommand(lexical.FORMAT_TEXT_COMMAND, 'code');
                        }, className: 'toolbar-item spaced ' + (isCode ? 'active' : ''), title: "Insert code block", type: "button", "aria-label": "Insert code block", children: jsxRuntime.jsx("i", { className: "format code" }) }), jsxRuntime.jsx("button", { disabled: !isEditable, onClick: insertLink, className: 'toolbar-item spaced ' + (isLink ? 'active' : ''), "aria-label": "Insert link", title: "Insert link", type: "button", children: jsxRuntime.jsx("i", { className: "format link" }) }), jsxRuntime.jsx(DropdownColorPicker["default"], { disabled: !isEditable, buttonClassName: "toolbar-item color-picker", buttonAriaLabel: "Formatting text color", buttonIconClassName: "icon font-color", color: fontColor, onChange: onFontColorSelect, title: "text color" }), jsxRuntime.jsx(DropdownColorPicker["default"], { disabled: !isEditable, buttonClassName: "toolbar-item color-picker", buttonAriaLabel: "Formatting background color", buttonIconClassName: "icon bg-color", color: bgColor, onChange: onBgColorSelect, title: "bg color" }), jsxRuntime.jsxs(DropDown["default"], { disabled: !isEditable, buttonClassName: "toolbar-item spaced", buttonLabel: "", buttonAriaLabel: "Formatting options for additional text styles", buttonIconClassName: "icon dropdown-more", children: [jsxRuntime.jsxs(DropDown.DropDownItem, { onClick: () => {
                                    activeEditor.dispatchCommand(lexical.FORMAT_TEXT_COMMAND, 'strikethrough');
                                }, className: 'item ' + dropDownActiveClass(isStrikethrough), title: "Strikethrough", "aria-label": "Format text with a strikethrough", children: [jsxRuntime.jsx("i", { className: "icon strikethrough" }), jsxRuntime.jsx("span", { className: "text", children: "Strikethrough" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { onClick: () => {
                                    activeEditor.dispatchCommand(lexical.FORMAT_TEXT_COMMAND, 'subscript');
                                }, className: 'item ' + dropDownActiveClass(isSubscript), title: "Subscript", "aria-label": "Format text with a subscript", children: [jsxRuntime.jsx("i", { className: "icon subscript" }), jsxRuntime.jsx("span", { className: "text", children: "Subscript" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { onClick: () => {
                                    activeEditor.dispatchCommand(lexical.FORMAT_TEXT_COMMAND, 'superscript');
                                }, className: 'item ' + dropDownActiveClass(isSuperscript), title: "Superscript", "aria-label": "Format text with a superscript", children: [jsxRuntime.jsx("i", { className: "icon superscript" }), jsxRuntime.jsx("span", { className: "text", children: "Superscript" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { onClick: clearFormatting, className: "item", title: "Clear text formatting", "aria-label": "Clear all text formatting", children: [jsxRuntime.jsx("i", { className: "icon clear" }), jsxRuntime.jsx("span", { className: "text", children: "Clear Formatting" })] })] }), jsxRuntime.jsx(Divider, {}), rootType === 'table' && (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx(DropDown["default"], { disabled: !isEditable, buttonClassName: "toolbar-item spaced", buttonLabel: "Table", buttonAriaLabel: "Open table toolkit", buttonIconClassName: "icon table secondary", children: jsxRuntime.jsx(DropDown.DropDownItem, { onClick: () => {
                                        /**/
                                    }, className: "item", children: jsxRuntime.jsx("span", { className: "text", children: "TODO" }) }) }), jsxRuntime.jsx(Divider, {})] })), jsxRuntime.jsxs(DropDown["default"], { disabled: !isEditable, buttonClassName: "toolbar-item spaced", buttonLabel: "Insert", buttonAriaLabel: "Insert specialized editor node", buttonIconClassName: "icon plus", children: [jsxRuntime.jsxs(DropDown.DropDownItem, { onClick: () => {
                                    activeEditor.dispatchCommand(LexicalHorizontalRuleNode.INSERT_HORIZONTAL_RULE_COMMAND, undefined);
                                }, className: "item", children: [jsxRuntime.jsx("i", { className: "icon horizontal-rule" }), jsxRuntime.jsx("span", { className: "text", children: "Horizontal Rule" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { onClick: () => {
                                    activeEditor.dispatchCommand(index$1.INSERT_PAGE_BREAK, undefined);
                                }, className: "item", children: [jsxRuntime.jsx("i", { className: "icon page-break" }), jsxRuntime.jsx("span", { className: "text", children: "Page Break" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { onClick: () => {
                                    showModal('Insert Image', (onClose) => (jsxRuntime.jsx(index$2.InsertImageDialog, { activeEditor: activeEditor, onClose: onClose })));
                                }, className: "item", children: [jsxRuntime.jsx("i", { className: "icon image" }), jsxRuntime.jsx("span", { className: "text", children: "Image" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { onClick: () => {
                                    showModal('Insert Table', (onClose) => (jsxRuntime.jsx(TablePlugin.InsertTableDialog, { activeEditor: activeEditor, onClose: onClose })));
                                }, className: "item", children: [jsxRuntime.jsx("i", { className: "icon table" }), jsxRuntime.jsx("span", { className: "text", children: "Table" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { onClick: () => {
                                    editor.update(() => {
                                        const root = lexical.$getRoot();
                                        const stickyNode = StickyNode.$createStickyNode(0, 0);
                                        root.append(stickyNode);
                                    });
                                }, className: "item", children: [jsxRuntime.jsx("i", { className: "icon sticky" }), jsxRuntime.jsx("span", { className: "text", children: "Sticky Note" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { onClick: () => {
                                    editor.dispatchCommand(index$3.INSERT_COLLAPSIBLE_COMMAND, undefined);
                                }, className: "item", children: [jsxRuntime.jsx("i", { className: "icon caret-right" }), jsxRuntime.jsx("span", { className: "text", children: "Collapsible container" })] }), index$4.EmbedConfigs.map((embedConfig) => (jsxRuntime.jsxs(DropDown.DropDownItem, { onClick: () => {
                                    activeEditor.dispatchCommand(LexicalAutoEmbedPlugin.INSERT_EMBED_COMMAND, embedConfig.type);
                                }, className: "item", children: [embedConfig.icon, jsxRuntime.jsx("span", { className: "text", children: embedConfig.contentName })] }, embedConfig.type)))] })] })), jsxRuntime.jsx(Divider, {}), jsxRuntime.jsxs(DropDown["default"], { disabled: !isEditable, buttonLabel: "Align", buttonIconClassName: "icon left-align", buttonClassName: "toolbar-item spaced alignment", buttonAriaLabel: "Formatting options for text alignment", children: [jsxRuntime.jsxs(DropDown.DropDownItem, { onClick: () => {
                            activeEditor.dispatchCommand(lexical.FORMAT_ELEMENT_COMMAND, 'left');
                        }, className: "item", children: [jsxRuntime.jsx("i", { className: "icon left-align" }), jsxRuntime.jsx("span", { className: "text", children: "Left Align" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { onClick: () => {
                            activeEditor.dispatchCommand(lexical.FORMAT_ELEMENT_COMMAND, 'center');
                        }, className: "item", children: [jsxRuntime.jsx("i", { className: "icon center-align" }), jsxRuntime.jsx("span", { className: "text", children: "Center Align" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { onClick: () => {
                            activeEditor.dispatchCommand(lexical.FORMAT_ELEMENT_COMMAND, 'right');
                        }, className: "item", children: [jsxRuntime.jsx("i", { className: "icon right-align" }), jsxRuntime.jsx("span", { className: "text", children: "Right Align" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { onClick: () => {
                            activeEditor.dispatchCommand(lexical.FORMAT_ELEMENT_COMMAND, 'justify');
                        }, className: "item", children: [jsxRuntime.jsx("i", { className: "icon justify-align" }), jsxRuntime.jsx("span", { className: "text", children: "Justify Align" })] }), jsxRuntime.jsx(Divider, {}), jsxRuntime.jsxs(DropDown.DropDownItem, { onClick: () => {
                            activeEditor.dispatchCommand(lexical.OUTDENT_CONTENT_COMMAND, undefined);
                        }, className: "item", children: [jsxRuntime.jsx("i", { className: 'icon ' + (isRTL ? 'indent' : 'outdent') }), jsxRuntime.jsx("span", { className: "text", children: "Outdent" })] }), jsxRuntime.jsxs(DropDown.DropDownItem, { onClick: () => {
                            activeEditor.dispatchCommand(lexical.INDENT_CONTENT_COMMAND, undefined);
                        }, className: "item", children: [jsxRuntime.jsx("i", { className: 'icon ' + (isRTL ? 'outdent' : 'indent') }), jsxRuntime.jsx("span", { className: "text", children: "Indent" })] })] }), modal] }));
}

exports["default"] = ToolbarPlugin;
