'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var React = require('react');
var ReactDOM = require('react-dom');

function _interopNamespace(e) {
    if (e && e.__esModule) return e;
    var n = Object.create(null);
    if (e) {
        Object.keys(e).forEach(function (k) {
            if (k !== 'default') {
                var d = Object.getOwnPropertyDescriptor(e, k);
                Object.defineProperty(n, k, d.get ? d : {
                    enumerable: true,
                    get: function () { return e[k]; }
                });
            }
        });
    }
    n["default"] = e;
    return Object.freeze(n);
}

var React__namespace = /*#__PURE__*/_interopNamespace(React);

const DropDownContext = React__namespace.createContext(null);
const dropDownPadding = 4;
function DropDownItem({ children, className, onClick, title, }) {
    const ref = React.useRef(null);
    const dropDownContext = React__namespace.useContext(DropDownContext);
    if (dropDownContext === null) {
        throw new Error('DropDownItem must be used within a DropDown');
    }
    const { registerItem } = dropDownContext;
    React.useEffect(() => {
        if (ref && ref.current) {
            registerItem(ref);
        }
    }, [ref, registerItem]);
    return (jsxRuntime.jsx("button", { className: className, onClick: onClick, ref: ref, title: title, type: "button", children: children }));
}
function DropDownItems({ children, dropDownRef, onClose, }) {
    const [items, setItems] = React.useState();
    const [highlightedItem, setHighlightedItem] = React.useState();
    const registerItem = React.useCallback((itemRef) => {
        setItems((prev) => (prev ? [...prev, itemRef] : [itemRef]));
    }, [setItems]);
    const handleKeyDown = (event) => {
        if (!items)
            return;
        const key = event.key;
        if (['Escape', 'ArrowUp', 'ArrowDown', 'Tab'].includes(key)) {
            event.preventDefault();
        }
        if (key === 'Escape' || key === 'Tab') {
            onClose();
        }
        else if (key === 'ArrowUp') {
            setHighlightedItem((prev) => {
                if (!prev)
                    return items[0];
                const index = items.indexOf(prev) - 1;
                return items[index === -1 ? items.length - 1 : index];
            });
        }
        else if (key === 'ArrowDown') {
            setHighlightedItem((prev) => {
                if (!prev)
                    return items[0];
                return items[items.indexOf(prev) + 1];
            });
        }
    };
    const contextValue = React.useMemo(() => ({
        registerItem,
    }), [registerItem]);
    React.useEffect(() => {
        if (items && !highlightedItem) {
            setHighlightedItem(items[0]);
        }
        if (highlightedItem && highlightedItem.current) {
            highlightedItem.current.focus();
        }
    }, [items, highlightedItem]);
    return (jsxRuntime.jsx(DropDownContext.Provider, { value: contextValue, children: jsxRuntime.jsx("div", { className: "dropdown", ref: dropDownRef, onKeyDown: handleKeyDown, children: children }) }));
}
function DropDown({ disabled = false, buttonLabel, buttonAriaLabel, buttonClassName, buttonIconClassName, children, stopCloseOnClickSelf, }) {
    const dropDownRef = React.useRef(null);
    const buttonRef = React.useRef(null);
    const [showDropDown, setShowDropDown] = React.useState(false);
    const handleClose = () => {
        setShowDropDown(false);
        if (buttonRef && buttonRef.current) {
            buttonRef.current.focus();
        }
    };
    React.useEffect(() => {
        const button = buttonRef.current;
        const dropDown = dropDownRef.current;
        if (showDropDown && button !== null && dropDown !== null) {
            const { top, left } = button.getBoundingClientRect();
            dropDown.style.top = `${top + button.offsetHeight + dropDownPadding}px`;
            dropDown.style.left = `${Math.min(left, window.innerWidth - dropDown.offsetWidth - 20)}px`;
        }
    }, [dropDownRef, buttonRef, showDropDown]);
    React.useEffect(() => {
        const button = buttonRef.current;
        if (button !== null && showDropDown) {
            const handle = (event) => {
                const target = event.target;
                if (stopCloseOnClickSelf) {
                    if (dropDownRef.current &&
                        dropDownRef.current.contains(target))
                        return;
                }
                if (!button.contains(target)) {
                    setShowDropDown(false);
                }
            };
            document.addEventListener('click', handle);
            return () => {
                document.removeEventListener('click', handle);
            };
        }
    }, [dropDownRef, buttonRef, showDropDown, stopCloseOnClickSelf]);
    React.useEffect(() => {
        const handleButtonPositionUpdate = () => {
            if (showDropDown) {
                const button = buttonRef.current;
                const dropDown = dropDownRef.current;
                if (button !== null && dropDown !== null) {
                    const { top } = button.getBoundingClientRect();
                    const newPosition = top + button.offsetHeight + dropDownPadding;
                    if (newPosition !== dropDown.getBoundingClientRect().top) {
                        dropDown.style.top = `${newPosition}px`;
                    }
                }
            }
        };
        document.addEventListener('scroll', handleButtonPositionUpdate);
        return () => {
            document.removeEventListener('scroll', handleButtonPositionUpdate);
        };
    }, [buttonRef, dropDownRef, showDropDown]);
    return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsxs("button", { type: "button", disabled: disabled, "aria-label": buttonAriaLabel || buttonLabel, className: buttonClassName, onClick: () => setShowDropDown(!showDropDown), ref: buttonRef, children: [buttonIconClassName && jsxRuntime.jsx("span", { className: buttonIconClassName }), buttonLabel && (jsxRuntime.jsx("span", { className: "text dropdown-button-text", children: buttonLabel })), jsxRuntime.jsx("i", { className: "chevron-down" })] }), showDropDown &&
                ReactDOM.createPortal(jsxRuntime.jsx(DropDownItems, { dropDownRef: dropDownRef, onClose: handleClose, children: children }), document.body)] }));
}

exports.DropDownItem = DropDownItem;
exports["default"] = DropDown;
