'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
require('./Modal.css.js');
var React = require('react');
var ReactDOM = require('react-dom');

function PortalImpl({ onClose, children, title, closeOnClickOutside, }) {
    const modalRef = React.useRef(null);
    React.useEffect(() => {
        if (modalRef.current !== null) {
            modalRef.current.focus();
        }
    }, []);
    React.useEffect(() => {
        let modalOverlayElement = null;
        const handler = (event) => {
            if (event.keyCode === 27) {
                onClose();
            }
        };
        const clickOutsideHandler = (event) => {
            const target = event.target;
            if (modalRef.current !== null &&
                !modalRef.current.contains(target) &&
                closeOnClickOutside) {
                onClose();
            }
        };
        const modelElement = modalRef.current;
        if (modelElement !== null) {
            modalOverlayElement = modelElement.parentElement;
            if (modalOverlayElement !== null) {
                modalOverlayElement.addEventListener('click', clickOutsideHandler);
            }
        }
        window.addEventListener('keydown', handler);
        return () => {
            window.removeEventListener('keydown', handler);
            if (modalOverlayElement !== null) {
                modalOverlayElement === null || modalOverlayElement === void 0 ? void 0 : modalOverlayElement.removeEventListener('click', clickOutsideHandler);
            }
        };
    }, [closeOnClickOutside, onClose]);
    return (jsxRuntime.jsx("div", { className: "Modal__overlay", role: "dialog", children: jsxRuntime.jsxs("div", { className: "Modal__modal", tabIndex: -1, ref: modalRef, children: [jsxRuntime.jsx("h2", { className: "Modal__title", children: title }), jsxRuntime.jsx("button", { className: "Modal__closeButton", "aria-label": "Close modal", type: "button", onClick: onClose, children: "X" }), jsxRuntime.jsx("div", { className: "Modal__content", children: children })] }) }));
}
function Modal({ onClose, children, title, closeOnClickOutside = false, }) {
    return ReactDOM.createPortal(jsxRuntime.jsx(PortalImpl, { onClose: onClose, title: title, closeOnClickOutside: closeOnClickOutside, children: children }), document.body);
}

exports["default"] = Modal;
