'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var tslib_es6 = require('../node_modules/tslib/tslib.es6.js');

const domain = `https://editor.cpchain.io`;
const defaultUrl = domain + `/graphql`;
const editorUploadImageUrl = `${domain}/upload`;
function graphqlQuery(query, opts) {
    return tslib_es6.__awaiter(this, void 0, void 0, function* () {
        const res = yield fetch((opts === null || opts === void 0 ? void 0 : opts.server) || defaultUrl, {
            method: 'POST',
            headers: {
                Accept: 'application/json',
                'Content-Type': 'application/json'
            },
            body: JSON.stringify({
                query
            })
        });
        const data = yield res.json();
        return data.data;
    });
}
function getFiles({ limit, offset }) {
    return tslib_es6.__awaiter(this, void 0, void 0, function* () {
        const r = yield graphqlQuery(`query { 
        files(limit:${limit},offset:${offset}, tags:["image"], excludeTags:["svgr/webpack"]) {
            count,
            results {
              originPath,
              minPath,
              tags,
            }
          }
      } `);
        return r.files;
    });
}
function getEditorImages({ limit, offset }) {
    return tslib_es6.__awaiter(this, void 0, void 0, function* () {
        const r = yield getFiles({ limit, offset });
        const urls = r.results.map(p => domain + p.originPath);
        return { count: r.count, results: urls };
    });
}

exports.domain = domain;
exports.editorUploadImageUrl = editorUploadImageUrl;
exports.getEditorImages = getEditorImages;
exports.getFiles = getFiles;
exports.graphqlQuery = graphqlQuery;
